@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 2004, 2005, 2006, 2008, 2009, 2010, 2011 Savoir-Faire Linux Inc.
+ *  Copyright (C) 2004-2012 Savoir-Faire Linux Inc.
  *  Author: Alexandre Savard <alexandre.savard@savoirfairelinux.com>
  *
  *  This program is free software; you can redistribute it and/or modify
@@ -14,7 +14,7 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301 USA.
  *
  *  Additional permission under GNU GPL version 3 section 7:
  *
@@ -35,6 +35,7 @@
 #include "audiorecord.h"
 #include <unistd.h>
 #include <sstream> // for stringstream
+#include <algorithm>
 #include <cstdio>
 #include "logger.h"
 #include "fileutils.h"
@@ -57,6 +58,54 @@ struct wavhdr {
     SINT32 data_length;     // in bytes
 };
 
+namespace {
+std::string
+createFilename()
+{
+    time_t rawtime = time(NULL);
+    struct tm * timeinfo = localtime(&rawtime);
+
+    std::stringstream out;
+
+    // DATE
+    out << timeinfo->tm_year + 1900;
+
+    if (timeinfo->tm_mon < 9) // january is 01, not 1
+        out << 0;
+
+    out << timeinfo->tm_mon + 1;
+
+    if (timeinfo->tm_mday < 10) // 01 02 03, not 1 2 3
+        out << 0;
+
+    out << timeinfo->tm_mday;
+
+    out << '-';
+
+    // hour
+    if (timeinfo->tm_hour < 10) // 01 02 03, not 1 2 3
+        out << 0;
+
+    out << timeinfo->tm_hour;
+
+    out << ':';
+
+    if (timeinfo->tm_min < 10) // 01 02 03, not 1 2 3
+        out << 0;
+
+    out << timeinfo->tm_min;
+
+    out << ':';
+
+    if (timeinfo->tm_sec < 10) // 01 02 03,  not 1 2 3
+        out << 0;
+
+    out << timeinfo->tm_sec;
+    return out.str();
+}
+}
+
+
 AudioRecord::AudioRecord() : fileHandle_(NULL)
     , fileType_(FILE_INVALID)
     , channels_(1)
@@ -68,10 +117,10 @@ AudioRecord::AudioRecord() : fileHandle_(NULL)
     , mixBuffer_()
     , micBuffer_()
     , spkBuffer_()
-    , filename_()
+    , filename_(createFilename())
     , savePath_()
 {
-    createFilename();
+    WARN("Generate filename for this call %s ", filename_.c_str());
 }
 
 void AudioRecord::setSndSamplingRate(int smplRate)
@@ -81,28 +130,41 @@ void AudioRecord::setSndSamplingRate(int smplRate)
 
 void AudioRecord::setRecordingOption(FILE_TYPE type, int sndSmplRate, const std::string &path)
 {
-    std::stringstream s;
     std::string filePath;
 
     // use HOME directory if path is empty, or if path does not exist
-    if (path.empty() || !fileutils::check_dir(path.c_str())) {
-        s << getenv("HOME");
-        filePath = s.str();
-    }
-    else {
+    if (path.empty() or not fileutils::check_dir(path.c_str())) {
+        filePath = fileutils::get_home_dir();
+    } else {
         filePath = path;
     }
 
     fileType_ = type;
     channels_ = 1;
     sndSmplRate_ = sndSmplRate;
-    savePath_ = (*filePath.rbegin() == '/') ? filePath : filePath + "/";
+    savePath_ = (*filePath.rbegin() == DIR_SEPARATOR_CH) ? filePath : filePath + DIR_SEPARATOR_STR;
+}
+
+namespace {
+bool
+nonFilenameCharacter(char c)
+{
+    return not (std::isalnum(c) or c == '_' or c == '.');
+}
+
+// Replace any character that is inappropriate for a filename with '_'
+std::string
+sanitize(std::string s)
+{
+    std::replace_if(s.begin(), s.end(), nonFilenameCharacter, '_');
+    return s;
+}
 }
 
 void AudioRecord::initFilename(const std::string &peerNumber)
 {
     std::string fName(filename_);
-    fName.append("-" + peerNumber + "-" PACKAGE);
+    fName.append("-" + sanitize(peerNumber) + "-" PACKAGE);
 
     if (fileType_ == FILE_RAW) {
         if (filename_.find(".raw") == std::string::npos) {
@@ -188,52 +250,6 @@ void AudioRecord::stopRecording()
     recordingEnabled_ = false;
 }
 
-void AudioRecord::createFilename()
-{
-    time_t rawtime = time(NULL);
-    struct tm * timeinfo = localtime(&rawtime);
-
-    std::stringstream out;
-
-    // DATE
-    out << timeinfo->tm_year + 1900;
-
-    if (timeinfo->tm_mon < 9) // january is 01, not 1
-        out << 0;
-
-    out << timeinfo->tm_mon+1;
-
-    if (timeinfo->tm_mday < 10) // 01 02 03, not 1 2 3
-        out << 0;
-
-    out << timeinfo->tm_mday;
-
-    out << '-';
-
-    // hour
-    if (timeinfo->tm_hour < 10) // 01 02 03, not 1 2 3
-        out << 0;
-
-    out << timeinfo->tm_hour;
-
-    out << ':';
-
-    if (timeinfo->tm_min < 10) // 01 02 03, not 1 2 3
-        out << 0;
-
-    out << timeinfo->tm_min;
-
-    out << ':';
-
-    if (timeinfo->tm_sec < 10) // 01 02 03,  not 1 2 3
-        out << 0;
-
-    out << timeinfo->tm_sec;
-    filename_ = out.str();
-
-    DEBUG("Generate filename for this call %s ", filename_.c_str());
-}
-
 bool AudioRecord::setRawFile()
 {
     fileHandle_ = fopen(savePath_.c_str(), "wb");
@@ -370,7 +386,9 @@ void AudioRecord::closeWavFile()
 
     SINT32 bytes = byteCounter_ * channels_;
 
-    fseek(fileHandle_, 40, SEEK_SET);  // jump to data length
+    // jump to data length
+    if (fseek(fileHandle_, 40, SEEK_SET) != 0)
+        WARN("Could not seek in file");
 
     if (ferror(fileHandle_))
         WARN("Can't reach offset 40 while closing");
@@ -382,7 +400,9 @@ void AudioRecord::closeWavFile()
 
     bytes = byteCounter_ * channels_ + 44; // + 44 for the wave header
 
-    fseek(fileHandle_, 4, SEEK_SET);  // jump to file size
+    // jump to file size
+    if (fseek(fileHandle_, 4, SEEK_SET) != 0)
+        WARN("Could not seek in file");
 
     if (ferror(fileHandle_))
         WARN("Can't reach offset 4");
