@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 2004, 2005, 2006, 2008, 2009, 2010, 2011 Savoir-Faire Linux Inc.
+ *  Copyright (C) 2004-2012 Savoir-Faire Linux Inc.
  *  Author: Pierre-Luc Bacon <pierre-luc.bacon@savoirfairelinux.com>
  *  Author: Alexandre Savard <alexandre.savard@savoirfairelinux.com>
  *
@@ -14,7 +14,7 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301 USA.
  *
  *  Additional permission under GNU GPL version 3 section 7:
  *
@@ -28,6 +28,10 @@
  *  as that of the covered work.
  */
 
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
+
 #include "audio_rtp_factory.h"
 #if HAVE_ZRTP
 #include "audio_zrtp_session.h"
@@ -38,8 +42,8 @@
 #include "sip/sipcall.h"
 #include "sip/sipaccount.h"
 #include "sip/sdes_negotiator.h"
+#include "scoped_lock.h"
 #include "logger.h"
-#include "config.h"
 
 namespace sfl {
 
@@ -51,11 +55,14 @@ AudioRtpFactory::AudioRtpFactory(SIPCall *ca) : rtpSession_(NULL),
     cachedRemoteMasterSalt_(MAX_MASTER_SALT_LENGTH),
     remoteOfferIsSet_(false), ca_(ca),
     keyExchangeProtocol_(NONE)
-{}
+{
+    pthread_mutex_init(&audioRtpThreadMutex_, NULL);
+}
 
 AudioRtpFactory::~AudioRtpFactory()
 {
     delete rtpSession_;
+    pthread_mutex_destroy(&audioRtpThreadMutex_);
 }
 
 void AudioRtpFactory::initConfig()
@@ -64,9 +71,9 @@ void AudioRtpFactory::initConfig()
     if (rtpSession_ != NULL)
         stop();
 
-    std::string accountId(Manager::instance().getAccountFromCall(ca_->getCallId()));
+    const std::string accountId(ca_->getAccountId());
 
-    SIPAccount *account = dynamic_cast<SIPAccount *>(Manager::instance().getAccount(accountId));
+    SIPAccount *account = Manager::instance().getSipAccount(accountId);
 
     if (account) {
         srtpEnabled_ = account->getSrtpEnabled();
@@ -93,8 +100,7 @@ void AudioRtpFactory::initConfig()
 
 void AudioRtpFactory::initSession()
 {
-    DEBUG("AudioRtpFactory: init session2");
-    ost::MutexLock m(audioRtpThreadMutex_);
+    ScopedLock m(audioRtpThreadMutex_);
 
     if (srtpEnabled_) {
         const std::string zidFilename(Manager::instance().voipPreferences.getZidFile());
@@ -120,18 +126,23 @@ void AudioRtpFactory::initSession()
         rtpSession_ = new AudioSymmetricRtpSession(*ca_);
 }
 
-void sfl::AudioRtpFactory::start(AudioCodec* audiocodec)
+std::vector<long>
+AudioRtpFactory::getSocketDescriptors() const
+{
+    return rtpSession_->getSocketDescriptors();
+}
+
+void AudioRtpFactory::start(const std::vector<AudioCodec*> &audioCodecs)
 {
     if (rtpSession_ == NULL)
         throw AudioRtpFactoryException("RTP session was null when trying to start audio thread");
 
-    if (rtpSession_->startRtpThread(*audiocodec) != 0)
-        throw AudioRtpFactoryException("Failed to start AudioRtpSession thread");
+    rtpSession_->startRtpThreads(audioCodecs);
 }
 
 void AudioRtpFactory::stop()
 {
-    ost::MutexLock mutex(audioRtpThreadMutex_);
+    ScopedLock mutex(audioRtpThreadMutex_);
 
     delete rtpSession_;
     rtpSession_ = NULL;
@@ -142,15 +153,24 @@ int AudioRtpFactory::getSessionMedia()
     if (rtpSession_ == NULL)
         throw AudioRtpFactoryException("RTP session was null when trying to get session media type");
 
-    return rtpSession_->getCodecPayloadType();
+    return rtpSession_->getEncoderPayloadType();
 }
 
-void AudioRtpFactory::updateSessionMedia(AudioCodec *audiocodec)
+std::string
+AudioRtpFactory::getCurrentAudioCodecNames() const
+{
+    if (rtpSession_ == NULL)
+        throw AudioRtpFactoryException("RTP session was null when trying to get session media type");
+
+    return rtpSession_->getCurrentAudioCodecNames();
+}
+
+void AudioRtpFactory::updateSessionMedia(const std::vector<AudioCodec*> &audioCodecs)
 {
     if (rtpSession_ == NULL)
         throw AudioRtpFactoryException("rtpSession_ was NULL when trying to update IP address");
 
-    rtpSession_->updateSessionMedia(*audiocodec);
+    rtpSession_->updateSessionMedia(audioCodecs);
 }
 
 void AudioRtpFactory::updateDestinationIpAddress()
@@ -160,7 +180,7 @@ void AudioRtpFactory::updateDestinationIpAddress()
 }
 
 #if HAVE_ZRTP
-sfl::AudioZrtpSession * AudioRtpFactory::getAudioZrtpSession()
+AudioZrtpSession * AudioRtpFactory::getAudioZrtpSession()
 {
     if (keyExchangeProtocol_ == ZRTP)
         return static_cast<AudioZrtpSession *>(rtpSession_);
@@ -169,7 +189,7 @@ sfl::AudioZrtpSession * AudioRtpFactory::getAudioZrtpSession()
 }
 #endif
 
-void sfl::AudioRtpFactory::initLocalCryptoInfo()
+void AudioRtpFactory::initLocalCryptoInfo()
 {
     DEBUG("AudioRtpFactory: Init local crypto info");
     if (rtpSession_ && keyExchangeProtocol_ == SDES) {
@@ -180,7 +200,7 @@ void sfl::AudioRtpFactory::initLocalCryptoInfo()
     }
 }
 
-void sfl::AudioRtpFactory::initLocalCryptoInfoOnOffHold()
+void AudioRtpFactory::initLocalCryptoInfoOnOffHold()
 {
     DEBUG("AudioRtpFactory: Init local crypto info");
     if (rtpSession_ && keyExchangeProtocol_ == SDES) {
@@ -192,13 +212,17 @@ void sfl::AudioRtpFactory::initLocalCryptoInfoOnOffHold()
 }
 
 
-void AudioRtpFactory::setRemoteCryptoInfo(sfl::SdesNegotiator& nego)
+void AudioRtpFactory::setRemoteCryptoInfo(SdesNegotiator& nego)
 {
-    if (rtpSession_ and keyExchangeProtocol_ == SDES) {
-        AudioSrtpSession *srtp = static_cast<AudioSrtpSession *>(rtpSession_);
-        srtp->setRemoteCryptoInfo(nego);
+    if (rtpSession_ ) {
+        if (keyExchangeProtocol_ == SDES) {
+            AudioSrtpSession *srtp = static_cast<AudioSrtpSession *>(rtpSession_);
+            srtp->setRemoteCryptoInfo(nego);
+        } else {
+            ERROR("Should not store remote crypto info for non-SDES sessions");
+        }
     } else
-        throw AudioRtpFactoryException("RTP: Error: rtpSession_ is NULL in setRemoteCryptoInfo");
+        throw AudioRtpFactoryException("rtpSession_ is NULL in setRemoteCryptoInfo");
 }
 
 void AudioRtpFactory::setDtmfPayloadType(unsigned int payloadType)
@@ -209,26 +233,23 @@ void AudioRtpFactory::setDtmfPayloadType(unsigned int payloadType)
 
 void AudioRtpFactory::sendDtmfDigit(int digit)
 {
-    rtpSession_->putDtmfEvent(digit);
+    if (rtpSession_)
+        rtpSession_->putDtmfEvent(digit);
 }
 
-void sfl::AudioRtpFactory::saveLocalContext()
+void AudioRtpFactory::saveLocalContext()
 {
     if (rtpSession_ and keyExchangeProtocol_ == SDES) {
-        AudioSrtpSession *srtp = dynamic_cast<AudioSrtpSession *>(rtpSession_);
-        assert(srtp);
-        cachedLocalMasterKey_ = srtp->getLocalMasterKey();
-        cachedLocalMasterSalt_ = srtp->getLocalMasterSalt();
+        cachedLocalMasterKey_ = rtpSession_->getLocalMasterKey();
+        cachedLocalMasterSalt_ = rtpSession_->getLocalMasterSalt();
     }
 }
 
-void sfl::AudioRtpFactory::restoreLocalContext()
+void AudioRtpFactory::restoreLocalContext()
 {
     if (rtpSession_ and keyExchangeProtocol_ == SDES) {
-        AudioSrtpSession *srtp = dynamic_cast<AudioSrtpSession *>(rtpSession_);
-        assert(srtp);
-        srtp->setLocalMasterKey(cachedLocalMasterKey_);
-        srtp->setLocalMasterSalt(cachedLocalMasterSalt_);
+        rtpSession_->setLocalMasterKey(cachedLocalMasterKey_);
+        rtpSession_->setLocalMasterSalt(cachedLocalMasterSalt_);
     }
 }
 }
