@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 2004, 2005, 2006, 2008, 2009, 2010, 2011 Savoir-Faire Linux Inc.
+ *  Copyright (C) 2004-2012 Savoir-Faire Linux Inc.
  *  Author: Alexandre Savard <alexandre.savard@savoirfairelinux.com>
  *
  *  This program is free software; you can redistribute it and/or modify
@@ -13,7 +13,7 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301 USA.
  *
  *  Additional permission under GNU GPL version 3 section 7:
  *
@@ -34,14 +34,12 @@
 #include "audio_rtp_record_handler.h"
 #include <fstream>
 #include <algorithm>
-
 #include "logger.h"
 #include "sip/sipcall.h"
 #include "audio/audiolayer.h"
+#include "scoped_lock.h"
 #include "manager.h"
 
-#include <fstream>
-
 namespace sfl {
 
 #ifdef RECTODISK
@@ -49,8 +47,37 @@ std::ofstream rtpResampled ("testRtpOutputResampled.raw", std::ifstream::binary)
 std::ofstream rtpNotResampled("testRtpOutput.raw", std::ifstream::binary);
 #endif
 
-DTMFEvent::DTMFEvent(int digit) : payload(), newevent(true), length(1000)
+DTMFEvent::DTMFEvent(char digit) : payload(), newevent(true), length(1000)
 {
+/*
+   From RFC2833:
+
+   Event  encoding (decimal)
+   _________________________
+   0--9                0--9
+   *                     10
+   #                     11
+   A--D              12--15
+   Flash                 16
+*/
+
+    switch (digit) {
+        case '*':
+            digit = 10;
+            break;
+        case '#':
+            digit = 11;
+            break;
+        case 'A' ... 'D':
+            digit = digit - 'A' + 12;
+            break;
+        case '0' ... '9':
+            digit = digit - '0';
+            break;
+        default:
+            ERROR("Unexpected DTMF %c", digit);
+    }
+
     payload.event = digit;
     payload.ebit = false; // end of event bit
     payload.rbit = false; // reserved bit
@@ -61,9 +88,10 @@ AudioRtpRecord::AudioRtpRecord() :
       callId_("")
     , codecSampleRate_(0)
     , dtmfQueue_()
-    , audioCodec_(0)
+    , audioCodecs_()
     , audioCodecMutex_()
-    , codecPayloadType_(0)
+    , encoderPayloadType_(0)
+    , decoderPayloadType_(0)
     , hasDynamicPayloadType_(false)
     , decData_()     // std::tr1::arrays will be 0-initialized
     , resampledData_()
@@ -80,7 +108,13 @@ AudioRtpRecord::AudioRtpRecord() :
 #endif
     , dtmfPayloadType_(101) // same as Asterisk
     , dead_(false)
-{}
+    , currentCodecIndex_(0)
+{
+    pthread_mutex_init(&audioCodecMutex_, NULL);
+#if HAVE_SPEEXDSP
+    pthread_mutex_init(&audioProcessMutex_, NULL);
+#endif
+}
 
 // Call from processData*
 bool AudioRtpRecord::isDead()
@@ -92,6 +126,41 @@ bool AudioRtpRecord::isDead()
 #endif
 }
 
+sfl::AudioCodec *
+AudioRtpRecord::getCurrentCodec() const
+{
+    if (audioCodecs_.empty() or currentCodecIndex_ >= audioCodecs_.size()) {
+        ERROR("No codec found");
+        return 0;
+    }
+    return audioCodecs_[currentCodecIndex_];
+}
+
+void
+AudioRtpRecord::deleteCodecs()
+{
+    for (std::vector<AudioCodec *>::iterator i = audioCodecs_.begin(); i != audioCodecs_.end(); ++i)
+        delete *i;
+    audioCodecs_.clear();
+}
+
+bool AudioRtpRecord::tryToSwitchPayloadTypes(int newPt)
+{
+    for (std::vector<AudioCodec *>::iterator i = audioCodecs_.begin(); i != audioCodecs_.end(); ++i)
+        if (*i and (*i)->getPayloadType() == newPt) {
+            decoderPayloadType_ = (*i)->getPayloadType();
+            codecSampleRate_ = (*i)->getClockRate();
+            codecFrameSize_ = (*i)->getFrameSize();
+            hasDynamicPayloadType_ = (*i)->hasDynamicPayload();
+            currentCodecIndex_ = std::distance(audioCodecs_.begin(), i);
+            DEBUG("Switched payload type to %d", newPt);
+            return true;
+        }
+
+    ERROR("Could not switch payload types");
+    return false;
+}
+
 AudioRtpRecord::~AudioRtpRecord()
 {
     dead_ = true;
@@ -105,18 +174,22 @@ AudioRtpRecord::~AudioRtpRecord()
     delete converterDecode_;
     converterDecode_ = 0;
     {
-        ost::MutexLock lock(audioCodecMutex_);
-        delete audioCodec_;
-        audioCodec_ = 0;
+        ScopedLock lock(audioCodecMutex_);
+        deleteCodecs();
     }
 #if HAVE_SPEEXDSP
     {
-        ost::MutexLock lock(audioProcessMutex_);
+        ScopedLock lock(audioProcessMutex_);
         delete noiseSuppressDecode_;
         noiseSuppressDecode_ = 0;
         delete noiseSuppressEncode_;
         noiseSuppressEncode_ = 0;
     }
+#endif
+    pthread_mutex_destroy(&audioCodecMutex_);
+
+#if HAVE_SPEEXDSP
+    pthread_mutex_destroy(&audioProcessMutex_);
 #endif
 }
 
@@ -124,23 +197,48 @@ AudioRtpRecord::~AudioRtpRecord()
 AudioRtpRecordHandler::AudioRtpRecordHandler(SIPCall &call) :
     audioRtpRecord_(),
     id_(call.getCallId()),
-    gainController(8000, -10.0)
+    gainController(8000, -10.0),
+    warningInterval_(0)
 {}
 
 
 AudioRtpRecordHandler::~AudioRtpRecordHandler() {}
 
-void AudioRtpRecordHandler::setRtpMedia(AudioCodec *audioCodec)
+std::string
+AudioRtpRecordHandler::getCurrentAudioCodecNames()
 {
-    ost::MutexLock lock(audioRtpRecord_.audioCodecMutex_);
+    std::string result;
+    ScopedLock lock(audioRtpRecord_.audioCodecMutex_);
+    {
+        std::string sep = "";
+        for (std::vector<AudioCodec*>::const_iterator i = audioRtpRecord_.audioCodecs_.begin();
+                i != audioRtpRecord_.audioCodecs_.end(); ++i) {
+            if (*i)
+                result += sep + (*i)->getMimeSubtype();
+            sep = " ";
+        }
+    }
 
-    delete audioRtpRecord_.audioCodec_;
-    // Set varios codec info to reduce indirection
-    audioRtpRecord_.audioCodec_ = audioCodec;
-    audioRtpRecord_.codecPayloadType_ = audioCodec->getPayloadType();
-    audioRtpRecord_.codecSampleRate_ = audioCodec->getClockRate();
-    audioRtpRecord_.codecFrameSize_ = audioCodec->getFrameSize();
-    audioRtpRecord_.hasDynamicPayloadType_ = audioCodec->hasDynamicPayload();
+    return result;
+}
+
+void AudioRtpRecordHandler::setRtpMedia(const std::vector<AudioCodec*> &audioCodecs)
+{
+    ScopedLock lock(audioRtpRecord_.audioCodecMutex_);
+
+    audioRtpRecord_.deleteCodecs();
+    // Set various codec info to reduce indirection
+    audioRtpRecord_.audioCodecs_ = audioCodecs;
+    if (audioCodecs.empty()) {
+        ERROR("Audio codecs empty");
+        return;
+    }
+
+    audioRtpRecord_.currentCodecIndex_ = 0;
+    audioRtpRecord_.encoderPayloadType_ = audioRtpRecord_.decoderPayloadType_ = audioCodecs[0]->getPayloadType();
+    audioRtpRecord_.codecSampleRate_ = audioCodecs[0]->getClockRate();
+    audioRtpRecord_.codecFrameSize_ = audioCodecs[0]->getFrameSize();
+    audioRtpRecord_.hasDynamicPayloadType_ = audioCodecs[0]->hasDynamicPayload();
 }
 
 void AudioRtpRecordHandler::initBuffers()
@@ -159,7 +257,7 @@ void AudioRtpRecordHandler::initBuffers()
 #if HAVE_SPEEXDSP
 void AudioRtpRecordHandler::initNoiseSuppress()
 {
-    ost::MutexLock lock(audioRtpRecord_.audioProcessMutex_);
+    ScopedLock lock(audioRtpRecord_.audioProcessMutex_);
     delete audioRtpRecord_.noiseSuppressEncode_;
     audioRtpRecord_.noiseSuppressEncode_ = new NoiseSuppress(getCodecFrameSize(), getCodecSampleRate());
     delete audioRtpRecord_.noiseSuppressDecode_;
@@ -167,7 +265,7 @@ void AudioRtpRecordHandler::initNoiseSuppress()
 }
 #endif
 
-void AudioRtpRecordHandler::putDtmfEvent(int digit)
+void AudioRtpRecordHandler::putDtmfEvent(char digit)
 {
     DTMFEvent dtmf(digit);
     audioRtpRecord_.dtmfQueue_.push_back(dtmf);
@@ -181,7 +279,7 @@ int AudioRtpRecordHandler::processDataEncode()
         return 0;
 
     int codecSampleRate = getCodecSampleRate();
-    int mainBufferSampleRate = Manager::instance().getMainBuffer()->getInternalSamplingRate();
+    int mainBufferSampleRate = Manager::instance().getMainBuffer().getInternalSamplingRate();
 
     double resampleFactor = (double) mainBufferSampleRate / codecSampleRate;
 
@@ -189,11 +287,11 @@ int AudioRtpRecordHandler::processDataEncode()
     int samplesToGet = resampleFactor * getCodecFrameSize();
     const size_t bytesToGet = samplesToGet * sizeof(SFLDataFormat);
 
-    if (Manager::instance().getMainBuffer()->availableForGet(id_) < bytesToGet)
+    if (Manager::instance().getMainBuffer().availableForGet(id_) < bytesToGet)
         return 0;
 
     SFLDataFormat *micData = audioRtpRecord_.decData_.data();
-    const size_t bytes = Manager::instance().getMainBuffer()->getData(micData, bytesToGet, id_);
+    const size_t bytes = Manager::instance().getMainBuffer().getData(micData, bytesToGet, id_);
 
 #ifdef RECTODISK
     rtpNotResampled.write((const char *)micData, bytes);
@@ -228,17 +326,17 @@ int AudioRtpRecordHandler::processDataEncode()
 
 #if HAVE_SPEEXDSP
     if (Manager::instance().audioPreference.getNoiseReduce()) {
-        ost::MutexLock lock(audioRtpRecord_.audioProcessMutex_);
+        ScopedLock lock(audioRtpRecord_.audioProcessMutex_);
         RETURN_IF_NULL(audioRtpRecord_.noiseSuppressEncode_, 0, "Noise suppressor already destroyed");
         audioRtpRecord_.noiseSuppressEncode_->process(micData, getCodecFrameSize());
     }
 #endif
 
     {
-        ost::MutexLock lock(audioRtpRecord_.audioCodecMutex_);
-        RETURN_IF_NULL(audioRtpRecord_.audioCodec_, 0, "Audio codec already destroyed");
+        ScopedLock lock(audioRtpRecord_.audioCodecMutex_);
+        RETURN_IF_NULL(audioRtpRecord_.getCurrentCodec(), 0, "Audio codec already destroyed");
         unsigned char *micDataEncoded = audioRtpRecord_.encodedData_.data();
-        return audioRtpRecord_.audioCodec_->encode(micDataEncoded, out, getCodecFrameSize());
+        return audioRtpRecord_.getCurrentCodec()->encode(micDataEncoded, out, getCodecFrameSize());
     }
 }
 #undef RETURN_IF_NULL
@@ -247,22 +345,33 @@ int AudioRtpRecordHandler::processDataEncode()
 
 void AudioRtpRecordHandler::processDataDecode(unsigned char *spkrData, size_t size, int payloadType)
 {
-    if (audioRtpRecord_.isDead() or getCodecPayloadType() != payloadType)
+    if (audioRtpRecord_.isDead())
         return;
+    if (audioRtpRecord_.decoderPayloadType_ != payloadType) {
+        const bool switched = audioRtpRecord_.tryToSwitchPayloadTypes(payloadType);
+        if (not switched) {
+            if (!warningInterval_) {
+                warningInterval_ = 250;
+                WARN("Invalid payload type %d, expected %d", payloadType, audioRtpRecord_.decoderPayloadType_);
+            }
+            warningInterval_--;
+            return;
+        }
+    }
 
     int inSamples = 0;
     size = std::min(size, audioRtpRecord_.decData_.size());
     SFLDataFormat *spkrDataDecoded = audioRtpRecord_.decData_.data();
     {
-        ost::MutexLock lock(audioRtpRecord_.audioCodecMutex_);
-        RETURN_IF_NULL(audioRtpRecord_.audioCodec_, "Audio codec already destroyed");
+        ScopedLock lock(audioRtpRecord_.audioCodecMutex_);
+        RETURN_IF_NULL(audioRtpRecord_.getCurrentCodec(), "Audio codecs already destroyed");
         // Return the size of data in samples
-        inSamples = audioRtpRecord_.audioCodec_->decode(spkrDataDecoded, spkrData, size);
+        inSamples = audioRtpRecord_.getCurrentCodec()->decode(spkrDataDecoded, spkrData, size);
     }
 
 #if HAVE_SPEEXDSP
     if (Manager::instance().audioPreference.getNoiseReduce()) {
-        ost::MutexLock lock(audioRtpRecord_.audioProcessMutex_);
+        ScopedLock lock(audioRtpRecord_.audioProcessMutex_);
         RETURN_IF_NULL(audioRtpRecord_.noiseSuppressDecode_, "Noise suppressor already destroyed");
         audioRtpRecord_.noiseSuppressDecode_->process(spkrDataDecoded, getCodecFrameSize());
     }
@@ -277,7 +386,7 @@ void AudioRtpRecordHandler::processDataDecode(unsigned char *spkrData, size_t si
     int outSamples = inSamples;
 
     int codecSampleRate = getCodecSampleRate();
-    int mainBufferSampleRate = Manager::instance().getMainBuffer()->getInternalSamplingRate();
+    int mainBufferSampleRate = Manager::instance().getMainBuffer().getInternalSamplingRate();
 
     // test if resampling is required
     if (codecSampleRate != mainBufferSampleRate) {
@@ -290,7 +399,7 @@ void AudioRtpRecordHandler::processDataDecode(unsigned char *spkrData, size_t si
                 mainBufferSampleRate, inSamples);
     }
 
-    Manager::instance().getMainBuffer()->putData(out, outSamples * sizeof(SFLDataFormat), id_);
+    Manager::instance().getMainBuffer().putData(out, outSamples * sizeof(SFLDataFormat), id_);
 }
 #undef RETURN_IF_NULL
 
@@ -300,11 +409,30 @@ void AudioRtpRecord::fadeInDecodedData(size_t size)
     if (fadeFactor_ >= 1.0 or size > decData_.size())
         return;
 
-    std::transform(decData_.begin(), decData_.begin() + size, decData_.begin(),
-            std::bind1st(std::multiplies<double>(), fadeFactor_));
+    for (size_t i = 0; i < size; ++i)
+        decData_[i] *= fadeFactor_;
 
     // Factor used to increase volume in fade in
     const double FADEIN_STEP_SIZE = 4.0;
     fadeFactor_ *= FADEIN_STEP_SIZE;
 }
+
+bool
+AudioRtpRecordHandler::codecsDiffer(const std::vector<AudioCodec*> &codecs) const
+{
+    const std::vector<AudioCodec*> &current = audioRtpRecord_.audioCodecs_;
+    if (codecs.size() != current.size())
+        return true;
+    for (std::vector<AudioCodec*>::const_iterator i = codecs.begin(); i != codecs.end(); ++i) {
+        if (*i) {
+            bool matched = false;
+            for (std::vector<AudioCodec*>::const_iterator j = current.begin(); !matched and j != current.end(); ++j)
+                matched = (*i)->getPayloadType() == (*j)->getPayloadType();
+            if (not matched)
+                return true;
+        }
+    }
+    return false;
+}
+
 }
