@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 2004, 2005, 2006, 2008, 2009, 2010, 2011 Savoir-Faire Linux Inc.
+ *  Copyright (C) 2004-2012 Savoir-Faire Linux Inc.
  *  Author: Pierre-Luc Bacon <pierre-luc.bacon@savoirfairelinux.com>
  *  Author: Alexandre Bourget <alexandre.bourget@savoirfairelinux.com>
  *  Author: Laurielle Lea <laurielle.lea@savoirfairelinux.com>
@@ -18,7 +18,7 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301 USA.
  *
  *  Additional permission under GNU GPL version 3 section 7:
  *
@@ -40,17 +40,18 @@
 #include "manager.h"
 
 namespace sfl {
-AudioRtpSession::AudioRtpSession(SIPCall &call, ost::RTPDataQueue &queue, ost::Thread &thread) :
+AudioRtpSession::AudioRtpSession(SIPCall &call, ost::RTPDataQueue &queue) :
     AudioRtpRecordHandler(call)
+    , isStarted_(false)
+    , queue_(queue)
     , call_(call)
     , timestamp_(0)
     , timestampIncrement_(0)
-    , queue_(queue)
-    , isStarted_(false)
+    , transportRate_(20)
     , remote_ip_()
     , remote_port_(0)
     , timestampCount_(0)
-    , thread_(thread)
+    , rtpSendThread_(*this)
 {
     queue_.setTypeOfService(ost::RTPDataQueue::tosEnhanced);
 }
@@ -60,11 +61,12 @@ AudioRtpSession::~AudioRtpSession()
     queue_.disableStack();
 }
 
-void AudioRtpSession::updateSessionMedia(AudioCodec &audioCodec)
+void AudioRtpSession::updateSessionMedia(const std::vector<AudioCodec*> &audioCodecs)
 {
     int lastSamplingRate = audioRtpRecord_.codecSampleRate_;
 
-    setSessionMedia(audioCodec);
+    if (codecsDiffer(audioCodecs))
+        setSessionMedia(audioCodecs);
 
     Manager::instance().audioSamplingRateChanged(audioRtpRecord_.codecSampleRate_);
 
@@ -77,12 +79,12 @@ void AudioRtpSession::updateSessionMedia(AudioCodec &audioCodec)
 #endif
 }
 
-void AudioRtpSession::setSessionMedia(AudioCodec &audioCodec)
+void AudioRtpSession::setSessionMedia(const std::vector<AudioCodec*> &audioCodecs)
 {
-    setRtpMedia(&audioCodec);
+    setRtpMedia(audioCodecs);
 
     // G722 requires timestamp to be incremented at 8kHz
-    const ost::PayloadType payloadType = getCodecPayloadType();
+    const ost::PayloadType payloadType = getEncoderPayloadType();
     if (payloadType == ost::sptG722) {
         const int G722_RTP_TIME_INCREMENT = 160;
         timestampIncrement_ = G722_RTP_TIME_INCREMENT;
@@ -98,6 +100,12 @@ void AudioRtpSession::setSessionMedia(AudioCodec &audioCodec)
         else
             queue_.setPayloadFormat(ost::StaticPayloadFormat(static_cast<ost::StaticPayloadType>(payloadType)));
     }
+
+    call_.setRecordingSmplRate(getCodecSampleRate());
+
+    int transportRate = getCodecFrameSize() / (getCodecSampleRate() / 1000);
+    transportRate_ = (transportRate > 0)?transportRate:20;
+    DEBUG("Switching to a transport rate of %d ms",transportRate_);
 }
 
 void AudioRtpSession::sendDtmfEvent()
@@ -126,7 +134,7 @@ void AudioRtpSession::sendDtmfEvent()
     }
 
     // restore the payload to audio
-    const ost::StaticPayloadFormat pf(static_cast<ost::StaticPayloadType>(getCodecPayloadType()));
+    const ost::StaticPayloadFormat pf(static_cast<ost::StaticPayloadType>(getEncoderPayloadType()));
     queue_.setPayloadFormat(pf);
 
     // decrease length remaining to process for this event
@@ -215,7 +223,7 @@ void AudioRtpSession::updateDestinationIpAddress()
     // Destination address are stored in a list in ccrtp
     // This method remove the current destination entry
 
-    if (!queue_.forgetDestination(remote_ip_, remote_port_, remote_port_ + 1))
+    if (!queue_.forgetDestination(remote_ip_, remote_port_))
         DEBUG("Did not remove previous destination");
 
     // new destination is stored in call
@@ -224,24 +232,18 @@ void AudioRtpSession::updateDestinationIpAddress()
 }
 
 
-int AudioRtpSession::startRtpThread(AudioCodec &audiocodec)
+void AudioRtpSession::prepareRtpReceiveThread(const std::vector<AudioCodec*> &audioCodecs)
 {
-    if (isStarted_)
-        return 0;
-
-    DEBUG("Starting main thread");
-
+    DEBUG("Preparing receiving thread");
     isStarted_ = true;
     setSessionTimeouts();
-    setSessionMedia(audiocodec);
+    setSessionMedia(audioCodecs);
     initBuffers();
 #if HAVE_SPEEXDSP
     initNoiseSuppress();
 #endif
 
     queue_.enableStack();
-    thread_.start();
-    return 0;
 }
 
 
@@ -256,4 +258,63 @@ int AudioRtpSession::getIncrementForDTMF() const
     return timestampIncrement_;
 }
 
+void AudioRtpSession::startRtpThreads(const std::vector<AudioCodec*> &audioCodecs)
+{
+    if (isStarted_)
+        return;
+
+    prepareRtpReceiveThread(audioCodecs);
+    // implemented in subclasses
+    startReceiveThread();
+    startSendThread();
+}
+
+AudioRtpSession::AudioRtpSendThread::AudioRtpSendThread(AudioRtpSession &session) :
+    running_(false), rtpSession_(session), thread_(0), timer_()
+{}
+
+AudioRtpSession::AudioRtpSendThread::~AudioRtpSendThread()
+{
+    running_ = false;
+    if (thread_)
+        pthread_join(thread_, NULL);
+}
+
+void AudioRtpSession::AudioRtpSendThread::start()
+{
+    running_ = true;
+    pthread_create(&thread_, NULL, &runCallback, this);
+}
+
+void *
+AudioRtpSession::AudioRtpSendThread::runCallback(void *data)
+{
+    AudioRtpSession::AudioRtpSendThread *context = static_cast<AudioRtpSession::AudioRtpSendThread*>(data);
+    context->run();
+    return NULL;
+}
+
+void AudioRtpSession::AudioRtpSendThread::run()
+{
+    timer_.setTimer(rtpSession_.transportRate_);
+    const int MS_TO_USEC = 1000;
+
+    while (running_) {
+        // Send session
+        if (rtpSession_.hasDTMFPending())
+            rtpSession_.sendDtmfEvent();
+        else
+            rtpSession_.sendMicData();
+
+        usleep(timer_.getTimer() * MS_TO_USEC);
+
+        timer_.incTimer(rtpSession_.transportRate_);
+    }
+}
+
+
+void AudioRtpSession::startSendThread()
+{
+    rtpSendThread_.start();
+}
 }
