@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 2004, 2005, 2006, 2008, 2009, 2010, 2011 Savoir-Faire Linux Inc.
+ *  Copyright (C) 2004-2012 Savoir-Faire Linux Inc.
  *  Author: Pierre-Luc Bacon <pierre-luc.bacon@savoirfairelinux.com>
  *  Author: Alexandre Bourget <alexandre.bourget@savoirfairelinux.com>
  *  Author: Laurielle Lea <laurielle.lea@savoirfairelinux.com>
@@ -18,7 +18,7 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301 USA.
  *
  *  Additional permission under GNU GPL version 3 section 7:
  *
@@ -38,6 +38,7 @@
 #include <cassert>
 #include <cstddef>
 
+#include "global.h"
 #include "audio_rtp_session.h"
 #include "noncopyable.h"
 
@@ -52,43 +53,35 @@ class SIPCall;
 
 namespace sfl {
 
-class AudioSymmetricRtpSession : public ost::TimerPort, public ost::SymmetricRTPSession, public AudioRtpSession {
+class AudioSymmetricRtpSession : public ost::SymmetricRTPSession, public AudioRtpSession {
     public:
         /**
         * Constructor
         * @param call The SIP call
         */
         AudioSymmetricRtpSession(SIPCall &call);
-        ~AudioSymmetricRtpSession();
+
+        std::vector<long>
+        getSocketDescriptors() const;
 
         virtual bool onRTPPacketRecv(ost::IncomingRTPPkt& pkt) {
             return AudioRtpSession::onRTPPacketRecv(pkt);
         }
 
-        int startSymmetricRtpThread() {
-            rtpThread_.start();
-            return 0;
-        }
+        virtual void setLocalMasterKey(const std::vector<uint8>& key UNUSED) {}
+
+        virtual void setLocalMasterSalt(const std::vector<uint8>& key UNUSED) {};
+
+        /** Not used for symmetric rtp session, return an empty vector */
+        virtual std::vector<uint8> getLocalMasterKey() const { std::vector<uint8> vec; return vec; }
+
+        /** Not used for symmetric rtp session, return an empty vector */
+        virtual std::vector<uint8> getLocalMasterSalt() const { std::vector<uint8> vec; return vec; }
 
     private:
         NON_COPYABLE(AudioSymmetricRtpSession);
 
-        class AudioRtpThread : public ost::Thread, public ost::TimerPort {
-            public:
-                AudioRtpThread(AudioSymmetricRtpSession &session);
-
-                virtual void run();
-
-                bool running_;
-
-            private:
-                NON_COPYABLE(AudioRtpThread);
-                AudioSymmetricRtpSession &rtpSession_;
-        };
-        void setSessionMedia(AudioCodec &codec);
-        int startRtpThread(AudioCodec &audiocodec);
-
-        AudioRtpThread rtpThread_;
+        void startReceiveThread();
 };
 
 }
