@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 2004, 2005, 2006, 2008, 2009, 2010, 2011 Savoir-Faire Linux Inc.
+ *  Copyright (C) 2004-2012 Savoir-Faire Linux Inc.
  *  Author: Alexandre Savard <alexandre.savard@savoirfairelinux.com>
  *  Author: Pierre-Luc Bacon <pierre-luc.bacon@savoirfairelinux.com>
  *
@@ -14,7 +14,7 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301 USA.
  *
  *  Additional permission under GNU GPL version 3 section 7:
  *
@@ -30,6 +30,7 @@
 #ifndef __AUDIO_ZRTP_SESSION_H__
 #define __AUDIO_ZRTP_SESSION_H__
 
+#pragma GCC diagnostic ignored "-Weffc++"
 #include <cstddef>
 #include <stdexcept>
 
@@ -39,8 +40,8 @@ using std::ptrdiff_t;
 #include <libzrtpcpp/ZrtpQueue.h>
 #include <libzrtpcpp/ZrtpUserCallback.h>
 
+#include "global.h"
 #include "audio_rtp_session.h"
-// #include <commoncpp/numbers.h> // OST::Time
 
 class SIPCall;
 class AudioCodec;
@@ -49,51 +50,39 @@ namespace sfl {
 
 class ZrtpZidException : public std::runtime_error {
     public:
-        ZrtpZidException(const std::string& str = "") :
-            std::runtime_error("ZRTP ZID initialization failed." + str) {}
+        ZrtpZidException(const char *str):
+            std::runtime_error(str) {}
 };
 
 class AudioZrtpSession :
-     public ost::TimerPort,
-    // public ost::TRTPSessionBase<ost::SymmetricRTPChannel, ost::SymmetricRTPChannel, ost::ZrtpQueue> {
     public ost::SymmetricZRTPSession,
     public AudioRtpSession {
     public:
         AudioZrtpSession(SIPCall &call, const std::string& zidFilename);
-        ~AudioZrtpSession();
 
-        int startZrtpThread() {
-            rtpThread_.start();
-            return 0;
-        }
+        std::vector<long>
+        getSocketDescriptors() const;
 
         virtual bool onRTPPacketRecv(ost::IncomingRTPPkt &pkt) {
             return AudioRtpSession::onRTPPacketRecv(pkt);
         }
 
+        virtual std::vector<uint8> getLocalMasterKey() const { std::vector<uint8> vec; return vec; }
+
+        virtual std::vector<uint8> getLocalMasterSalt() const { std::vector<uint8> vec; return vec; }
+
+        virtual void setLocalMasterKey(const std::vector<unsigned char>& vec UNUSED) {}
+
+        virtual void setLocalMasterSalt(const std::vector<unsigned char>& vec UNUSED) {}
+
     private:
         NON_COPYABLE(AudioZrtpSession);
 
-        class AudioZrtpThread : public ost::Thread, public ost::TimerPort {
-            public:
-                AudioZrtpThread(AudioZrtpSession &session);
-
-                virtual void run();
-
-                bool running_;
-
-            private:
-                NON_COPYABLE(AudioZrtpThread);
-                AudioZrtpSession &zrtpSession_;
-        };
         void sendMicData();
         void initializeZid();
         std::string zidFilename_;
-        void setSessionMedia(AudioCodec &codec);
-        int startRtpThread(AudioCodec &audiocodec);
+        void startReceiveThread();
         virtual int getIncrementForDTMF() const;
-
-        AudioZrtpThread rtpThread_;
 };
 
 }
