@@ -1,22 +1,22 @@
 /*
- * Copyright (C) 2004, 2005, 2006, 2008, 2009, 2010 Savoir-Faire Linux Inc.
- * Author:  Alexandre Savard <alexandre.savard@savoirfairelinux.com>
+ *  Copyright (C) 2004-2012 Savoir-Faire Linux Inc.
+ *  Author:  Alexandre Savard <alexandre.savard@savoirfairelinux.com>
  *
- * Mostly borrowed from asterisk's sources (Steve Underwood <steveu@coppice.org>)
+ *  Mostly borrowed from asterisk's sources (Steve Underwood <steveu@coppice.org>)
  *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 3 of the License, or
- * (at your option) any later version.
+ *  This program is free software; you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation; either version 3 of the License, or
+ *  (at your option) any later version.
  *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ *  This program is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
  *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ *  You should have received a copy of the GNU General Public License
+ *  along with this program; if not, write to the Free Software
+ *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301 USA.
  *
  *  Additional permission under GNU GPL version 3 section 7:
  *
@@ -43,7 +43,6 @@ AudioCodec::AudioCodec(uint8 payload, const std::string &codecName,
     channel_(channel),
     frameSize_(frameSize),
     bitrate_(0.0),
-    bandwidth_(0.0),
     payload_(payload),
     payloadFormat_(payload, clockRate_),
     hasDynamicPayload_((payload_ >= 96 and payload_ <= 127) or payload_ == 9)
@@ -55,7 +54,6 @@ AudioCodec::AudioCodec(const AudioCodec& c) :
     channel_(c.channel_),
     frameSize_(c.frameSize_),
     bitrate_(c.bitrate_),
-    bandwidth_(c.bandwidth_),
     payload_(c.payload_),
     payloadFormat_(c.payloadFormat_),
     hasDynamicPayload_(c.hasDynamicPayload_)
