@@ -1,22 +1,22 @@
 /*
- * Copyright (C) 2004, 2005, 2006, 2008, 2009, 2010 Savoir-Faire Linux Inc.
- * Author:  Alexandre Savard <alexandre.savard@savoirfairelinux.com>
+ *  Copyright (C) 2004-2012 Savoir-Faire Linux Inc.
+ *  Author:  Alexandre Savard <alexandre.savard@savoirfairelinux.com>
  *
- * Mostly borrowed from asterisk's sources (Steve Underwood <steveu@coppice.org>)
+ *  Mostly borrowed from asterisk's sources (Steve Underwood <steveu@coppice.org>)
  *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 3 of the License, or
- * (at your option) any later version.
+ *  This program is free software; you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation; either version 3 of the License, or
+ *  (at your option) any later version.
  *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ *  This program is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
  *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ *  You should have received a copy of the GNU General Public License
+ *  along with this program; if not, write to the Free Software
+ *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301 USA.
  *
  *  Additional permission under GNU GPL version 3 section 7:
  *
@@ -36,11 +36,12 @@
 #include "cc_config.h"
 #include <ccrtp/formats.h> // for ost::DynamicPayloadFormat
 
-#include "codec.h"
+#define XSTR(s) STR(s)
+#define STR(s) #s
 
 /* bump when codec binary interface changes */
-#define CODEC_ENTRY create_1_1_0
-#define CODEC_ENTRY_SYMBOL "create_1_1_0"
+#define AUDIO_CODEC_ENTRY create_1_2_3
+#define AUDIO_CODEC_ENTRY_SYMBOL XSTR(AUDIO_CODEC_ENTRY)
 
 // We assume all decoders will be fed 20ms of audio or less
 // And we'll resample them to 44.1kHz or less
@@ -49,7 +50,7 @@
 
 namespace sfl {
 
-class AudioCodec : public Codec {
+class AudioCodec {
     public:
         AudioCodec(uint8 payload, const std::string &codecName, int clockRate,
                    int frameSize, int channel);
@@ -61,9 +62,6 @@ class AudioCodec : public Codec {
 
         virtual ~AudioCodec() {};
 
-        /**
-         * @Override
-         */
         std::string getMimeSubtype() const;
 
         /**
@@ -80,14 +78,8 @@ class AudioCodec : public Codec {
          */
         virtual int encode(unsigned char *dst, short *src, size_t buffer_size) = 0;
 
-        /**
-         * @Override
-         */
-        uint8 getPayloadType() const ;
+        uint8 getPayloadType() const;
 
-        /**
-         * @Override
-         */
         void setPayloadType(uint8 pt) {
             payload_ = pt;
         }
@@ -97,14 +89,8 @@ class AudioCodec : public Codec {
          */
         bool hasDynamicPayload() const;
 
-        /**
-         * @Override
-         */
         uint32 getClockRate() const;
 
-        /**
-         * @Override
-         */
         double getBitRate() const;
 
         /**
@@ -128,9 +114,6 @@ class AudioCodec : public Codec {
         /** Bitrate */
         double bitrate_;
 
-        /** Bandwidth */
-        double bandwidth_;
-
     private:
         AudioCodec& operator=(const AudioCodec&);
         uint8 payload_;
@@ -142,4 +125,8 @@ protected:
 };
 } // end namespace sfl
 
+
+typedef sfl::AudioCodec* create_t();
+typedef void destroy_t(sfl::AudioCodec* codec);
+
 #endif
