@@ -1,9 +1,10 @@
 /*
- *  Copyright (C) 2004, 2005, 2006, 2008, 2009, 2010, 2011 Savoir-Faire Linux Inc.
+ *  Copyright (C) 2004-2012 Savoir-Faire Linux Inc.
  *  Author: Yan Morin <yan.morin@savoirfairelinux.com>
  *  Author: Laurielle Lea <laurielle.lea@savoirfairelinux.com>
  *  Author: Emmanuel Milou <emmanuel.milou@savoirfairelinux.com>
  *  Author: Alexandre Savard <alexandre.savard@savoirfairelinux.com>
+ *  Author: Emmanuel Lepage <emmanuel.lepage@savoirfairelinux.com>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -17,7 +18,7 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301 USA.
  *
  *  Additional permission under GNU GPL version 3 section 7:
  *
@@ -35,11 +36,13 @@
 #include "config.h"
 #endif
 
-#include "audiocodecfactory.h"
 #include <cstdlib>
 #include <dlfcn.h>
 #include <algorithm> // for std::find
 #include <dlfcn.h>
+
+#include "audiocodec.h"
+#include "audiocodecfactory.h"
 #include "fileutils.h"
 #include "array_size.h"
 #include "logger.h"
@@ -47,13 +50,13 @@
 AudioCodecFactory::AudioCodecFactory() :
     codecsMap_(), defaultCodecList_(), libCache_(), codecInMemory_()
 {
-    typedef std::vector<sfl::Codec*> CodecVector;
-    CodecVector codecDynamicList(scanCodecDirectory());
+    typedef std::vector<sfl::AudioCodec*> AudioCodecVector;
+    AudioCodecVector codecDynamicList(scanCodecDirectory());
 
     if (codecDynamicList.empty())
         ERROR("No codecs available");
     else {
-        for (CodecVector::const_iterator iter = codecDynamicList.begin();
+        for (AudioCodecVector::const_iterator iter = codecDynamicList.begin();
                 iter != codecDynamicList.end() ; ++iter) {
             codecsMap_[(int)(*iter)->getPayloadType()] = *iter;
             DEBUG("Loaded codec %s" , (*iter)->getMimeSubtype().c_str());
@@ -61,17 +64,18 @@ AudioCodecFactory::AudioCodecFactory() :
     }
 }
 
-void AudioCodecFactory::setDefaultOrder()
+void
+AudioCodecFactory::setDefaultOrder()
 {
     defaultCodecList_.clear();
-    for (CodecsMap::const_iterator i = codecsMap_.begin(); i != codecsMap_.end(); ++i)
+    for (AudioCodecsMap::const_iterator i = codecsMap_.begin(); i != codecsMap_.end(); ++i)
         defaultCodecList_.push_back(i->first);
 }
 
 std::string
 AudioCodecFactory::getCodecName(int payload) const
 {
-    CodecsMap::const_iterator iter = codecsMap_.find(payload);
+    AudioCodecsMap::const_iterator iter = codecsMap_.find(payload);
 
     if (iter != codecsMap_.end())
         return iter->second->getMimeSubtype();
@@ -80,32 +84,33 @@ AudioCodecFactory::getCodecName(int payload) const
 }
 
 std::vector<int32_t>
-AudioCodecFactory::getAudioCodecList() const
+AudioCodecFactory::getCodecList() const
 {
     std::vector<int32_t> list;
-    for (CodecsMap::const_iterator iter = codecsMap_.begin(); iter != codecsMap_.end(); ++iter)
+    for (AudioCodecsMap::const_iterator iter = codecsMap_.begin(); iter != codecsMap_.end(); ++iter)
         if (iter->second)
             list.push_back((int32_t) iter->first);
 
     return list;
 }
 
-sfl::Codec*
+sfl::AudioCodec*
 AudioCodecFactory::getCodec(int payload) const
 {
-    CodecsMap::const_iterator iter = codecsMap_.find(payload);
+    AudioCodecsMap::const_iterator iter = codecsMap_.find(payload);
 
     if (iter != codecsMap_.end())
-        return iter->second;
+        return static_cast<sfl::AudioCodec *>(iter->second);
     else {
         ERROR("Cannot find codec %i", payload);
         return NULL;
     }
 }
 
-double AudioCodecFactory::getBitRate(int payload) const
+double
+AudioCodecFactory::getBitRate(int payload) const
 {
-    CodecsMap::const_iterator iter = codecsMap_.find(payload);
+    AudioCodecsMap::const_iterator iter = codecsMap_.find(payload);
 
     if (iter != codecsMap_.end())
         return iter->second->getBitRate();
@@ -114,9 +119,10 @@ double AudioCodecFactory::getBitRate(int payload) const
 }
 
 
-int AudioCodecFactory::getSampleRate(int payload) const
+int
+AudioCodecFactory::getSampleRate(int payload) const
 {
-    CodecsMap::const_iterator iter = codecsMap_.find(payload);
+    AudioCodecsMap::const_iterator iter = codecsMap_.find(payload);
 
     if (iter != codecsMap_.end())
         return iter->second->getClockRate();
@@ -124,7 +130,8 @@ int AudioCodecFactory::getSampleRate(int payload) const
         return 0;
 }
 
-void AudioCodecFactory::saveActiveCodecs(const std::vector<std::string>& list)
+void
+AudioCodecFactory::saveActiveCodecs(const std::vector<std::string>& list)
 {
     defaultCodecList_.clear();
     // list contains the ordered payload of active codecs picked by the user
@@ -141,17 +148,18 @@ void AudioCodecFactory::saveActiveCodecs(const std::vector<std::string>& list)
 
 AudioCodecFactory::~AudioCodecFactory()
 {
-    for (std::vector<CodecHandlePointer>::const_iterator iter =
-                codecInMemory_.begin(); iter != codecInMemory_.end(); ++iter)
+    for (std::vector<AudioCodecHandlePointer>::iterator iter =
+         codecInMemory_.begin(); iter != codecInMemory_.end(); ++iter)
         unloadCodec(*iter);
 }
 
-std::vector<sfl::Codec*> AudioCodecFactory::scanCodecDirectory()
+std::vector<sfl::AudioCodec*>
+AudioCodecFactory::scanCodecDirectory()
 {
-    std::vector<sfl::Codec*> codecs;
+    std::vector<sfl::AudioCodec*> codecs;
     std::vector<std::string> dirToScan;
 
-    dirToScan.push_back(std::string(HOMEDIR) + DIR_SEPARATOR_STR "." PACKAGE "/");
+    dirToScan.push_back(fileutils::get_home_dir() + DIR_SEPARATOR_STR "." PACKAGE "/");
     dirToScan.push_back(CODECS_DIR "/");
     const char *envDir = getenv("CODECS_PATH");
 
@@ -181,7 +189,7 @@ std::vector<sfl::Codec*> AudioCodecFactory::scanCodecDirectory()
                 continue;
 
             if (seemsValid(file) && !alreadyInCache(file)) {
-                sfl::Codec* audioCodec = loadCodec(dirStr+file);
+                sfl::AudioCodec *audioCodec(loadCodec(dirStr + file));
 
                 if (audioCodec) {
                     codecs.push_back(audioCodec);
@@ -196,70 +204,83 @@ std::vector<sfl::Codec*> AudioCodecFactory::scanCodecDirectory()
     return codecs;
 }
 
-sfl::Codec* AudioCodecFactory::loadCodec(const std::string &path)
+sfl::AudioCodec *
+AudioCodecFactory::loadCodec(const std::string &path)
 {
-    void * codecHandle = dlopen(path.c_str(), RTLD_LAZY);
+    // Clear any existing error
+    dlerror();
+
+    void * codecHandle = dlopen(path.c_str(), RTLD_NOW);
 
     if (!codecHandle) {
         ERROR("%s", dlerror());
         return NULL;
     }
 
-    dlerror();
-
-    create_t* createCodec = (create_t*) dlsym(codecHandle, CODEC_ENTRY_SYMBOL);
-    char *error = dlerror();
+    create_t* createCodec = (create_t*) dlsym(codecHandle, AUDIO_CODEC_ENTRY_SYMBOL);
+    const char *error = dlerror();
 
     if (error) {
         ERROR("%s", error);
+        dlclose(codecHandle);
         return NULL;
     }
 
-    sfl::Codec* a = createCodec();
-
-    codecInMemory_.push_back(CodecHandlePointer(a, codecHandle));
+    sfl::AudioCodec *a = static_cast<sfl::AudioCodec *>(createCodec());
+    if (a)
+        codecInMemory_.push_back(AudioCodecHandlePointer(a, codecHandle));
+    else
+        dlclose(codecHandle);
 
     return a;
 }
 
 
-void AudioCodecFactory::unloadCodec(CodecHandlePointer p)
+void
+AudioCodecFactory::unloadCodec(AudioCodecHandlePointer &ptr)
 {
-    destroy_t* destroyCodec = (destroy_t*) dlsym(p.second , "destroy");
+    destroy_t *destroyCodec = 0;
+    if (ptr.second)
+        destroyCodec = (destroy_t*) dlsym(ptr.second, "destroy");
 
-    char *error = dlerror();
+    const char *error = dlerror();
 
     if (error) {
         ERROR("%s", error);
         return;
     }
 
-    destroyCodec(p.first);
+    if (ptr.first and destroyCodec)
+        destroyCodec(ptr.first);
 
-    dlclose(p.second);
+    if (ptr.second)
+        dlclose(ptr.second);
 }
 
-sfl::Codec* AudioCodecFactory::instantiateCodec(int payload) const
+sfl::AudioCodec*
+AudioCodecFactory::instantiateCodec(int payload) const
 {
-    std::vector< CodecHandlePointer >::const_iterator iter;
+    std::vector<AudioCodecHandlePointer>::const_iterator iter;
 
+    sfl::AudioCodec *result = NULL;
     for (iter = codecInMemory_.begin(); iter != codecInMemory_.end(); ++iter) {
         if (iter->first->getPayloadType() == payload) {
-            create_t* createCodec = (create_t*) dlsym(iter->second , CODEC_ENTRY_SYMBOL);
+            create_t* createCodec = (create_t*) dlsym(iter->second , AUDIO_CODEC_ENTRY_SYMBOL);
 
-            char *error = dlerror();
+            const char *error = dlerror();
 
             if (error)
                 ERROR("%s", error);
             else
-                return createCodec();
+                result = static_cast<sfl::AudioCodec *>(createCodec());
         }
     }
 
-    return NULL;
+    return result;
 }
 
-bool AudioCodecFactory::seemsValid(const std::string &lib)
+bool
+AudioCodecFactory::seemsValid(const std::string &lib)
 {
     // The name of the shared library seems valid  <==> it looks like libcodec_xxx.so
     // We check this
@@ -281,6 +302,8 @@ bool AudioCodecFactory::seemsValid(const std::string &lib)
     "ulaw",
     "alaw",
     "g722",
+    "g729", //G729 have to be loaded first, if it is valid or not is checked later
+    "opus", //Opus have to be loaded first, if it is valid or not is checked later
 #ifdef HAVE_SPEEX_CODEC
     "speex_nb",
     "speex_wb",
@@ -307,9 +330,10 @@ AudioCodecFactory::alreadyInCache(const std::string &lib)
     return std::find(libCache_.begin(), libCache_.end(), lib) != libCache_.end();
 }
 
-bool AudioCodecFactory::isCodecLoaded(int payload) const
+bool
+AudioCodecFactory::isCodecLoaded(int payload) const
 {
-    CodecsMap::const_iterator iter;
+    AudioCodecsMap::const_iterator iter;
 
     for (iter = codecsMap_.begin(); iter != codecsMap_.end(); ++iter)
         if (iter->first == payload)
