@@ -1,21 +1,21 @@
 /*
- *  Copyright (C) 2004, 2005, 2006, 2008, 2009, 2010, 2011 Savoir-Faire Linux Inc.
- * Author:  Yan Morin <yan.morin@savoirfairelinux.com>
- * Author:  Laurielle Lea <laurielle.lea@savoirfairelinux.com>
+ *  Copyright (C) 2004-2012 Savoir-Faire Linux Inc.
+ *  Author:  Yan Morin <yan.morin@savoirfairelinux.com>
+ *  Author:  Laurielle Lea <laurielle.lea@savoirfairelinux.com>
  *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 3 of the License, or
- * (at your option) any later version.
+ *  This program is free software; you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation; either version 3 of the License, or
+ *  (at your option) any later version.
  *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ *  This program is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
  *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ *  You should have received a copy of the GNU General Public License
+ *  along with this program; if not, write to the Free Software
+ *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301 USA.
  *
  *  Additional permission under GNU GPL version 3 section 7:
  *
@@ -40,18 +40,19 @@ class Ulaw : public sfl::AudioCodec {
             hasDynamicPayload_ = false;
         }
 
-        virtual int decode(SFLDataFormat *dst, unsigned char *src, size_t buf_size) {
+    private:
+        int decode(SFLDataFormat *dst, unsigned char *src, size_t buf_size) {
             for (unsigned char* end = src + buf_size; src < end; ++src, ++dst)
                 *dst = ULawDecode(*src);
 
-            return frameSize_;
+            return buf_size;
         }
 
-        virtual int encode(unsigned char *dst, SFLDataFormat *src, size_t /*buf_size*/) {
-            for (unsigned char * end = dst + frameSize_; dst < end; ++src, ++dst)
+        int encode(unsigned char *dst, SFLDataFormat *src, size_t buf_size) {
+            for (unsigned char * end = dst + buf_size; dst < end; ++src, ++dst)
                 *dst = ULawEncode(*src);
 
-            return frameSize_ / 2 /* compression factor = 2:1 */ * sizeof(SFLDataFormat);;
+            return buf_size;
         }
 
         SFLDataFormat ULawDecode(uint8 ulaw)
@@ -115,13 +116,13 @@ class Ulaw : public sfl::AudioCodec {
 
 // the class factories
 // cppcheck-suppress unusedFunction
-extern "C" sfl::Codec* CODEC_ENTRY()
+extern "C" sfl::AudioCodec* AUDIO_CODEC_ENTRY()
 {
     return new Ulaw;
 }
 
 // cppcheck-suppress unusedFunction
-extern "C" void destroy(sfl::Codec* a)
+extern "C" void destroy(sfl::AudioCodec* a)
 {
     delete a;
 }
