@@ -1,8 +1,7 @@
 /*
- *  Copyright (C) 2004, 2005, 2006, 2008, 2009, 2010, 2011 Savoir-Faire Linux Inc.
+ *  Copyright (C) 2004-2012 Savoir-Faire Linux Inc.
  *  Author : Alexandre Savard <alexandre.savard@savoirfairelinux.com>
  *
- *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
  *  the Free Software Foundation; either version 3 of the License, or
@@ -15,7 +14,7 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301 USA.
  *
  *  Additional permission under GNU GPL version 3 section 7:
  *
@@ -33,19 +32,24 @@
 #include "ringbuffer.h"
 #include "sfl_types.h" // for SIZEBUF
 #include <climits>
+#include <cstring>
 #include <utility> // for std::pair
+#include "scoped_lock.h"
 #include "logger.h"
 
 const char * const MainBuffer::DEFAULT_ID = "audiolayer_id";
 
 MainBuffer::MainBuffer() : ringBufferMap_(), callIDMap_(), mutex_(), internalSamplingRate_(8000)
-{}
+{
+    pthread_mutex_init(&mutex_, NULL);
+}
 
 MainBuffer::~MainBuffer()
 {
     // delete any ring buffers that didn't get removed
     for (RingBufferMap::iterator iter = ringBufferMap_.begin(); iter != ringBufferMap_.end(); ++iter)
         delete iter->second;
+    pthread_mutex_destroy(&mutex_);
 }
 
 void MainBuffer::setInternalSamplingRate(int sr)
@@ -84,7 +88,10 @@ void MainBuffer::removeCallIDSet(const std::string &set_id)
 void MainBuffer::addCallIDtoSet(const std::string &set_id, const std::string &call_id)
 {
     CallIDSet* callid_set = getCallIDSet(set_id);
-    callid_set->insert(call_id);
+    if (callid_set)
+        callid_set->insert(call_id);
+    else
+        ERROR("CallIDSet %s does not exist!", set_id.c_str());
 }
 
 void MainBuffer::removeCallIDfromSet(const std::string &set_id, const std::string &call_id)
@@ -130,7 +137,7 @@ void MainBuffer::removeRingBuffer(const std::string &call_id)
 
 void MainBuffer::bindCallID(const std::string & call_id1, const std::string & call_id2)
 {
-    ost::MutexLock guard(mutex_);
+    sfl::ScopedLock guard(mutex_);
 
     createRingBuffer(call_id1);
     createCallIDSet(call_id1);
@@ -145,7 +152,7 @@ void MainBuffer::bindCallID(const std::string & call_id1, const std::string & ca
 
 void MainBuffer::bindHalfDuplexOut(const std::string & process_id, const std::string & call_id)
 {
-    ost::MutexLock guard(mutex_);
+    sfl::ScopedLock guard(mutex_);
 
     // This method is used only for active calls, if this call does not exist, do nothing
     if (!getRingBuffer(call_id))
@@ -158,7 +165,7 @@ void MainBuffer::bindHalfDuplexOut(const std::string & process_id, const std::st
 
 void MainBuffer::unBindCallID(const std::string & call_id1, const std::string & call_id2)
 {
-    ost::MutexLock guard(mutex_);
+    sfl::ScopedLock guard(mutex_);
 
     removeCallIDfromSet(call_id1, call_id2);
     removeCallIDfromSet(call_id2, call_id1);
@@ -188,7 +195,7 @@ void MainBuffer::unBindCallID(const std::string & call_id1, const std::string &
 
 void MainBuffer::unBindHalfDuplexOut(const std::string & process_id, const std::string & call_id)
 {
-    ost::MutexLock guard(mutex_);
+    sfl::ScopedLock guard(mutex_);
 
     removeCallIDfromSet(process_id, call_id);
 
@@ -230,7 +237,7 @@ void MainBuffer::unBindAll(const std::string & call_id)
 
 void MainBuffer::putData(void *buffer, size_t toCopy, const std::string &call_id)
 {
-    ost::MutexLock guard(mutex_);
+    sfl::ScopedLock guard(mutex_);
 
     RingBuffer* ring_buffer = getRingBuffer(call_id);
 
@@ -240,7 +247,7 @@ void MainBuffer::putData(void *buffer, size_t toCopy, const std::string &call_id
 
 size_t MainBuffer::getData(void *buffer, size_t toCopy, const std::string &call_id)
 {
-    ost::MutexLock guard(mutex_);
+    sfl::ScopedLock guard(mutex_);
 
     CallIDSet* callid_set = getCallIDSet(call_id);
 
@@ -286,7 +293,7 @@ size_t MainBuffer::getDataByID(void *buffer, size_t toCopy, const std::string &
 
 size_t MainBuffer::availableForGet(const std::string &call_id)
 {
-    ost::MutexLock guard(mutex_);
+    sfl::ScopedLock guard(mutex_);
 
     CallIDSet* callid_set = getCallIDSet(call_id);
 
@@ -333,7 +340,7 @@ size_t MainBuffer::availableForGetByID(const std::string &call_id,
 
 size_t MainBuffer::discard(size_t toDiscard, const std::string &call_id)
 {
-    ost::MutexLock guard(mutex_);
+    sfl::ScopedLock guard(mutex_);
 
     CallIDSet* callid_set = getCallIDSet(call_id);
 
@@ -356,7 +363,7 @@ void MainBuffer::discardByID(size_t toDiscard, const std::string & call_id, cons
 
 void MainBuffer::flush(const std::string & call_id)
 {
-    ost::MutexLock guard(mutex_);
+    sfl::ScopedLock guard(mutex_);
 
     CallIDSet* callid_set = getCallIDSet(call_id);
 
@@ -383,8 +390,9 @@ void MainBuffer::flushAllBuffers()
         iter->second->flushAll();
 }
 
-void MainBuffer::dumpInfo() const
+void MainBuffer::dumpInfo()
 {
+    sfl::ScopedLock guard(mutex_);
     // print each call and bound call ids
     for (CallIDMap::const_iterator iter_call = callIDMap_.begin(); iter_call != callIDMap_.end(); ++iter_call) {
         std::string dbg_str("    Call: \t");
