@@ -1,8 +1,7 @@
 /*
- *  Copyright (C) 2004, 2005, 2006, 2008, 2009, 2010, 2011 Savoir-Faire Linux Inc.
+ *  Copyright (C) 2004-2012 Savoir-Faire Linux Inc.
  *  Author : Alexandre Savard <alexandre.savard@savoirfairelinux.com>
  *
- *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
  *  the Free Software Foundation; either version 3 of the License, or
@@ -15,7 +14,7 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301 USA.
  *
  *  Additional permission under GNU GPL version 3 section 7:
  *
@@ -35,8 +34,7 @@
 #include <map>
 #include <set>
 #include <string>
-
-#include "cc_thread.h" // for ost::Mutex
+#include <pthread.h>
 
 class RingBuffer;
 
@@ -94,7 +92,7 @@ class MainBuffer {
 
         void flushAllBuffers();
 
-        void dumpInfo() const;
+        void dumpInfo();
 
     private:
 
@@ -135,7 +133,7 @@ class MainBuffer {
         typedef std::map<std::string, CallIDSet*> CallIDMap;
         CallIDMap callIDMap_;
 
-        ost::Mutex mutex_;
+        pthread_mutex_t mutex_;
 
         int internalSamplingRate_;
 
