@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 2004, 2005, 2006, 2008, 2009, 2010, 2011 Savoir-Faire Linux Inc.
+ *  Copyright (C) 2004-2012 Savoir-Faire Linux Inc.
  *  Author: Yan Morin <yan.morin@savoirfairelinux.com>
  *  Author : Laurielle Lea <laurielle.lea@savoirfairelinux.com>
  *
@@ -15,7 +15,7 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301 USA.
  *
  *  Additional permission under GNU GPL version 3 section 7:
  *
@@ -32,8 +32,9 @@
 #include "manager.h"
 #include "audio/mainbuffer.h"
 #include "history/historyitem.h"
+#include "scoped_lock.h"
 
-Call::Call(const std::string& id, Call::CallType type)
+Call::Call(const std::string& id, Call::CallType type, const std::string &accountID)
     : callMutex_()
     , localIPAddress_("")
     , localAudioPort_(0)
@@ -41,6 +42,7 @@ Call::Call(const std::string& id, Call::CallType type)
     , id_(id)
     , confID_()
     , type_(type)
+    , accountID_(accountID)
     , connectionState_(Call::DISCONNECTED)
     , callState_(Call::INACTIVE)
     , isIPToIP_(false)
@@ -49,37 +51,40 @@ Call::Call(const std::string& id, Call::CallType type)
     , timestamp_start_(0)
     , timestamp_stop_(0)
 {
+    pthread_mutex_init(&callMutex_, NULL);
     time(&timestamp_start_);
 }
 
 Call::~Call()
-{}
+{
+    pthread_mutex_destroy(&callMutex_);
+}
 
 void
 Call::setConnectionState(ConnectionState state)
 {
-    ost::MutexLock m(callMutex_);
+    sfl::ScopedLock m(callMutex_);
     connectionState_ = state;
 }
 
 Call::ConnectionState
 Call::getConnectionState()
 {
-    ost::MutexLock m(callMutex_);
+    sfl::ScopedLock m(callMutex_);
     return connectionState_;
 }
 
 void
 Call::setState(CallState state)
 {
-    ost::MutexLock m(callMutex_);
+    sfl::ScopedLock m(callMutex_);
     callState_ = state;
 }
 
 Call::CallState
 Call::getState()
 {
-    ost::MutexLock m(callMutex_);
+    sfl::ScopedLock m(callMutex_);
     return callState_;
 }
 
@@ -124,21 +129,21 @@ Call::getStateStr()
 std::string
 Call::getLocalIp()
 {
-    ost::MutexLock m(callMutex_);
+    sfl::ScopedLock m(callMutex_);
     return localIPAddress_;
 }
 
 unsigned int
 Call::getLocalAudioPort()
 {
-    ost::MutexLock m(callMutex_);
+    sfl::ScopedLock m(callMutex_);
     return localAudioPort_;
 }
 
 unsigned int
 Call::getLocalVideoPort()
 {
-    ost::MutexLock m (callMutex_);
+    sfl::ScopedLock m(callMutex_);
     return localVideoPort_;
 }
 
@@ -148,20 +153,20 @@ Call::setRecording()
     bool recordStatus = Recordable::recAudio_.isRecording();
 
     Recordable::recAudio_.setRecording();
-    MainBuffer *mbuffer = Manager::instance().getMainBuffer();
+    MainBuffer &mbuffer = Manager::instance().getMainBuffer();
     std::string process_id = Recordable::recorder_.getRecorderID();
 
     if (!recordStatus) {
-        mbuffer->bindHalfDuplexOut(process_id, id_);
-        mbuffer->bindHalfDuplexOut(process_id, MainBuffer::DEFAULT_ID);
+        mbuffer.bindHalfDuplexOut(process_id, id_);
+        mbuffer.bindHalfDuplexOut(process_id, MainBuffer::DEFAULT_ID);
 
         Recordable::recorder_.start();
     } else {
-        mbuffer->unBindHalfDuplexOut(process_id, id_);
-        mbuffer->unBindHalfDuplexOut(process_id, MainBuffer::DEFAULT_ID);
+        mbuffer.unBindHalfDuplexOut(process_id, id_);
+        mbuffer.unBindHalfDuplexOut(process_id, MainBuffer::DEFAULT_ID);
     }
 
-    Manager::instance().getMainBuffer()->dumpInfo();
+    Manager::instance().getMainBuffer().dumpInfo();
 
     return recordStatus;
 }
@@ -196,8 +201,10 @@ namespace {
 
 std::map<std::string, std::string> Call::createHistoryEntry() const
 {
+    using sfl::HistoryItem;
     std::map<std::string, std::string> result;
-    result[HistoryItem::ACCOUNT_ID_KEY] = Manager::instance().getAccountFromCall(id_);
+
+    result[HistoryItem::ACCOUNT_ID_KEY] = accountID_;
     result[HistoryItem::CONFID_KEY] = confID_;
     result[HistoryItem::CALLID_KEY] = id_;
     result[HistoryItem::DISPLAY_NAME_KEY] = displayName_;
@@ -224,6 +231,7 @@ Call::getDetails()
     details["CALL_STATE"] = getStateStr();
     details["CONF_ID"] = confID_;
     details["TIMESTAMP_START"] = timestamp_to_string(timestamp_start_);
+    details["ACCOUNTID"] = accountID_;
     return details;
 }
 
