@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 2004, 2005, 2006, 2008, 2009, 2010, 2011 Savoir-Faire Linux Inc.
+ *  Copyright (C) 2004-2012 Savoir-Faire Linux Inc.
  *  Author: Emmanuel Milou <emmanuel.milou@savoirfairelinux.com>
  *  Author: Yan Morin <yan.morin@savoirfairelinux.com>
  *  Author : Laurielle Lea <laurielle.lea@savoirfairelinux.com>
@@ -16,7 +16,7 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301 USA.
  *
  *  Additional permission under GNU GPL version 3 section 7:
  *
@@ -34,7 +34,7 @@
 
 #include <sstream>
 #include <map>
-#include "cc_thread.h"
+#include <pthread.h>
 #include "audio/recordable.h"
 
 /*
@@ -72,7 +72,7 @@ class Call : public Recordable {
          * @param id Unique identifier of the call
          * @param type set definitely this call as incoming/outgoing
          */
-        Call(const std::string& id, Call::CallType type);
+        Call(const std::string& id, Call::CallType type, const std::string &accountID);
         virtual ~Call();
 
         /**
@@ -95,6 +95,10 @@ class Call : public Recordable {
             confID_ = id;
         }
 
+        std::string getAccountId() const {
+            return accountID_;
+        }
+
         CallType getCallType() const {
             return type_;
         }
@@ -220,13 +224,16 @@ class Call : public Recordable {
         void time_stop();
         virtual std::map<std::string, std::string> getDetails();
         static std::map<std::string, std::string> getNullDetails();
-        std::map<std::string, std::string> createHistoryEntry() const;
+
+        virtual std::map<std::string, std::string>
+        createHistoryEntry() const;
+
         virtual bool setRecording();
 
     private:
         std::string getTypeStr() const;
         /** Protect every attribute that can be changed by two threads */
-        ost::Mutex callMutex_;
+        pthread_mutex_t callMutex_;
 
         // Informations about call socket / audio
 
@@ -248,6 +255,9 @@ class Call : public Recordable {
         /** Type of the call */
         CallType type_;
 
+        /** Associate account ID */
+        std::string accountID_;
+
         /** Disconnected/Progressing/Trying/Ringing/Connected */
         ConnectionState connectionState_;
 
