@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 2004, 2005, 2006, 2008, 2009, 2010, 2011 Savoir-Faire Linux Inc.
+ *  Copyright (C) 2004-2012 Savoir-Faire Linux Inc.
  *  Author: Alexandre Savard <alexandre.savard@savoirfairelinux.com>
  *
  *  This program is free software; you can redistribute it and/or modify
@@ -14,7 +14,7 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301 USA.
  *
  *  Additional permission under GNU GPL version 3 section 7:
  *
@@ -33,7 +33,7 @@
 
 namespace Conf {
     class YamlEmitter;
-    class MappingNode;
+    class YamlNode;
 }
 
 class Serializable {
@@ -41,7 +41,7 @@ class Serializable {
     public:
         virtual ~Serializable() {};
         virtual void serialize(Conf::YamlEmitter &emitter) = 0;
-        virtual void unserialize(const Conf::MappingNode &map) = 0;
+        virtual void unserialize(const Conf::YamlNode &map) = 0;
 };
 
 #endif
