@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 2004, 2005, 2006, 2008, 2009, 2010, 2011 Savoir-Faire Linux Inc.
+ *  Copyright (C) 2004-2012 Savoir-Faire Linux Inc.
  *  Author: Alexandre Savard <alexandre.savard@savoirfairelinux.com>
  *
  *  This program is free software; you can redistribute it and/or modify
@@ -14,7 +14,7 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301 USA.
  *
  *  Additional permission under GNU GPL version 3 section 7:
  *
@@ -36,8 +36,8 @@
 namespace Conf {
 
 YamlEmitter::YamlEmitter(const char *file) : filename_(file), fd_(0),
-    emitter_(), document_(), topLevelMapping_(0), isFirstAccount_(true),
-    accountSequence_(0)
+    emitter_(), events_(), buffer_(), document_(), topLevelMapping_(0),
+    isFirstAccount_(true), accountSequence_(0)
 {
     open();
 }
@@ -76,8 +76,10 @@ void YamlEmitter::close()
 
     // Refererence:
     // http://www.parashift.com/c++-faq-lite/exceptions.html#faq-17.9
-    if (!fd_)
+    if (!fd_) {
         ERROR("File descriptor not valid");
+        return;
+    }
 
     if (fclose(fd_))
         ERROR("Error closing file descriptor");
@@ -140,11 +142,9 @@ void YamlEmitter::serializePreference(MappingNode *map, const char *preference_s
     addMappingItems(preferenceMapping, map->getMapping());
 }
 
-typedef std::map<std::string, YamlNode*> Mapping;
-
-void YamlEmitter::addMappingItems(int mappingID, Mapping *iMap)
+void YamlEmitter::addMappingItems(int mappingID, YamlNodeMap &iMap)
 {
-    for (Mapping::const_iterator i = iMap->begin(); i != iMap->end(); ++i)
+    for (YamlNodeMap::const_iterator i = iMap.begin(); i != iMap.end(); ++i)
         addMappingItem(mappingID, i->first, i->second);
 }
 
