@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 2004, 2005, 2006, 2008, 2009, 2010, 2011 Savoir-Faire Linux Inc.
+ *  Copyright (C) 2004-2012 Savoir-Faire Linux Inc.
  *  Author: Alexandre Savard <alexandre.savard@savoirfairelinux.com>
  *
  *  This program is free software; you can redistribute it and/or modify
@@ -14,7 +14,7 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301 USA.
  *
  *  Additional permission under GNU GPL version 3 section 7:
  *
@@ -28,18 +28,19 @@
  *  as that of the covered work.
  */
 
+#include <cstdio>
+#include <assert.h>
+
 #include "yamlparser.h"
 
 #include "../global.h"
 #include "sfl_config.h"
 #include "yamlnode.h"
 #include "logger.h"
-#include <cstdio>
 
 namespace Conf {
 
-YamlParser::YamlParser(const char *file) : filename_(file)
-    , fd_(0)
+YamlParser::YamlParser(FILE *fd) : fd_(fd)
     , parser_()
     , events_()
     , eventNumber_(0)
@@ -47,7 +48,6 @@ YamlParser::YamlParser(const char *file) : filename_(file)
     , eventIndex_(0)
     , accountSequence_(NULL)
     , preferenceNode_(NULL)
-    , addressbookNode_(NULL)
     , audioNode_(NULL)
 #ifdef SFL_VIDEO
     , videoNode_(NULL)
@@ -56,7 +56,6 @@ YamlParser::YamlParser(const char *file) : filename_(file)
     , voiplinkNode_(NULL)
     , shortcutNode_(NULL)
 {
-    fd_ = fopen(filename_.c_str(), "rb");
     if (!fd_)
         throw YamlParserException("Could not open file descriptor");
 
@@ -85,12 +84,6 @@ YamlParser::getPreferenceNode()
     CHECK_AND_RETURN(preferenceNode_);
 }
 
-MappingNode *
-YamlParser::getAddressbookNode()
-{
-    CHECK_AND_RETURN(addressbookNode_);
-}
-
 MappingNode *
 YamlParser::getAudioNode()
 {
@@ -127,18 +120,13 @@ YamlParser::getShortcutNode()
 
 YamlParser::~YamlParser()
 {
-    if (fd_) {
-        fclose(fd_);
+    if (fd_)
         yaml_parser_delete(&parser_);
-    }
 
     for (int i = 0; i < eventNumber_; ++i)
         yaml_event_delete(&events_[i]);
 
-    if (doc_) {
-        doc_->deleteChildNodes();
-        delete doc_;
-    }
+    doc_.deleteChildNodes();
 }
 
 void YamlParser::serializeEvents()
@@ -256,7 +244,7 @@ void YamlParser::copyEvent(yaml_event_t *event_to, yaml_event_t *event_from)
 }
 
 
-YamlDocument *YamlParser::composeEvents()
+void YamlParser::composeEvents()
 {
     if (eventNumber_ == 0)
         throw YamlParserException("No event available");
@@ -267,8 +255,6 @@ YamlDocument *YamlParser::composeEvents()
     eventIndex_ = 0;
 
     processStream();
-
-    return doc_;
 }
 
 void YamlParser::processStream()
@@ -283,18 +269,18 @@ void YamlParser::processStream()
 
 void YamlParser::processDocument()
 {
-    doc_ = new YamlDocument;
+    assert(eventNumber_ > 0);
 
     for (; (eventIndex_ < eventNumber_) and (events_[eventIndex_].type != YAML_DOCUMENT_END_EVENT); ++eventIndex_) {
         switch (events_[eventIndex_].type) {
             case YAML_SCALAR_EVENT:
-                processScalar(doc_);
+                processScalar(&doc_);
                 break;
             case YAML_SEQUENCE_START_EVENT:
-                processSequence(doc_);
+                processSequence(&doc_);
                 break;
             case YAML_MAPPING_START_EVENT:
-                processMapping(doc_);
+                processMapping(&doc_);
                 break;
             default:
                 break;
@@ -313,20 +299,7 @@ void YamlParser::processScalar(YamlNode *topNode)
 
     ScalarNode *sclr = new ScalarNode(std::string((const char*) events_[eventIndex_].data.scalar.value), topNode);
 
-    switch (topNode->getType()) {
-        case DOCUMENT:
-            ((YamlDocument *)(topNode))->addNode(sclr);
-            break;
-        case SEQUENCE:
-            ((SequenceNode *)(topNode))->addNode(sclr);
-            break;
-        case MAPPING:
-            ((MappingNode *)(topNode))->addNode(sclr);
-            break;
-        case SCALAR:
-        default:
-            break;
-    }
+    topNode->addNode(sclr);
 }
 
 
@@ -337,19 +310,7 @@ void YamlParser::processSequence(YamlNode *topNode)
 
     SequenceNode *seq = new SequenceNode(topNode);
 
-    switch (topNode->getType()) {
-        case DOCUMENT:
-            ((YamlDocument *)(topNode))->addNode(seq);
-            break;
-        case SEQUENCE:
-            ((SequenceNode *)(topNode))->addNode(seq);
-            break;
-        case MAPPING:
-            ((MappingNode *)(topNode))->addNode(seq);
-        case SCALAR:
-        default:
-            break;
-    }
+    topNode->addNode(seq);
 
     ++eventIndex_;
 
@@ -381,19 +342,7 @@ void YamlParser::processMapping(YamlNode *topNode)
 
     MappingNode *map = new MappingNode(topNode);
 
-    switch (topNode->getType()) {
-        case DOCUMENT:
-            ((YamlDocument *)(topNode))->addNode(map);
-            break;
-        case SEQUENCE:
-            ((SequenceNode *)(topNode))->addNode(map);
-            break;
-        case MAPPING:
-            ((MappingNode *)(topNode))->addNode(map);
-        case SCALAR:
-        default:
-            break;
-    }
+    topNode->addNode(map);
 
     ++eventIndex_;
 
@@ -403,6 +352,7 @@ void YamlParser::processMapping(YamlNode *topNode)
             throw YamlParserException("Mapping not followed by a key");
 
         map->setTmpKey(std::string((const char *)events_[eventIndex_].data.scalar.value));
+        std::string tmpstring((const char *)events_[eventIndex_].data.scalar.value);
         ++eventIndex_;
 
         switch (events_[eventIndex_].type) {
@@ -428,23 +378,24 @@ void YamlParser::processMapping(YamlNode *topNode)
 
 void YamlParser::constructNativeData()
 {
-    if (!doc_)
-        throw YamlParserException("YAML Document not initialized");
-    Sequence *seq = doc_->getSequence();
+    Sequence *seq = doc_.getSequence();
 
     for (Sequence::iterator iter = seq->begin(); iter != seq->end(); ++iter) {
-        switch ((*iter)->getType()) {
-            case SCALAR:
-                throw YamlParserException("No scalar allowed at document level, expect a mapping");
-                break;
-            case SEQUENCE:
-                throw YamlParserException("No sequence allowed at document level, expect a mapping");
-                break;
+        YamlNode *yamlNode = static_cast<YamlNode *>(*iter);
+        if (yamlNode == NULL) {
+            ERROR("Could not retrieve yaml node from document sequence");
+            continue;
+        }
+
+        NodeType nodeType = yamlNode->getType();
+        switch (nodeType) {
             case MAPPING: {
-                MappingNode *map = (MappingNode *)(*iter);
+                MappingNode *map = static_cast<MappingNode *>(yamlNode);
                 mainNativeDataMapping(map);
                 break;
             }
+            case SCALAR:
+            case SEQUENCE:
             default:
                 throw YamlParserException("Unknown type in configuration file, expect a mapping");
                 break;
@@ -454,18 +405,17 @@ void YamlParser::constructNativeData()
 
 void YamlParser::mainNativeDataMapping(MappingNode *map)
 {
-    std::map<std::string, YamlNode*> *mapping = map->getMapping();
+    std::map<std::string, YamlNode*> &mapping = map->getMapping();
 
-    accountSequence_    = (SequenceNode*)(*mapping)["accounts"];
-    addressbookNode_    = (MappingNode*)(*mapping)["addressbook"];
-    audioNode_          = (MappingNode*)(*mapping)["audio"];
+    accountSequence_    = static_cast<SequenceNode*>(mapping["accounts"]);
+    audioNode_          = static_cast<MappingNode *>(mapping["audio"]);
 #ifdef SFL_VIDEO
-    videoNode_          = (MappingNode*)(*mapping)["video"];
+    videoNode_          = static_cast<MappingNode *>(mapping["video"]);
 #endif
-    hooksNode_          = (MappingNode*)(*mapping)["hooks"];
-    preferenceNode_     = (MappingNode*)(*mapping)["preferences"];
-    voiplinkNode_       = (MappingNode*)(*mapping)["voipPreferences"];
-    shortcutNode_       = (MappingNode*)(*mapping)["shortcuts"];
+    hooksNode_          = static_cast<MappingNode *>(mapping["hooks"]);
+    preferenceNode_     = static_cast<MappingNode *>(mapping["preferences"]);
+    voiplinkNode_       = static_cast<MappingNode *>(mapping["voipPreferences"]);
+    shortcutNode_       = static_cast<MappingNode *>(mapping["shortcuts"]);
 }
 }
 
