@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 2004, 2005, 2006, 2008, 2009, 2010, 2011 Savoir-Faire Linux Inc.
+ *  Copyright (C) 2004-2012 Savoir-Faire Linux Inc.
  *  Emmanuel Milou <emmanuel.milou@savoirfairelinux.com>
  *
  *  This program is free software; you can redistribute it and/or modify
@@ -14,7 +14,7 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301 USA.
  *
  *  Additional permission under GNU GPL version 3 section 7:
  *
@@ -31,25 +31,30 @@
 #ifndef EVENT_THREAD_H_
 #define EVENT_THREAD_H_
 
-#include "cc_thread.h"
 #include "noncopyable.h"
+#include <pthread.h>
 
 class VoIPLink;
 
 /**
  * @file eventthread.h
- * @brief Thread which listens to VoIP events continuously
+ * @brief Runs thread which listens to VoIP events continuously
  */
 
-class EventThread : public ost::Thread {
+class EventThread {
     public:
         EventThread(VoIPLink* link);
-        void run();
+        ~EventThread();
+        // spawns thread
+        void start();
 
     private:
         NON_COPYABLE(EventThread);
         // VoIPLink is the object being called by getEvents() method
         VoIPLink* link_;
+        pthread_t thread_;
+        void run();
+        static void *runCallback(void *);
 };
 
 #endif // EVENT_THREAD_H__
