@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 2011 Savoir-Faire Linux Inc.
+ *  Copyright (C) 2011-2012 Savoir-Faire Linux Inc.
  *  Author: Rafaël Carré <rafael.carre@savoirfairelinux.com>
  *
  *  This program is free software; you can redistribute it and/or modify
@@ -14,7 +14,7 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301 USA.
  *
  *  Additional permission under GNU GPL version 3 section 7:
  *
@@ -31,26 +31,35 @@
 #ifndef FILEUTILS_H_
 #define FILEUTILS_H_
 
+#include <string>
+
 #define PROTECTED_GETENV(str) ({char *envvar_ = getenv((str)); \
                                                    envvar_ ? envvar_ : "";})
 
-#define HOMEDIR                 (PROTECTED_GETENV("HOME"))
 #define XDG_DATA_HOME           (PROTECTED_GETENV("XDG_DATA_HOME"))
 #define XDG_CONFIG_HOME         (PROTECTED_GETENV("XDG_CONFIG_HOME"))
 #define XDG_CACHE_HOME          (PROTECTED_GETENV("XDG_CACHE_HOME"))
 
-#define PIDFILE "sfl.pid"
+#define PIDFILE ".sfl.pid"
 
 
 #define DIR_SEPARATOR_STR "/"   // Directory separator char
-#define DIR_SEPARATOR_CH = '/'  // Directory separator string
+#define DIR_SEPARATOR_CH  '/'  // Directory separator string
 
 namespace fileutils {
+    std::string get_home_dir();
     bool check_dir(const char *path);
     void set_program_dir(char *program_path);
     const char *get_program_dir();
-    const char *get_data_dir();
-    bool create_pidfile();
+    std::string get_data_dir();
+    bool isDirectoryWritable(const std::string &directory);
+    struct FileHandle {
+        int fd;
+        const std::string name;
+        FileHandle(const std::string &name);
+        ~FileHandle();
+    };
+    FileHandle create_pidfile();
 }
 
 #endif	// FILEUTILS_H_
