@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 2004, 2005, 2006, 2008, 2009, 2010, 2011 Savoir-Faire Linux Inc.
+ *  Copyright (C) 2004-2012 Savoir-Faire Linux Inc.
  *
  *  Author: Emmanuel Milou <emmanuel.milou@savoirfairelinux.com>
  *  Author: Alexandre Savard <alexandre.savard@savoirfairelinux.com>
@@ -16,7 +16,7 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301 USA.
  *
  *  Additional permission under GNU GPL version 3 section 7:
  *
@@ -36,16 +36,26 @@
 #include <fstream>
 #include <sys/stat.h> // for mkdir
 #include <ctime>
+#include "scoped_lock.h"
 #include "fileutils.h"
 #include "logger.h"
 #include "call.h"
 
+namespace sfl {
+
 using std::map;
 using std::string;
 using std::vector;
 
 History::History() : historyItemsMutex_(), items_(), path_("")
-{}
+{
+    pthread_mutex_init(&historyItemsMutex_, NULL);
+}
+
+History::~History()
+{
+    pthread_mutex_destroy(&historyItemsMutex_);
+}
 
 bool History::load(int limit)
 {
@@ -64,7 +74,7 @@ bool History::load(int limit)
 
 bool History::save()
 {
-    ost::MutexLock lock(historyItemsMutex_);
+    sfl::ScopedLock lock(historyItemsMutex_);
     DEBUG("Saving history in XDG directory: %s", path_.c_str());
     ensurePath();
     std::sort(items_.begin(), items_.end());
@@ -79,7 +89,7 @@ bool History::save()
 
 void History::addEntry(const HistoryItem &item, int oldest)
 {
-    ost::MutexLock lock(historyItemsMutex_);
+    sfl::ScopedLock lock(historyItemsMutex_);
     if (item.hasPeerNumber() and item.youngerThan(oldest))
         items_.push_back(item);
 }
@@ -87,13 +97,13 @@ void History::addEntry(const HistoryItem &item, int oldest)
 void History::ensurePath()
 {
     if (path_.empty()) {
-        string xdg_data = string(HOMEDIR) + DIR_SEPARATOR_STR + ".local/share/sflphone";
+        const string xdg_data = fileutils::get_home_dir() + DIR_SEPARATOR_STR +
+                                ".local/share/sflphone";
 
-        string userdata;
         // If the environment variable is set (not null and not empty), we'll use it to save the history
-        // Else we 'll the standard one, ie: XDG_DATA_HOME = $HOMEDIR/.local/share/sflphone
+        // Else we 'll the standard one, ie: XDG_DATA_HOME = $HOME/.local/share/sflphone
         string xdg_env(XDG_DATA_HOME);
-        (not xdg_env.empty()) ? userdata = xdg_env : userdata = xdg_data;
+        const string userdata = not xdg_env.empty() ? xdg_env : xdg_data;
 
         if (mkdir(userdata.data(), 0755) != 0) {
             // If directory	creation failed
@@ -109,7 +119,7 @@ void History::ensurePath()
 
 vector<map<string, string> > History::getSerialized()
 {
-    ost::MutexLock lock(historyItemsMutex_);
+    sfl::ScopedLock lock(historyItemsMutex_);
     vector<map<string, string> > result;
     for (vector<HistoryItem>::const_iterator iter = items_.begin();
          iter != items_.end(); ++iter)
@@ -136,19 +146,21 @@ void History::addCall(Call *call, int limit)
 
 void History::clear()
 {
-    ost::MutexLock lock(historyItemsMutex_);
+    sfl::ScopedLock lock(historyItemsMutex_);
     items_.clear();
 }
 
 bool History::empty()
 {
-    ost::MutexLock lock(historyItemsMutex_);
+    sfl::ScopedLock lock(historyItemsMutex_);
     return items_.empty();
 }
 
 
 size_t History::numberOfItems()
 {
-    ost::MutexLock lock(historyItemsMutex_);
+    sfl::ScopedLock lock(historyItemsMutex_);
     return items_.size();
 }
+
+}
