@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 2004, 2005, 2006, 2008, 2009, 2010, 2011 Savoir-Faire Linux Inc.
+ *  Copyright (C) 2004-2012 Savoir-Faire Linux Inc.
  *  Author: Alexandre Bourget <alexandre.bourget@savoirfairelinux.com>
  *  Author: Yan Morin <yan.morin@savoirfairelinux.com>
  *
@@ -15,7 +15,7 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301 USA.
  *
  *  Additional permission under GNU GPL version 3 section 7:
  *
@@ -43,7 +43,7 @@ class IAXAccount : public Account {
         IAXAccount(const std::string& accountID);
 
         virtual void serialize(Conf::YamlEmitter &emitter);
-        virtual void unserialize(const Conf::MappingNode &map);
+        virtual void unserialize(const Conf::YamlNode &map);
 
         void setAccountDetails(std::map<std::string, std::string> details);
 
@@ -67,6 +67,7 @@ class IAXAccount : public Account {
         std::string password_;
         IAXVoIPLink link_;
         virtual VoIPLink* getVoIPLink();
+        static const char * const ACCOUNT_TYPE;
 };
 
 #endif
