@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 2004, 2005, 2006, 2008, 2009, 2010, 2011 Savoir-Faire Linux Inc.
+ *  Copyright (C) 2004-2012 Savoir-Faire Linux Inc.
  *  Author: Alexandre Bourget <alexandre.bourget@savoirfairelinux.com>
  *  Author: Yan Morin <yan.morin@savoirfairelinux.com>
  *
@@ -15,7 +15,7 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301 USA.
  *
  *  Additional permission under GNU GPL version 3 section 7:
  *
@@ -29,6 +29,10 @@
  *  as that of the covered work.
  */
 #include "iaxvoiplink.h"
+#include <unistd.h>
+#include <cmath>
+#include <algorithm>
+
 #include "iaxcall.h"
 #include "eventthread.h"
 #include "im/instant_messaging.h"
@@ -39,9 +43,14 @@
 #include "audio/audiolayer.h"
 #include "audio/samplerateconverter.h"
 #include "array_size.h"
+#include "scoped_lock.h"
+#include "map_utils.h"
 
-#include <cmath>
-#include <dlfcn.h>
+AccountMap IAXVoIPLink::iaxAccountMap_;
+IAXCallMap IAXVoIPLink::iaxCallMap_;
+// has same effect as pthread_mutex_init with default args, but for a statically
+// allocated mutex
+pthread_mutex_t IAXVoIPLink::iaxCallMapMutex_ = PTHREAD_MUTEX_INITIALIZER;
 
 IAXVoIPLink::IAXVoIPLink(const std::string& accountID) :
     regSession_(NULL)
@@ -55,6 +64,7 @@ IAXVoIPLink::IAXVoIPLink(const std::string& accountID) :
     , accountID_(accountID)
     , evThread_(this)
 {
+    pthread_mutex_init(&mutexIAX_, NULL);
     srand(time(NULL));    // to get random number for RANDOM_PORT
 }
 
@@ -64,6 +74,11 @@ IAXVoIPLink::~IAXVoIPLink()
     handlingEvents_ = false;
     regSession_ = NULL; // shall not delete it // XXX: but why?
     terminate();
+
+    // This is our last account
+    if (iaxAccountMap_.size() == 1)
+        clearIaxCallMap();
+    pthread_mutex_destroy(&mutexIAX_);
 }
 
 void
@@ -88,19 +103,19 @@ IAXVoIPLink::terminate()
     if (!initDone_)
         return;
 
-    ost::MutexLock m(callMapMutex_);
+    sfl::ScopedLock m(iaxCallMapMutex_);
 
-    for (CallMap::iterator iter = callMap_.begin(); iter != callMap_.end(); ++iter) {
-        IAXCall *call = dynamic_cast<IAXCall*>(iter->second);
+    for (IAXCallMap::iterator iter = iaxCallMap_.begin(); iter != iaxCallMap_.end(); ++iter) {
+        IAXCall *call = static_cast<IAXCall*>(iter->second);
 
         if (call) {
-            ost::MutexLock lock(mutexIAX_);
+            sfl::ScopedLock lock(mutexIAX_);
             iax_hangup(call->session, const_cast<char*>("Dumped Call"));
             delete call;
         }
     }
 
-    callMap_.clear();
+    iaxCallMap_.clear();
 
     initDone_ = false;
 }
@@ -108,14 +123,20 @@ IAXVoIPLink::terminate()
 bool
 IAXVoIPLink::getEvent()
 {
-    mutexIAX_.enter();
-    iax_event *event;
+    iax_event *event = NULL;
 
-    while ((event = iax_get_event(0)) != NULL) {
+    {
+        sfl::ScopedLock lock(mutexIAX_);
+        event = iax_get_event(0);
+    }
+
+    while (event != NULL) {
 
         // If we received an 'ACK', libiax2 tells apps to ignore them.
         if (event->etype == IAX_EVENT_NULL) {
+            sfl::ScopedLock lock(mutexIAX_);
             iax_event_free(event);
+            event = iax_get_event(0);
             continue;
         }
 
@@ -123,33 +144,46 @@ IAXVoIPLink::getEvent()
 
         if (call) {
             iaxHandleCallEvent(event, call);
-        }
-        else if (event->session && event->session == regSession_) {
-            iaxHandleRegReply(event);   // This is a registration session, deal with it
-        }
-        else // We've got an event before it's associated with any call
+        } else if (event->session && event->session == regSession_) {
+            // This is a registration session, deal with it
+            iaxHandleRegReply(event);
+        } else {
+            // We've got an event before it's associated with any call
             iaxHandlePrecallEvent(event);
+        }
 
-        iax_event_free(event);
+        {
+            sfl::ScopedLock lock(mutexIAX_);
+            iax_event_free(event);
+            event = iax_get_event(0);
+        }
     }
 
-    mutexIAX_.leave();
-
     if (nextRefreshStamp_ && nextRefreshStamp_ < time(NULL))
-        sendRegister(dynamic_cast<IAXAccount *>(Manager::instance().getAccount(accountID_)));
+        sendRegister(Manager::instance().getIaxAccount(accountID_));
 
     sendAudioFromMic();
 
     // thread wait 3 millisecond
-    ost::Thread::sleep(3);
+    usleep(3000);
     return handlingEvents_;
 }
 
+std::vector<std::string>
+IAXVoIPLink::getCallIDs()
+{
+    std::vector<std::string> v;
+    sfl::ScopedLock m(iaxCallMapMutex_);
+
+    map_utils::vectorFromMapKeys(iaxCallMap_, v);
+    return v;
+}
+
 void
 IAXVoIPLink::sendAudioFromMic()
 {
-    for (CallMap::const_iterator iter = callMap_.begin(); iter != callMap_.end() ; ++iter) {
-        IAXCall *currentCall = dynamic_cast<IAXCall*>(iter->second);
+    for (IAXCallMap::const_iterator iter = iaxCallMap_.begin(); iter != iaxCallMap_.end() ; ++iter) {
+        IAXCall *currentCall = static_cast<IAXCall*>(iter->second);
 
         if (!currentCall or currentCall->getState() != Call::ACTIVE)
             continue;
@@ -160,19 +194,19 @@ IAXVoIPLink::sendAudioFromMic()
         if (!audioCodec)
             continue;
 
-        Manager::instance().getMainBuffer()->setInternalSamplingRate(audioCodec->getClockRate());
+        Manager::instance().getMainBuffer().setInternalSamplingRate(audioCodec->getClockRate());
 
-        unsigned int mainBufferSampleRate = Manager::instance().getMainBuffer()->getInternalSamplingRate();
+        unsigned int mainBufferSampleRate = Manager::instance().getMainBuffer().getInternalSamplingRate();
 
         // we have to get 20ms of data from the mic *20/1000 = /50
         // rate/50 shall be lower than IAX__20S_48KHZ_MAX
         const size_t bytesNeeded = mainBufferSampleRate * 20 / 1000 * sizeof(SFLDataFormat);
 
-        if (Manager::instance().getMainBuffer()->availableForGet(currentCall->getCallId()) < bytesNeeded)
+        if (Manager::instance().getMainBuffer().availableForGet(currentCall->getCallId()) < bytesNeeded)
             continue;
 
         // Get bytes from micRingBuffer to data_from_mic
-        int bytes = Manager::instance().getMainBuffer()->getData(decData_, bytesNeeded, currentCall->getCallId());
+        int bytes = Manager::instance().getMainBuffer().getData(decData_, bytesNeeded, currentCall->getCallId());
         int samples = bytes / sizeof(SFLDataFormat);
 
         int compSize;
@@ -193,7 +227,7 @@ IAXVoIPLink::sendAudioFromMic()
         compSize = audioCodec->encode(encodedData_, in, DEC_BUFFER_SIZE);
 
         if (currentCall->session and bytes > 0) {
-            ost::MutexLock m(mutexIAX_);
+            sfl::ScopedLock m(mutexIAX_);
 
             if (iax_send_voice(currentCall->session, currentCall->format, encodedData_, compSize, outSamples) == -1)
                 ERROR("IAX: Error sending voice data.");
@@ -205,13 +239,13 @@ IAXVoIPLink::sendAudioFromMic()
 IAXCall*
 IAXVoIPLink::getIAXCall(const std::string& id)
 {
-    return dynamic_cast<IAXCall*>(getCall(id));
+    return getIaxCall(id);
 }
 
 void
 IAXVoIPLink::sendRegister(Account *a)
 {
-    IAXAccount *account = dynamic_cast<IAXAccount*>(a);
+    IAXAccount *account = static_cast<IAXAccount*>(a);
 
     if (account->getHostname().empty())
         throw VoipLinkException("Account hostname is empty");
@@ -219,7 +253,7 @@ IAXVoIPLink::sendRegister(Account *a)
     if (account->getUsername().empty())
         throw VoipLinkException("Account username is empty");
 
-    ost::MutexLock m(mutexIAX_);
+    sfl::ScopedLock m(mutexIAX_);
 
     if (regSession_)
         iax_destroy(regSession_);
@@ -237,20 +271,20 @@ void
 IAXVoIPLink::sendUnregister(Account *a)
 {
     if (regSession_) {
-        ost::MutexLock m(mutexIAX_);
+        sfl::ScopedLock m(mutexIAX_);
         iax_destroy(regSession_);
         regSession_ = NULL;
     }
 
     nextRefreshStamp_ = 0;
 
-    dynamic_cast<IAXAccount*>(a)->setRegistrationState(UNREGISTERED);
+    static_cast<IAXAccount*>(a)->setRegistrationState(UNREGISTERED);
 }
 
 Call*
-IAXVoIPLink::newOutgoingCall(const std::string& id, const std::string& toUrl)
+IAXVoIPLink::newOutgoingCall(const std::string& id, const std::string& toUrl, const std::string &account_id)
 {
-    IAXCall* call = new IAXCall(id, Call::OUTGOING);
+    IAXCall* call = new IAXCall(id, Call::OUTGOING, account_id);
 
     call->setPeerNumber(toUrl);
     call->initRecFilename(toUrl);
@@ -258,7 +292,7 @@ IAXVoIPLink::newOutgoingCall(const std::string& id, const std::string& toUrl)
     iaxOutgoingInvite(call);
     call->setConnectionState(Call::PROGRESSING);
     call->setState(Call::ACTIVE);
-    addCall(call);
+    addIaxCall(call);
 
     return call;
 }
@@ -269,33 +303,35 @@ IAXVoIPLink::answer(Call *call)
 {
     Manager::instance().addStream(call->getCallId());
 
-    mutexIAX_.enter();
-    call->answer();
-    mutexIAX_.leave();
+    {
+        sfl::ScopedLock lock(mutexIAX_);
+        call->answer();
+    }
 
     call->setState(Call::ACTIVE);
     call->setConnectionState(Call::CONNECTED);
 
-    Manager::instance().getMainBuffer()->flushAllBuffers();
+    Manager::instance().getMainBuffer().flushAllBuffers();
 }
 
 void
-IAXVoIPLink::hangup(const std::string& id)
+IAXVoIPLink::hangup(const std::string& id, int reason UNUSED)
 {
     IAXCall* call = getIAXCall(id);
 
     if (call == NULL)
         throw VoipLinkException("Could not find call");
 
-    Manager::instance().getMainBuffer()->unBindAll(call->getCallId());
+    Manager::instance().getMainBuffer().unBindAll(call->getCallId());
 
-    mutexIAX_.enter();
-    iax_hangup(call->session, (char*) "Dumped Call");
-    mutexIAX_.leave();
+    {
+        sfl::ScopedLock lock(mutexIAX_);
+        iax_hangup(call->session, (char*) "Dumped Call");
+    }
 
     call->session = NULL;
 
-    removeCall(id);
+    removeIaxCall(id);
 }
 
 
@@ -307,11 +343,11 @@ IAXVoIPLink::peerHungup(const std::string& id)
     if (call == NULL)
         throw VoipLinkException("Could not find call");
 
-    Manager::instance().getMainBuffer()->unBindAll(call->getCallId());
+    Manager::instance().getMainBuffer().unBindAll(call->getCallId());
 
     call->session = NULL;
 
-    removeCall(id);
+    removeIaxCall(id);
 }
 
 
@@ -324,11 +360,12 @@ IAXVoIPLink::onhold(const std::string& id)
     if (call == NULL)
         throw VoipLinkException("Call does not exist");
 
-    Manager::instance().getMainBuffer()->unBindAll(call->getCallId());
+    Manager::instance().getMainBuffer().unBindAll(call->getCallId());
 
-    mutexIAX_.enter();
-    iax_quelch_moh(call->session, true);
-    mutexIAX_.leave();
+    {
+        sfl::ScopedLock lock(mutexIAX_);
+        iax_quelch_moh(call->session, true);
+    }
 
     call->setState(Call::HOLD);
 }
@@ -343,10 +380,12 @@ IAXVoIPLink::offhold(const std::string& id)
 
     Manager::instance().addStream(call->getCallId());
 
-    mutexIAX_.enter();
-    iax_unquelch(call->session);
-    mutexIAX_.leave();
-    Manager::instance().getAudioDriver()->startStream();
+    {
+        sfl::ScopedLock lock(mutexIAX_);
+        iax_unquelch(call->session);
+    }
+
+    Manager::instance().startAudioDriverStream();
     call->setState(Call::ACTIVE);
 }
 
@@ -361,9 +400,10 @@ IAXVoIPLink::transfer(const std::string& id, const std::string& to)
     char callto[to.length() +1];
     strcpy(callto, to.c_str());
 
-    mutexIAX_.enter();
-    iax_transfer(call->session, callto);
-    mutexIAX_.leave();
+    {
+        sfl::ScopedLock lock(mutexIAX_);
+        iax_transfer(call->session, callto);
+    }
 }
 
 bool
@@ -378,11 +418,12 @@ IAXVoIPLink::refuse(const std::string& id)
     IAXCall* call = getIAXCall(id);
 
     if (call) {
-        mutexIAX_.enter();
-        iax_reject(call->session, (char*) "Call rejected manually.");
-        mutexIAX_.leave();
+        {
+            sfl::ScopedLock lock(mutexIAX_);
+            iax_reject(call->session, (char*) "Call rejected manually.");
+        }
 
-        removeCall(id);
+        removeIaxCall(id);
     }
 }
 
@@ -393,9 +434,8 @@ IAXVoIPLink::carryingDTMFdigits(const std::string& id, char code)
     IAXCall* call = getIAXCall(id);
 
     if (call) {
-        mutexIAX_.enter();
+        sfl::ScopedLock lock(mutexIAX_);
         iax_send_dtmf(call->session, code);
-        mutexIAX_.leave();
     }
 }
 
@@ -408,12 +448,57 @@ IAXVoIPLink::sendTextMessage(const std::string& callID,
     IAXCall* call = getIAXCall(callID);
 
     if (call) {
-        ost::MutexLock lock(mutexIAX_);
+        sfl::ScopedLock lock(mutexIAX_);
         sfl::InstantMessaging::send_iax_message(call->session, callID, message.c_str());
     }
 }
 #endif
 
+void
+IAXVoIPLink::clearIaxCallMap()
+{
+    sfl::ScopedLock m(iaxCallMapMutex_);
+
+    for (IAXCallMap::const_iterator iter = iaxCallMap_.begin();
+            iter != iaxCallMap_.end(); ++iter)
+        delete iter->second;
+
+    iaxCallMap_.clear();
+
+}
+
+void
+IAXVoIPLink::addIaxCall(IAXCall* call)
+{
+    if (call and getIaxCall(call->getCallId()) == NULL) {
+        sfl::ScopedLock m(iaxCallMapMutex_);
+        iaxCallMap_[call->getCallId()] = call;
+    }
+}
+
+void
+IAXVoIPLink::removeIaxCall(const std::string& id)
+{
+    sfl::ScopedLock m(iaxCallMapMutex_);
+
+    DEBUG("Removing call %s from list", id.c_str());
+
+    delete iaxCallMap_[id];
+    iaxCallMap_.erase(id);
+}
+
+IAXCall*
+IAXVoIPLink::getIaxCall(const std::string& id)
+{
+    IAXCallMap::iterator iter = iaxCallMap_.find(id);
+
+    if (iter != iaxCallMap_.end())
+
+        return iter->second;
+    else
+        return NULL;
+}
+
 std::string
 IAXVoIPLink::getCurrentVideoCodecName(Call * /*call*/) const
 {
@@ -422,21 +507,21 @@ IAXVoIPLink::getCurrentVideoCodecName(Call * /*call*/) const
 }
 
 std::string
-IAXVoIPLink::getCurrentAudioCodecName(Call *c) const
+IAXVoIPLink::getCurrentAudioCodecNames(Call *c) const
 {
-    IAXCall *call = dynamic_cast<IAXCall*>(c);
-    sfl::Codec *audioCodec = Manager::instance().audioCodecFactory.getCodec(call->getAudioCodec());
+    IAXCall *call = static_cast<IAXCall*>(c);
+    sfl::AudioCodec *audioCodec = Manager::instance().audioCodecFactory.getCodec(call->getAudioCodec());
     return audioCodec ? audioCodec->getMimeSubtype() : "";
 }
 
 void
 IAXVoIPLink::iaxOutgoingInvite(IAXCall* call)
 {
-    ost::MutexLock m(mutexIAX_);
+    sfl::ScopedLock m(mutexIAX_);
 
     call->session = iax_session_new();
 
-    IAXAccount *account = dynamic_cast<IAXAccount *>(Manager::instance().getAccount(accountID_));
+    IAXAccount *account = Manager::instance().getIaxAccount(accountID_);
     std::string username(account->getUsername());
     std::string strNum(username + ":" + account->getPassword() + "@" + account->getHostname() + "/" + call->getPeerNumber());
 
@@ -452,10 +537,10 @@ IAXVoIPLink::iaxOutgoingInvite(IAXCall* call)
 IAXCall*
 IAXVoIPLink::iaxFindCallBySession(iax_session* session)
 {
-    ost::MutexLock m(callMapMutex_);
+    sfl::ScopedLock m(iaxCallMapMutex_);
 
-    for (CallMap::const_iterator iter = callMap_.begin(); iter != callMap_.end(); ++iter) {
-        IAXCall* call = dynamic_cast<IAXCall*>(iter->second);
+    for (IAXCallMap::const_iterator iter = iaxCallMap_.begin(); iter != iaxCallMap_.end(); ++iter) {
+        IAXCall* call = static_cast<IAXCall*>(iter->second);
 
         if (call and call->session == session)
             return call;
@@ -473,14 +558,14 @@ IAXVoIPLink::iaxHandleCallEvent(iax_event* event, IAXCall* call)
         case IAX_EVENT_HANGUP:
             Manager::instance().peerHungupCall(id);
 
-            removeCall(id);
+            removeIaxCall(id);
             break;
 
         case IAX_EVENT_REJECT:
             call->setConnectionState(Call::CONNECTED);
             call->setState(Call::ERROR);
             Manager::instance().callFailure(id);
-            removeCall(id);
+            removeIaxCall(id);
             break;
 
         case IAX_EVENT_ACCEPT:
@@ -506,8 +591,8 @@ IAXVoIPLink::iaxHandleCallEvent(iax_event* event, IAXCall* call)
 
             Manager::instance().peerAnsweredCall(id);
 
-            Manager::instance().getAudioDriver()->startStream();
-            Manager::instance().getMainBuffer()->flushAllBuffers();
+            Manager::instance().startAudioDriverStream();
+            Manager::instance().getMainBuffer().flushAllBuffers();
 
             break;
 
@@ -515,7 +600,7 @@ IAXVoIPLink::iaxHandleCallEvent(iax_event* event, IAXCall* call)
             call->setConnectionState(Call::CONNECTED);
             call->setState(Call::BUSY);
             Manager::instance().callBusy(id);
-            removeCall(id);
+            removeIaxCall(id);
             break;
 
         case IAX_EVENT_VOICE:
@@ -561,8 +646,8 @@ void IAXVoIPLink::iaxHandleVoiceEvent(iax_event* event, IAXCall* call)
     if (!audioCodec)
         return;
 
-    Manager::instance().getMainBuffer()->setInternalSamplingRate(audioCodec->getClockRate());
-    unsigned int mainBufferSampleRate = Manager::instance().getMainBuffer()->getInternalSamplingRate();
+    Manager::instance().getMainBuffer().setInternalSamplingRate(audioCodec->getClockRate());
+    unsigned int mainBufferSampleRate = Manager::instance().getMainBuffer().getInternalSamplingRate();
 
     if (event->subclass)
         call->format = event->subclass;
@@ -587,7 +672,7 @@ void IAXVoIPLink::iaxHandleVoiceEvent(iax_event* event, IAXCall* call)
         out = resampledData_;
     }
 
-    Manager::instance().getMainBuffer()->putData(out, outSize, call->getCallId());
+    Manager::instance().getMainBuffer().putData(out, outSize, call->getCallId());
 }
 
 /**
@@ -595,14 +680,16 @@ void IAXVoIPLink::iaxHandleVoiceEvent(iax_event* event, IAXCall* call)
  */
 void IAXVoIPLink::iaxHandleRegReply(iax_event* event)
 {
-    IAXAccount *account = dynamic_cast<IAXAccount *>(Manager::instance().getAccount(accountID_));
+    IAXAccount *account = Manager::instance().getIaxAccount(accountID_);
 
     if (event->etype != IAX_EVENT_REGREJ && event->etype != IAX_EVENT_REGACK)
         return;
 
-    ost::MutexLock m(mutexIAX_);
-    iax_destroy(regSession_);
-    regSession_ = NULL;
+    {
+        sfl::ScopedLock m(mutexIAX_);
+        iax_destroy(regSession_);
+        regSession_ = NULL;
+    }
 
     account->setRegistrationState((event->etype == IAX_EVENT_REGREJ) ? ERROR_AUTH : REGISTERED);
 
@@ -620,7 +707,7 @@ void IAXVoIPLink::iaxHandlePrecallEvent(iax_event* event)
         case IAX_EVENT_CONNECT:
             id = Manager::instance().getNewCallID();
 
-            call = new IAXCall(id, Call::INCOMING);
+            call = new IAXCall(id, Call::INCOMING, accountID_);
             call->session = event->session;
             call->setConnectionState(Call::PROGRESSING);
 
@@ -631,7 +718,8 @@ void IAXVoIPLink::iaxHandlePrecallEvent(iax_event* event)
                 call->setDisplayName(std::string(event->ies.calling_name));
 
             // if peerNumber exist append it to the name string
-            call->initRecFilename(std::string(event->ies.calling_number));
+            if (event->ies.calling_number)
+                call->initRecFilename(std::string(event->ies.calling_number));
             Manager::instance().incomingCall(*call, accountID_);
 
             format = call->getFirstMatchingFormat(event->ies.format, accountID_);
@@ -641,15 +729,19 @@ void IAXVoIPLink::iaxHandlePrecallEvent(iax_event* event)
 
             iax_accept(event->session, format);
             iax_ring_announce(event->session);
-            addCall(call);
+            addIaxCall(call);
             call->format = format;
 
             break;
 
         case IAX_EVENT_HANGUP:
-            id = iaxFindCallBySession(event->session)->getCallId();
-            Manager::instance().peerHungupCall(id);
-            removeCall(id);
+            call = iaxFindCallBySession(event->session);
+
+            if (call) {
+                id = call->getCallId();
+                Manager::instance().peerHungupCall(id);
+                removeIaxCall(id);
+            }
             break;
 
         case IAX_EVENT_TIMEOUT: // timeout for an unknown session
@@ -663,3 +755,10 @@ void IAXVoIPLink::iaxHandlePrecallEvent(iax_event* event)
             break;
     }
 }
+
+void
+IAXVoIPLink::unloadAccountMap()
+{
+    std::for_each(iaxAccountMap_.begin(), iaxAccountMap_.end(), unloadAccount);
+    iaxAccountMap_.clear();
+}
