@@ -16,7 +16,7 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301 USA.
  *
  *  Additional permission under GNU GPL version 3 section 7:
  *
@@ -149,8 +149,12 @@ int main(int argc, char *argv [])
     if (parse_args(argc, argv))
         return 0;
 
-    if (!fileutils::create_pidfile())
+    fileutils::FileHandle f(fileutils::create_pidfile());
+    if (f.fd == -1) {
+        std::cerr << "An " PACKAGE_NAME <<
+            " instance is already running, quitting..." << std::endl;
         return 1;
+    }
 
     try {
         Manager::instance().init("");
