@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 2004, 2005, 2006, 2008, 2009, 2010, 2011 Savoir-Faire Linux Inc.
+ *  Copyright (C) 2004-2012 Savoir-Faire Linux Inc.
  *  Author: Yan Morin <yan.morin@savoirfairelinux.com>
  *  Author: Laurielle Lea <laurielle.lea@savoirfairelinux.com>
  *  Author: Emmanuel Milou <emmanuel.milou@savoirfairelinux.com>
@@ -18,7 +18,7 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301 USA.
  *
  *  Additional permission under GNU GPL version 3 section 7:
  *
@@ -44,19 +44,22 @@
 #include <set>
 #include <map>
 #include <tr1/memory>
-#include "cc_thread.h"
+
+#include <pthread.h>
 #include "dbus/dbusmanager.h"
 
 #include "config/sfl_config.h"
 
+#include "account.h"
+
 #include "call.h"
 #include "conference.h"
 
 #include "audio/audiolayer.h"
 #include "audio/sound/tone.h"  // for Tone::TONEID declaration
 #include "audio/codecs/audiocodecfactory.h"
-
 #include "audio/mainbuffer.h"
+
 #include "preferences.h"
 #include "history/history.h"
 #include "noncopyable.h"
@@ -79,12 +82,7 @@ class DNSService;
 
 class Account;
 class SIPAccount;
-
-/** Define a type for a AccountMap container */
-typedef std::map<std::string, Account*> AccountMap;
-
-/** Define a type for a std::string to std::string Map inside ManagerImpl */
-typedef std::map<std::string, std::string> CallAccountMap;
+class IAXAccount;
 
 /** To send multiple string */
 typedef std::list<std::string> TokenList;
@@ -98,6 +96,7 @@ static const char * const default_conf = "conf";
 class ManagerImpl {
     public:
         ManagerImpl();
+        ~ManagerImpl();
 
         /**
          * General preferences configuration
@@ -109,11 +108,6 @@ class ManagerImpl {
          */
         VoipPreference voipPreferences;
 
-        /**
-         * Addressbook related preferences
-         */
-        AddressbookPreference addressbookPreference;
-
         /**
          * Hook preferences
          */
@@ -154,6 +148,8 @@ class ManagerImpl {
             return audiodriver_;
         }
 
+        void startAudioDriverStream();
+
         /**
          * Functions which occur with a user's action
          * Place a new call
@@ -178,7 +174,7 @@ class ManagerImpl {
          * Hangup the call
          * @param id  The call identifier
          */
-        void hangupCall(const std::string& id);
+        bool hangupCall(const std::string& id);
 
 
         /**
@@ -193,14 +189,14 @@ class ManagerImpl {
          * Put the call on hold
          * @param id  The call identifier
          */
-        void onHoldCall(const std::string& id);
+        bool onHoldCall(const std::string& id);
 
         /**
          * Functions which occur with a user's action
          * Put the call off hold
          * @param id  The call identifier
          */
-        void offHoldCall(const std::string& id);
+        bool offHoldCall(const std::string& id);
 
         /**
          * Functions which occur with a user's action
@@ -232,7 +228,7 @@ class ManagerImpl {
          * Refuse the call
          * @param id  The call identifier
          */
-        void refuseCall(const std::string& id);
+        bool refuseCall(const std::string& id);
 
         /**
          * Create a new conference given two participant
@@ -257,13 +253,13 @@ class ManagerImpl {
          * Hold every participant to a conference
          * @param the conference id
          */
-        void holdConference(const std::string& conference_id);
+        bool holdConference(const std::string& conference_id);
 
         /**
          * Unhold all conference participants
          * @param the conference id
          */
-        void unHoldConference(const std::string& conference_id);
+        bool unHoldConference(const std::string& conference_id);
 
         /**
          * Test if this id is a conference (usefull to test current call)
@@ -282,20 +278,21 @@ class ManagerImpl {
          * @param the call id
          * @param the conference id
          */
-        void addParticipant(const std::string& call_id, const std::string& conference_id);
+        bool addParticipant(const std::string& call_id, const std::string& conference_id);
 
         /**
          * Bind the main participant to a conference (mainly called on a double click action)
          * @param the conference id
          */
-        void addMainParticipant(const std::string& conference_id);
+        bool addMainParticipant(const std::string& conference_id);
 
         /**
          * Join two participants to create a conference
          * @param the fist call id
          * @param the second call id
          */
-        void joinParticipant(const std::string& call_id1, const std::string& call_id2);
+        bool joinParticipant(const std::string& call_id1,
+                             const std::string& call_id2);
 
         /**
          * Create a conference from a list of participant
@@ -308,7 +305,7 @@ class ManagerImpl {
          * @param call id
          * @param the current call id
          */
-        void detachParticipant(const std::string& call_id, const std::string& current_call_id);
+        bool detachParticipant(const std::string& call_id);
 
         /**
          * Remove the conference participant from a conference
@@ -319,7 +316,7 @@ class ManagerImpl {
         /**
          * Join two conference together into one unique conference
          */
-        void joinConference(const std::string& conf_id1, const std::string& conf_id2);
+        bool joinConference(const std::string& conf_id1, const std::string& conf_id2);
 
         void addStream(const std::string& call_id);
 
@@ -358,8 +355,7 @@ class ManagerImpl {
         void stopTone();
 
         /**
-         * When receiving a new incoming call, add it to the callaccount map
-         * and notify user
+         * Handle incoming call and notify user
          * @param call A call pointer
          * @param accountId an account id
          */
@@ -581,23 +577,6 @@ class ManagerImpl {
          */
         void setEchoCancelState(const std::string &state);
 
-        int getEchoCancelTailLength() const;
-
-        void setEchoCancelTailLength(int);
-
-        int getEchoCancelDelay() const;
-
-        void setEchoCancelDelay(int);
-
-        /**
-         * Convert a list of payload in a special format, readable by the server.
-         * Required format: payloads separated with one slash.
-         * @return std::string The serializabled string
-         */
-        static std::string join_string(const std::vector<std::string> &v);
-
-        static std::vector<std::string> split_string(std::string v);
-
         /**
          * Ringtone option.
          * If ringtone is enabled, ringtone on incoming call use custom choice. If not, only standart tone.
@@ -612,18 +591,6 @@ class ManagerImpl {
          */
         void ringtoneEnabled(const std::string& id);
 
-        /**
-         * Get the recording path from configuration tree
-         * @return the string correspoding to the path
-         */
-        std::string getRecordPath() const;
-
-        /**
-         * Set the recoding path in the configuration tree
-         * @param a string reresenting the path
-         */
-        void setRecordPath(const std::string& recPath);
-
         /**
          * Get is always recording functionality
          */
@@ -686,32 +653,6 @@ class ManagerImpl {
          */
         void startHidden();
 
-        /**
-         * Set the desktop mail notification level
-         */
-        void setMailNotify();
-
-
-        /**
-         * Addressbook configuration
-         */
-        std::map<std::string, int32_t> getAddressbookSettings() const;
-
-        /**
-         * Addressbook configuration
-         */
-        void setAddressbookSettings(const std::map<std::string, int32_t>& settings);
-
-        /**
-         * Addressbook list
-         */
-        void setAddressbookList(const std::vector<  std::string >& list);
-
-        /**
-         * Addressbook list
-         */
-        std::vector <std::string> getAddressbookList() const;
-
         /**
          * Get the audio manager
          * @return int The audio manager
@@ -733,12 +674,6 @@ class ManagerImpl {
          */
         void audioSamplingRateChanged(int);
 
-        /**
-         * Get the desktop mail notification level
-         * @return int The mail notification level
-         */
-        int32_t getMailNotify() const;
-
         /**
          * Change a specific value in the configuration tree.
          * This value will then be saved in the user config file sflphonedrc
@@ -842,14 +777,6 @@ class ManagerImpl {
 
         void initAudioDriver();
 
-        void audioLayerMutexLock() {
-            audioLayerMutex_.enterMutex();
-        }
-
-        void audioLayerMutexUnlock() {
-            audioLayerMutex_.leaveMutex();
-        }
-
         /**
          * Load the accounts order set by the user from the sflphonedrc config file
          * @return std::vector<std::string> A vector containing the account ID's
@@ -916,7 +843,7 @@ class ManagerImpl {
         std::string currentCallId_;
 
         /** Protected current call access */
-        ost::Mutex currentCallMutex_;
+        pthread_mutex_t currentCallMutex_;
 
         /** Audio layer */
         AudioLayer* audiodriver_;
@@ -927,7 +854,7 @@ class ManagerImpl {
         /////////////////////
         // Protected by Mutex
         /////////////////////
-        ost::Mutex toneMutex_;
+        pthread_mutex_t toneMutex_;
         std::tr1::shared_ptr<TelephoneTone> telephoneTone_;
         std::tr1::shared_ptr<AudioFile> audiofile_;
 
@@ -939,7 +866,7 @@ class ManagerImpl {
         /**
          * Mutex used to protect audio layer
          */
-        ost::Mutex audioLayerMutex_;
+        pthread_mutex_t audioLayerMutex_;
 
         /**
          * Waiting Call Vectors
@@ -949,7 +876,7 @@ class ManagerImpl {
         /**
          * Protect waiting call list, access by many voip/audio threads
          */
-        ost::Mutex waitingCallMutex_;
+        pthread_mutex_t waitingCallMutex_;
 
         /**
          * Number of waiting call, synchronize with waitingcall callidvector
@@ -985,35 +912,19 @@ class ManagerImpl {
         DNSService *DNSService_;
 #endif
 
-        /** Map to associate a CallID to the good account */
-        CallAccountMap callAccountMap_;
-
-        /** Mutex to lock the call account map (main thread + voiplink thread) */
-        ost::Mutex callAccountMapMutex_;
-
         std::map<std::string, bool> IPToIPMap_;
 
-
         bool isIPToIP(const std::string& callID) const;
 
-        /**
-         *Contains a list of account (sip, aix, etc) and their respective voiplink/calls */
-        AccountMap accountMap_;
-
         /**
          * Load the account map from configuration
          */
-        void loadAccountMap(Conf::YamlParser &parser);
+        int loadAccountMap(Conf::YamlParser &parser);
         /**
          * Load default account map (no configuration)
          */
         void loadDefaultAccountMap();
 
-        /**
-         * Unload the account (delete them)
-         */
-        void unloadAccountMap();
-
         /**
          * Instance of the MainBuffer for the whole application
          *
@@ -1027,14 +938,6 @@ class ManagerImpl {
 
         void setIPToIPForCall(const std::string& callID, bool IPToIP);
 
-        /** Associate a new std::string to a std::string
-         * Protected by mutex
-         * @param callID the new CallID not in the list yet
-         * @param accountID the known accountID present in accountMap
-         * @return bool True if the new association is create
-         */
-        void associateCallToAccount(const std::string& callID, const std::string& accountID);
-
         /**
          * Test if call is a valid call, i.e. have been created and stored in
          * call-account map
@@ -1046,8 +949,8 @@ class ManagerImpl {
         /**
          * Return a pointer to the  instance of the mainbuffer
          */
-        MainBuffer *getMainBuffer() {
-            return &mainBuffer_;
+        MainBuffer &getMainBuffer() {
+            return mainBuffer_;
         }
 
         /**
@@ -1082,12 +985,33 @@ class ManagerImpl {
         void clearHistory();
 
         /**
-         * Get an account pointer
+         * Get an account pointer, looks for both SIP and IAX
          * @param accountID account ID to get
          * @return Account*	 The account pointer or 0
          */
-        Account* getAccount(const std::string& accountID);
-        SIPAccount* getIP2IPAccount();
+        Account* getAccount(const std::string& accountID) const;
+
+        /**
+         * Get a SIP account pointer
+         * @param accountID account ID to get
+         * @return SIPAccount* The account pointer or 0
+         */
+        SIPAccount *getSipAccount(const std::string& accontID) const;
+
+#if HAVE_IAX
+        /**
+         * Get an IAX account pointer
+         * @param accountID account ID to get
+         * @return IAXAccount* The account pointer or 0
+         */
+        IAXAccount *getIaxAccount(const std::string& accountID) const;
+#endif
+
+	/**
+         * Get a pointer to the IP2IP account
+         * @return SIPAccount * Pointer to the IP2IP account
+         */
+        SIPAccount *getIP2IPAccount() const;
 
         /** Return the std::string from a CallID
          * Protected by mutex
@@ -1103,8 +1027,6 @@ class ManagerImpl {
          */
         VoIPLink* getAccountLink(const std::string& accountID);
 
-        std::string getAccountIdFromNameAndServer(const std::string& userName, const std::string& server) const;
-
         std::string getStunServer() const;
         void setStunServer(const std::string &server);
 
@@ -1123,11 +1045,19 @@ class ManagerImpl {
     private:
         NON_COPYABLE(ManagerImpl);
 
+        /**
+         * Get a map with all the current SIP and IAX accounts
+         */
+        AccountMap getAllAccounts() const;
+
+        void
+        checkAudio();
+
         /**
           * To handle the persistent history
           * TODO: move this to ConfigurationManager
           */
-        History history_;
+        sfl::History history_;
         bool finished_;
 };
 #endif // MANAGER_IMPL_H_
