@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 2004, 2005, 2006, 2008, 2009, 2010, 2011 Savoir-Faire Linux Inc.
+ *  Copyright (C) 2004-2012 Savoir-Faire Linux Inc.
  *
  *  Author: Emmanuel Milou <emmanuel.milou@savoirfairelinux.com>
  *
@@ -15,7 +15,7 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301 USA.
  *
  *  Additional permission under GNU GPL version 3 section 7:
  *
@@ -45,7 +45,7 @@ void strip_chars(const std::string &to_strip, std::string &num)
 
 std::string NumberCleaner::clean(std::string to_clean, const std::string &prefix)
 {
-   int pos;
+   size_t pos;
    //Hostname and DNS can have '-'
    if ((pos = to_clean.find("@")) == std::string::npos) {
       strip_chars(INVALID_CHAR, to_clean);
