@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 2004, 2005, 2006, 2008, 2009, 2010, 2011 Savoir-Faire Linux Inc.
+ *  Copyright (C) 2004-2012 Savoir-Faire Linux Inc.
  *  Author: Alexandre Savard <alexandre.savard@savoirfairelinux.com>
  *
  *  This program is free software; you can redistribute it and/or modify
@@ -14,7 +14,7 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301 USA.
  *
  *  Additional permission under GNU GPL version 3 section 7:
  *
@@ -28,6 +28,10 @@
  *  as that of the covered work.
  */
 
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
+
 #include "preferences.h"
 #include "logger.h"
 #include "audio/alsa/alsalayer.h"
@@ -40,7 +44,7 @@
 #include "sip/sip_utils.h"
 #include <sstream>
 #include "global.h"
-#include "config.h"
+#include "fileutils.h"
 
 const char * const Preferences::DFT_ZONE = "North America";
 const char * const Preferences::REGISTRATION_EXPIRE_KEY = "registrationexpire";
@@ -51,7 +55,6 @@ static const char * const ORDER_KEY = "order";
 static const char * const AUDIO_API_KEY = "audioApi";
 static const char * const HISTORY_LIMIT_KEY = "historyLimit";
 static const char * const HISTORY_MAX_CALLS_KEY = "historyMaxCalls";
-static const char * const NOTIFY_MAILS_KEY = "notifyMails";
 static const char * const ZONE_TONE_CHOICE_KEY = "zoneToneChoice";
 static const char * const PORT_NUM_KEY = "portNum";
 static const char * const SEARCH_BAR_DISPLAY_KEY = "searchBarDisplay";
@@ -65,15 +68,6 @@ static const char * const PULSE_LENGTH_KEY = "pulseLength";
 static const char * const SYMMETRIC_RTP_KEY = "symmetric";
 static const char * const ZID_FILE_KEY = "zidFile";
 
-// addressbook preferences
-static const char * const PHOTO_KEY = "photo";
-static const char * const ENABLED_KEY = "enabled";
-static const char * const LIST_KEY = "list";
-static const char * const MAX_RESULTS_KEY = "maxResults";
-static const char * const BUSINESS_KEY = "business";
-static const char * const HOME_KEY = "home";
-static const char * const MOBILE_KEY = "mobile";
-
 // hooks preferences
 static const char * const IAX2_ENABLED_KEY = "iax2Enabled";
 static const char * const NUMBER_ADD_PREFIX_KEY = "numberAddPrefix";
@@ -101,8 +95,6 @@ static const char * const VOLUMEMIC_KEY = "volumeMic";
 static const char * const VOLUMESPKR_KEY = "volumeSpkr";
 static const char * const NOISE_REDUCE_KEY = "noiseReduce";
 static const char * const ECHO_CANCEL_KEY = "echoCancel";
-static const char * const ECHO_TAIL_KEY = "echoTailLength";
-static const char * const ECHO_DELAY_KEY = "echoDelayLength";
 
 // shortcut preferences
 static const char * const HANGUP_SHORT_KEY = "hangUp";
@@ -122,7 +114,6 @@ Preferences::Preferences() :
     accountOrder_("")
     , historyLimit_(30)
     , historyMaxCalls_(20)
-    , notifyMails_(false)
     , zoneToneChoice_(DFT_ZONE) // DFT_ZONE
     , registrationExpire_(180)
     , portNum_(5060)
@@ -142,7 +133,6 @@ void Preferences::serialize(Conf::YamlEmitter &emiter)
     std::stringstream histmaxstr;
     histmaxstr << historyMaxCalls_;
     Conf::ScalarNode historyMaxCalls(histmaxstr.str());
-    Conf::ScalarNode notifyMails(notifyMails_);
     Conf::ScalarNode zoneToneChoice(zoneToneChoice_);
     std::stringstream expirestr;
     expirestr << registrationExpire_;
@@ -157,7 +147,6 @@ void Preferences::serialize(Conf::YamlEmitter &emiter)
     preferencemap.setKeyValue(ORDER_KEY, &order);
     preferencemap.setKeyValue(HISTORY_LIMIT_KEY, &historyLimit);
     preferencemap.setKeyValue(HISTORY_MAX_CALLS_KEY, &historyMaxCalls);
-    preferencemap.setKeyValue(NOTIFY_MAILS_KEY, &notifyMails);
     preferencemap.setKeyValue(ZONE_TONE_CHOICE_KEY, &zoneToneChoice);
     preferencemap.setKeyValue(REGISTRATION_EXPIRE_KEY, &registrationExpire);
     preferencemap.setKeyValue(PORT_NUM_KEY, &portNum);
@@ -168,12 +157,11 @@ void Preferences::serialize(Conf::YamlEmitter &emiter)
     emiter.serializePreference(&preferencemap, "preferences");
 }
 
-void Preferences::unserialize(const Conf::MappingNode &map)
+void Preferences::unserialize(const Conf::YamlNode &map)
 {
     map.getValue(ORDER_KEY, &accountOrder_);
     map.getValue(HISTORY_LIMIT_KEY, &historyLimit_);
     map.getValue(HISTORY_MAX_CALLS_KEY, &historyMaxCalls_);
-    map.getValue(NOTIFY_MAILS_KEY, &notifyMails_);
     map.getValue(ZONE_TONE_CHOICE_KEY, &zoneToneChoice_);
     map.getValue(REGISTRATION_EXPIRE_KEY, &registrationExpire_);
     map.getValue(PORT_NUM_KEY, &portNum_);
@@ -211,7 +199,7 @@ void VoipPreference::serialize(Conf::YamlEmitter &emitter)
     emitter.serializePreference(&preferencemap, "voipPreferences");
 }
 
-void VoipPreference::unserialize(const Conf::MappingNode &map)
+void VoipPreference::unserialize(const Conf::YamlNode &map)
 {
     map.getValue(PLAY_DTMF_KEY, &playDtmf_);
     map.getValue(PLAY_TONES_KEY, &playTones_);
@@ -220,51 +208,6 @@ void VoipPreference::unserialize(const Conf::MappingNode &map)
     map.getValue(ZID_FILE_KEY, &zidFile_);
 }
 
-AddressbookPreference::AddressbookPreference() : photo_(true)
-    , enabled_(true)
-    , list_("")
-    , maxResults_(25)
-    , business_(true)
-    , home_(true)
-    , mobile_(true)
-{}
-
-void AddressbookPreference::serialize(Conf::YamlEmitter &emitter)
-{
-    Conf::MappingNode preferencemap(NULL);
-
-    Conf::ScalarNode photo(photo_);
-    Conf::ScalarNode enabled(enabled_);
-    Conf::ScalarNode list(list_);
-    std::stringstream maxresultstr;
-    maxresultstr << maxResults_;
-    Conf::ScalarNode maxResults(maxresultstr.str());
-    Conf::ScalarNode business(business_);
-    Conf::ScalarNode home(home_);
-    Conf::ScalarNode mobile(mobile_);
-
-    preferencemap.setKeyValue(PHOTO_KEY, &photo);
-    preferencemap.setKeyValue(ENABLED_KEY, &enabled);
-    preferencemap.setKeyValue(LIST_KEY, &list);
-    preferencemap.setKeyValue(MAX_RESULTS_KEY, &maxResults);
-    preferencemap.setKeyValue(BUSINESS_KEY, &business);
-    preferencemap.setKeyValue(HOME_KEY, &home);
-    preferencemap.setKeyValue(MOBILE_KEY, &mobile);
-
-    emitter.serializePreference(&preferencemap, "addressbook");
-}
-
-void AddressbookPreference::unserialize(const Conf::MappingNode &map)
-{
-    map.getValue(PHOTO_KEY, &photo_);
-    map.getValue(ENABLED_KEY, &enabled_);
-    map.getValue(LIST_KEY, &list_);
-    map.getValue(MAX_RESULTS_KEY, &maxResults_);
-    map.getValue(BUSINESS_KEY, &business_);
-    map.getValue(HOME_KEY, &home_);
-    map.getValue(MOBILE_KEY, &mobile_);
-}
-
 HookPreference::HookPreference() :
     iax2Enabled_(false)
     , numberAddPrefix_("")
@@ -317,7 +260,7 @@ void HookPreference::serialize(Conf::YamlEmitter &emitter)
     emitter.serializePreference(&preferencemap, "hooks");
 }
 
-void HookPreference::unserialize(const Conf::MappingNode &map)
+void HookPreference::unserialize(const Conf::YamlNode &map)
 {
     map.getValue(IAX2_ENABLED_KEY, &iax2Enabled_);
     map.getValue(NUMBER_ADD_PREFIX_KEY, &numberAddPrefix_);
@@ -349,10 +292,8 @@ AudioPreference::AudioPreference() :
     , alwaysRecording_(false)
     , volumemic_(atoi(DFT_VOL_SPKR_STR))
     , volumespkr_(atoi(DFT_VOL_MICRO_STR))
-    , noisereduce_(true)
+    , noisereduce_(false)
     , echocancel_(false)
-    , echoCancelTailLength_(100)
-    , echoCancelDelay_(0)
 {}
 
 namespace {
@@ -429,12 +370,6 @@ void AudioPreference::serialize(Conf::YamlEmitter &emitter)
     Conf::ScalarNode volumespkr(spkrstr.str()); //: 100
     Conf::ScalarNode noise(noisereduce_);
     Conf::ScalarNode echo(echocancel_);
-    std::stringstream tailstr;
-    tailstr << echoCancelTailLength_;
-    Conf::ScalarNode echotail(tailstr.str());
-    std::stringstream delaystr;
-    delaystr << echoCancelDelay_;
-    Conf::ScalarNode echodelay(delaystr.str());
 
     Conf::MappingNode preferencemap(NULL);
     preferencemap.setKeyValue(AUDIO_API_KEY, &audioapi);
@@ -461,16 +396,30 @@ void AudioPreference::serialize(Conf::YamlEmitter &emitter)
 
     preferencemap.setKeyValue(NOISE_REDUCE_KEY, &noise);
     preferencemap.setKeyValue(ECHO_CANCEL_KEY, &echo);
-    preferencemap.setKeyValue(ECHO_TAIL_KEY, &echotail);
-    preferencemap.setKeyValue(ECHO_DELAY_KEY, &echodelay);
 
     emitter.serializePreference(&preferencemap, "audio");
 }
 
-void AudioPreference::unserialize(const Conf::MappingNode &map)
+bool
+AudioPreference::setRecordPath(const std::string &r)
+{
+    if (fileutils::isDirectoryWritable(r)) {
+        recordpath_ = r;
+        return true;
+    } else {
+        ERROR("%s is not writable, cannot be the recording path", r.c_str());
+        return false;
+    }
+}
+
+void AudioPreference::unserialize(const Conf::YamlNode &map)
 {
     map.getValue(AUDIO_API_KEY, &audioApi_);
-    map.getValue(RECORDPATH_KEY, &recordpath_);
+    std::string tmpRecordPath;
+    map.getValue(RECORDPATH_KEY, &tmpRecordPath);
+    if (not setRecordPath(tmpRecordPath))
+        setRecordPath(fileutils::get_home_dir());
+
     map.getValue(ALWAYS_RECORDING_KEY, &alwaysRecording_);
     map.getValue(VOLUMEMIC_KEY, &volumemic_);
     map.getValue(VOLUMESPKR_KEY, &volumespkr_);
@@ -543,7 +492,7 @@ void ShortcutPreferences::serialize(Conf::YamlEmitter &emitter)
     emitter.serializePreference(&preferencemap, "shortcuts");
 }
 
-void ShortcutPreferences::unserialize(const Conf::MappingNode &map)
+void ShortcutPreferences::unserialize(const Conf::YamlNode &map)
 {
     map.getValue(HANGUP_SHORT_KEY, &hangup_);
     map.getValue(PICKUP_SHORT_KEY, &pickup_);
