@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 2004, 2005, 2006, 2008, 2009, 2010, 2011 Savoir-Faire Linux Inc.
+ *  Copyright (C) 2004-2012 Savoir-Faire Linux Inc.
  *  Author: Emmanuel Milou <emmanuel.milou@savoirfairelinux.com>
  *  Author: Alexandre Savard <alexandre.savard@savoirfairelinux.com>
  *
@@ -15,7 +15,7 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301 USA.
  *
  *  Additional permission under GNU GPL version 3 section 7:
  *
@@ -49,7 +49,6 @@
 
 namespace sfl {
 class AudioCodec;
-class Codec;
 }
 
 class SdpException : public std::runtime_error {
@@ -164,13 +163,17 @@ class Sdp {
         }
 
         void setLocalPublishedAudioPort(int port) {
-            localAudioPort_ = port;
+            localAudioDataPort_ = port;
+            localAudioControlPort_ = port + 1;
         }
 
         void setLocalPublishedVideoPort (int port) {
-            localVideoPort_ = port;
+            localVideoDataPort_ = port;
+            localVideoControlPort_ = port + 1;
         }
 
+        void updatePorts(const std::vector<pj_sockaddr_in> &sockets);
+
         /**
          * Return IP of destination
          * @return const std:string	The remote IP address
@@ -203,6 +206,10 @@ class Sdp {
             return remoteVideoPort_;
         }
 
+        unsigned int getLocalVideoPort() const {
+            return localVideoDataPort_;
+        }
+
         void addAttributeToLocalAudioMedia(const char *attr);
         void removeAttributeFromLocalAudioMedia(const char *attr);
         void addAttributeToLocalVideoMedia(const char *attr);
@@ -239,9 +246,9 @@ class Sdp {
 
         void setMediaTransportInfoFromRemoteSdp();
 
-        std::string getAudioCodecName() const;
+        std::string getAudioCodecNames() const;
         std::string getSessionVideoCodec() const;
-        sfl::AudioCodec* getSessionAudioMedia() const;
+        void getSessionAudioMedia(std::vector<sfl::AudioCodec*> &) const;
         // Sets @param settings with appropriate values and returns true if
         // we are sending video, false otherwise
         bool getOutgoingVideoSettings(std::map<std::string, std::string> &settings) const;
@@ -255,6 +262,7 @@ class Sdp {
         std::string getOutgoingVideoField(const std::string &codec, const char *key) const;
         int getOutgoingVideoPayload() const;
         void getProfileLevelID(const pjmedia_sdp_session *session, std::string &dest, int payload) const;
+        void updateRemoteIP(unsigned index);
 
         /**
          * The pool to allocate memory, ownership to SipCall
@@ -292,20 +300,22 @@ class Sdp {
         /**
          * Codec Map used for offer
          */
-        std::vector<sfl::Codec *> audio_codec_list_;
+        std::vector<sfl::AudioCodec *> audio_codec_list_;
         std::vector<std::map<std::string, std::string> > video_codec_list_;
 
         /**
          * The codecs that will be used by the session (after the SDP negotiation)
          */
-        std::vector<sfl::Codec *> sessionAudioMedia_;
+        std::vector<sfl::AudioCodec *> sessionAudioMedia_;
         std::vector<std::string> sessionVideoMedia_;
 
         std::string localIpAddr_;
         std::string remoteIpAddr_;
 
-        int localAudioPort_;
-        int localVideoPort_;
+        int localAudioDataPort_;
+        int localAudioControlPort_;
+        int localVideoDataPort_;
+        int localVideoControlPort_;
         unsigned int remoteAudioPort_;
         unsigned int remoteVideoPort_;
 
@@ -322,7 +332,7 @@ class Sdp {
          * Build the sdp media section
          * Add rtpmap field if necessary
          */
-        pjmedia_sdp_media *setMediaDescriptorLine(bool audio);
+        pjmedia_sdp_media *setMediaDescriptorLines(bool audio);
 
         void setTelephoneEventRtpmap(pjmedia_sdp_media *med);
 
@@ -356,6 +366,8 @@ class Sdp {
          * @throw SdpException
          */
         void addZrtpAttribute(pjmedia_sdp_media* media, std::string hash);
+
+        void addRTCPAttribute(pjmedia_sdp_media *med);
 };
 
 
