@@ -15,7 +15,7 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301 USA.
  *
  *  Additional permission under GNU GPL version 3 section 7:
  *
@@ -33,11 +33,11 @@
 #define SIP_UTILS_H_
 
 #include <string>
-#include <list>
+#include <vector>
 
 #include <pjsip/sip_msg.h>
 
-class pjsip_msg;
+struct pjsip_msg;
 
 namespace sip_utils {
     /**
@@ -46,14 +46,14 @@ namespace sip_utils {
      */
     std::string fetchHeaderValue(pjsip_msg *msg, const std::string &field);
 
-    pjsip_route_hdr *createRouteSet(const std::string &route, pj_pool_t *hdr_pool);
+    pjsip_route_hdr *
+    createRouteSet(const std::string &route, pj_pool_t *hdr_pool);
 
     void stripSipUriPrefix(std::string& sipUri);
 
     std::string parseDisplayName(const char * buffer);
 
-    std::string resolveDns(const std::string &url);
-    std::list<std::string> resolveServerDns(const std::string &server);
+    std::vector<std::string> getIPList(const std::string &name);
 }
 
 #endif // SIP_UTILS_H_
