@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 2004, 2005, 2006, 2008, 2009, 2010, 2011 Savoir-Faire Linux Inc.
+ *  Copyright (C) 2004-2012 Savoir-Faire Linux Inc.
 *
 *  Author: Emmanuel Milou <emmanuel.milou@savoirfairelinux.com>
 *  Author: Pierre-Luc Bacon <pierre-luc.bacon@savoirfairelinux.com>
@@ -16,7 +16,7 @@
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
-*   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+*  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301 USA.
  *
  *  Additional permission under GNU GPL version 3 section 7:
  *
@@ -54,14 +54,17 @@
 const char * const SIPAccount::IP2IP_PROFILE = "IP2IP";
 const char * const SIPAccount::OVERRTP_STR = "overrtp";
 const char * const SIPAccount::SIPINFO_STR = "sipinfo";
+const char * const SIPAccount::ACCOUNT_TYPE = "SIP";
 
 namespace {
     const int MIN_REGISTRATION_TIME = 60;
     const int DEFAULT_REGISTRATION_TIME = 3600;
+    const char *const TRUE_STR = "true";
+    const char *const FALSE_STR = "false";
 }
 
 SIPAccount::SIPAccount(const std::string& accountID)
-    : Account(accountID, "SIP")
+    : Account(accountID)
     , transport_(NULL)
     , credentials_()
     , regc_(NULL)
@@ -78,12 +81,10 @@ SIPAccount::SIPAccount(const std::string& accountID)
     , cred_()
     , tlsSetting_()
     , ciphers(100)
-    , contactHeader_()
-    , contactUpdateEnabled_(false)
     , stunServerName_()
     , stunPort_(PJ_STUN_PORT)
     , dtmfType_(OVERRTP_STR)
-    , tlsEnable_("false")
+    , tlsEnable_(FALSE_STR)
     , tlsCaListFile_()
     , tlsCertificateFile_()
     , tlsPrivateKeyFile_()
@@ -112,7 +113,12 @@ SIPAccount::SIPAccount(const std::string& accountID)
     , link_(SIPVoIPLink::instance())
     , receivedParameter_("")
     , rPort_(-1)
+    , via_addr_()
 {
+    via_addr_.host.ptr = 0;
+    via_addr_.host.slen = 0;
+    via_addr_.port = 0;
+
     if (isIP2IP())
         alias_ = IP2IP_PROFILE;
 }
@@ -133,7 +139,8 @@ void SIPAccount::serialize(Conf::YamlEmitter &emitter)
     ScalarNode alias(Account::alias_);
     ScalarNode hostname(Account::hostname_);
     ScalarNode enable(enabled_);
-    ScalarNode type(Account::type_);
+    ScalarNode autoAnswer(autoAnswerEnabled_);
+    ScalarNode type(ACCOUNT_TYPE);
     std::stringstream registrationExpireStr;
     registrationExpireStr << registrationExpire_;
     ScalarNode expire(registrationExpireStr.str());
@@ -142,7 +149,6 @@ void SIPAccount::serialize(Conf::YamlEmitter &emitter)
     portstr << localPort_;
     ScalarNode port(portstr.str());
     ScalarNode serviceRoute(serviceRoute_);
-    ScalarNode contactUpdateEnabled(contactUpdateEnabled_);
     ScalarNode keepAliveEnabled(keepAliveEnabled_);
 
     ScalarNode mailbox(mailBox_);
@@ -210,6 +216,7 @@ void SIPAccount::serialize(Conf::YamlEmitter &emitter)
     accountmap.setKeyValue(USERNAME_KEY, &username);
     accountmap.setKeyValue(HOSTNAME_KEY, &hostname);
     accountmap.setKeyValue(ACCOUNT_ENABLE_KEY, &enable);
+    accountmap.setKeyValue(ACCOUNT_AUTOANSWER_KEY, &autoAnswer);
     accountmap.setKeyValue(MAILBOX_KEY, &mailbox);
     accountmap.setKeyValue(Preferences::REGISTRATION_EXPIRE_KEY, &expire);
     accountmap.setKeyValue(INTERFACE_KEY, &interface);
@@ -220,7 +227,6 @@ void SIPAccount::serialize(Conf::YamlEmitter &emitter)
     accountmap.setKeyValue(PUBLISH_PORT_KEY, &publishPort);
     accountmap.setKeyValue(SAME_AS_LOCAL_KEY, &sameasLocal);
     accountmap.setKeyValue(SERVICE_ROUTE_KEY, &serviceRoute);
-    accountmap.setKeyValue(UPDATE_CONTACT_HEADER_KEY, &contactUpdateEnabled);
     accountmap.setKeyValue(DTMF_TYPE_KEY, &dtmfType);
     accountmap.setKeyValue(DISPLAY_NAME_KEY, &displayName);
     accountmap.setKeyValue(AUDIO_CODECS_KEY, &audioCodecs);
@@ -297,7 +303,7 @@ void SIPAccount::serialize(Conf::YamlEmitter &emitter)
 #endif
 }
 
-void SIPAccount::unserialize(const Conf::MappingNode &mapNode)
+void SIPAccount::unserialize(const Conf::YamlNode &mapNode)
 {
     using namespace Conf;
     using std::vector;
@@ -305,14 +311,14 @@ void SIPAccount::unserialize(const Conf::MappingNode &mapNode)
     using std::string;
 
     mapNode.getValue(ALIAS_KEY, &alias_);
-    mapNode.getValue(TYPE_KEY, &type_);
     mapNode.getValue(USERNAME_KEY, &username_);
     if (not isIP2IP()) mapNode.getValue(HOSTNAME_KEY, &hostname_);
     mapNode.getValue(ACCOUNT_ENABLE_KEY, &enabled_);
+    mapNode.getValue(ACCOUNT_AUTOANSWER_KEY, &autoAnswerEnabled_);
     if (not isIP2IP()) mapNode.getValue(MAILBOX_KEY, &mailBox_);
     mapNode.getValue(AUDIO_CODECS_KEY, &audioCodecStr_);
     // Update codec list which one is used for SDP offer
-    setActiveAudioCodecs(ManagerImpl::split_string(audioCodecStr_));
+    setActiveAudioCodecs(split_string(audioCodecStr_));
 #ifdef SFL_VIDEO
     YamlNode *videoCodecsNode(mapNode.getValue(VIDEO_CODECS_KEY));
 
@@ -363,7 +369,6 @@ void SIPAccount::unserialize(const Conf::MappingNode &mapNode)
     dtmfType_ = dtmfType;
 
     if (not isIP2IP()) mapNode.getValue(SERVICE_ROUTE_KEY, &serviceRoute_);
-    mapNode.getValue(UPDATE_CONTACT_HEADER_KEY, &contactUpdateEnabled_);
 
     // stun enabled
     if (not isIP2IP()) mapNode.getValue(STUN_ENABLED_KEY, &stunEnabled_);
@@ -460,17 +465,16 @@ void SIPAccount::unserialize(const Conf::MappingNode &mapNode)
     }
 }
 
-
 void SIPAccount::setAccountDetails(std::map<std::string, std::string> details)
 {
     // Account setting common to SIP and IAX
     alias_ = details[CONFIG_ACCOUNT_ALIAS];
-    type_ = details[CONFIG_ACCOUNT_TYPE];
     username_ = details[CONFIG_ACCOUNT_USERNAME];
     hostname_ = details[CONFIG_ACCOUNT_HOSTNAME];
-    enabled_ = details[CONFIG_ACCOUNT_ENABLE] == "true";
+    enabled_ = details[CONFIG_ACCOUNT_ENABLE] == TRUE_STR;
+    autoAnswerEnabled_ = details[CONFIG_ACCOUNT_AUTOANSWER] == TRUE_STR;
     ringtonePath_ = details[CONFIG_RINGTONE_PATH];
-    ringtoneEnabled_ = details[CONFIG_RINGTONE_ENABLED] == "true";
+    ringtoneEnabled_ = details[CONFIG_RINGTONE_ENABLED] == TRUE_STR;
     mailBox_ = details[CONFIG_ACCOUNT_MAILBOX];
 
     // SIP specific account settings
@@ -479,7 +483,7 @@ void SIPAccount::setAccountDetails(std::map<std::string, std::string> details)
     displayName_ = details[CONFIG_DISPLAY_NAME];
     serviceRoute_ = details[CONFIG_ACCOUNT_ROUTESET];
     interface_ = details[CONFIG_LOCAL_INTERFACE];
-    publishedSameasLocal_ = details[CONFIG_PUBLISHED_SAMEAS_LOCAL] == "true";
+    publishedSameasLocal_ = details[CONFIG_PUBLISHED_SAMEAS_LOCAL] == TRUE_STR;
     publishedIpAddress_ = details[CONFIG_PUBLISHED_ADDRESS];
     localPort_ = atoi(details[CONFIG_LOCAL_PORT].c_str());
     publishedPort_ = atoi(details[CONFIG_PUBLISHED_PORT].c_str());
@@ -488,22 +492,22 @@ void SIPAccount::setAccountDetails(std::map<std::string, std::string> details)
         // pj_stun_sock_destroy(pj_stun_sock *stun_sock);
     }
     stunServer_ = details[CONFIG_STUN_SERVER];
-    stunEnabled_ = details[CONFIG_STUN_ENABLE] == "true";
+    stunEnabled_ = details[CONFIG_STUN_ENABLE] == TRUE_STR;
     dtmfType_ = details[CONFIG_ACCOUNT_DTMF_TYPE];
     registrationExpire_ = atoi(details[CONFIG_ACCOUNT_REGISTRATION_EXPIRE].c_str());
     if(registrationExpire_ < MIN_REGISTRATION_TIME)
         registrationExpire_ = MIN_REGISTRATION_TIME;
 
     userAgent_ = details[CONFIG_ACCOUNT_USERAGENT];
-    keepAliveEnabled_ = details[CONFIG_KEEP_ALIVE_ENABLED] == "true";
+    keepAliveEnabled_ = details[CONFIG_KEEP_ALIVE_ENABLED] == TRUE_STR;
 
     // srtp settings
-    srtpEnabled_ = details[CONFIG_SRTP_ENABLE] == "true";
-    srtpFallback_ = details[CONFIG_SRTP_RTP_FALLBACK] == "true";
-    zrtpDisplaySas_ = details[CONFIG_ZRTP_DISPLAY_SAS] == "true";
-    zrtpDisplaySasOnce_ = details[CONFIG_ZRTP_DISPLAY_SAS_ONCE] == "true";
-    zrtpNotSuppWarning_ = details[CONFIG_ZRTP_NOT_SUPP_WARNING] == "true";
-    zrtpHelloHash_ = details[CONFIG_ZRTP_HELLO_HASH] == "true";
+    srtpEnabled_ = details[CONFIG_SRTP_ENABLE] == TRUE_STR;
+    srtpFallback_ = details[CONFIG_SRTP_RTP_FALLBACK] == TRUE_STR;
+    zrtpDisplaySas_ = details[CONFIG_ZRTP_DISPLAY_SAS] == TRUE_STR;
+    zrtpDisplaySasOnce_ = details[CONFIG_ZRTP_DISPLAY_SAS_ONCE] == TRUE_STR;
+    zrtpNotSuppWarning_ = details[CONFIG_ZRTP_NOT_SUPP_WARNING] == TRUE_STR;
+    zrtpHelloHash_ = details[CONFIG_ZRTP_HELLO_HASH] == TRUE_STR;
     srtpKeyExchange_ = details[CONFIG_SRTP_KEY_EXCHANGE];
 
     // TLS settings
@@ -516,9 +520,9 @@ void SIPAccount::setAccountDetails(std::map<std::string, std::string> details)
     tlsMethod_ = details[CONFIG_TLS_METHOD];
     tlsCiphers_ = details[CONFIG_TLS_CIPHERS];
     tlsServerName_ = details[CONFIG_TLS_SERVER_NAME];
-    tlsVerifyServer_ = details[CONFIG_TLS_VERIFY_SERVER] == "true";
-    tlsVerifyClient_ = details[CONFIG_TLS_VERIFY_CLIENT] == "true";
-    tlsRequireClientCertificate_ = details[CONFIG_TLS_REQUIRE_CLIENT_CERTIFICATE] == "true";
+    tlsVerifyServer_ = details[CONFIG_TLS_VERIFY_SERVER] == TRUE_STR;
+    tlsVerifyClient_ = details[CONFIG_TLS_VERIFY_CLIENT] == TRUE_STR;
+    tlsRequireClientCertificate_ = details[CONFIG_TLS_REQUIRE_CLIENT_CERTIFICATE] == TRUE_STR;
     tlsNegotiationTimeoutSec_ = details[CONFIG_TLS_NEGOTIATION_TIMEOUT_SEC];
     tlsNegotiationTimeoutMsec_ = details[CONFIG_TLS_NEGOTIATION_TIMEOUT_MSEC];
 
@@ -541,13 +545,14 @@ std::map<std::string, std::string> SIPAccount::getAccountDetails() const
     // note: The IP2IP profile will always have IP2IP as an alias
     a[CONFIG_ACCOUNT_ALIAS] = alias_;
 
-    a[CONFIG_ACCOUNT_ENABLE] = enabled_ ? "true" : "false";
-    a[CONFIG_ACCOUNT_TYPE] = type_;
+    a[CONFIG_ACCOUNT_ENABLE] = enabled_ ? TRUE_STR : FALSE_STR;
+    a[CONFIG_ACCOUNT_AUTOANSWER]= autoAnswerEnabled_ ? TRUE_STR : FALSE_STR;
+    a[CONFIG_ACCOUNT_TYPE] = ACCOUNT_TYPE;
     a[CONFIG_ACCOUNT_HOSTNAME] = hostname_;
     a[CONFIG_ACCOUNT_USERNAME] = username_;
 
     a[CONFIG_RINGTONE_PATH] = ringtonePath_;
-    a[CONFIG_RINGTONE_ENABLED] = ringtoneEnabled_ ? "true" : "false";
+    a[CONFIG_RINGTONE_ENABLED] = ringtoneEnabled_ ? TRUE_STR : FALSE_STR;
     a[CONFIG_ACCOUNT_MAILBOX] = mailBox_;
 
     RegistrationState state = UNREGISTERED;
@@ -577,7 +582,7 @@ std::map<std::string, std::string> SIPAccount::getAccountDetails() const
     registrationExpireStr << registrationExpire_;
     a[CONFIG_ACCOUNT_REGISTRATION_EXPIRE] = registrationExpireStr.str();
     a[CONFIG_LOCAL_INTERFACE] = interface_;
-    a[CONFIG_PUBLISHED_SAMEAS_LOCAL] = publishedSameasLocal_ ? "true" : "false";
+    a[CONFIG_PUBLISHED_SAMEAS_LOCAL] = publishedSameasLocal_ ? TRUE_STR : FALSE_STR;
     a[CONFIG_PUBLISHED_ADDRESS] = publishedIpAddress_;
 
     std::stringstream localport;
@@ -586,19 +591,19 @@ std::map<std::string, std::string> SIPAccount::getAccountDetails() const
     std::stringstream publishedport;
     publishedport << publishedPort_;
     a[CONFIG_PUBLISHED_PORT] = publishedport.str();
-    a[CONFIG_STUN_ENABLE] = stunEnabled_ ? "true" : "false";
+    a[CONFIG_STUN_ENABLE] = stunEnabled_ ? TRUE_STR : FALSE_STR;
     a[CONFIG_STUN_SERVER] = stunServer_;
     a[CONFIG_ACCOUNT_DTMF_TYPE] = dtmfType_;
-    a[CONFIG_KEEP_ALIVE_ENABLED] = keepAliveEnabled_ ? "true" : "false";
+    a[CONFIG_KEEP_ALIVE_ENABLED] = keepAliveEnabled_ ? TRUE_STR : FALSE_STR;
 
     a[CONFIG_SRTP_KEY_EXCHANGE] = srtpKeyExchange_;
-    a[CONFIG_SRTP_ENABLE] = srtpEnabled_ ? "true" : "false";
-    a[CONFIG_SRTP_RTP_FALLBACK] = srtpFallback_ ? "true" : "false";
+    a[CONFIG_SRTP_ENABLE] = srtpEnabled_ ? TRUE_STR : FALSE_STR;
+    a[CONFIG_SRTP_RTP_FALLBACK] = srtpFallback_ ? TRUE_STR : FALSE_STR;
 
-    a[CONFIG_ZRTP_DISPLAY_SAS] = zrtpDisplaySas_ ? "true" : "false";
-    a[CONFIG_ZRTP_DISPLAY_SAS_ONCE] = zrtpDisplaySasOnce_ ? "true" : "false";
-    a[CONFIG_ZRTP_HELLO_HASH] = zrtpHelloHash_ ? "true" : "false";
-    a[CONFIG_ZRTP_NOT_SUPP_WARNING] = zrtpNotSuppWarning_ ? "true" : "false";
+    a[CONFIG_ZRTP_DISPLAY_SAS] = zrtpDisplaySas_ ? TRUE_STR : FALSE_STR;
+    a[CONFIG_ZRTP_DISPLAY_SAS_ONCE] = zrtpDisplaySasOnce_ ? TRUE_STR : FALSE_STR;
+    a[CONFIG_ZRTP_HELLO_HASH] = zrtpHelloHash_ ? TRUE_STR : FALSE_STR;
+    a[CONFIG_ZRTP_NOT_SUPP_WARNING] = zrtpNotSuppWarning_ ? TRUE_STR : FALSE_STR;
 
     // TLS listener is unique and parameters are modified through IP2IP_PROFILE
     std::stringstream tlslistenerport;
@@ -612,9 +617,9 @@ std::map<std::string, std::string> SIPAccount::getAccountDetails() const
     a[CONFIG_TLS_METHOD] = tlsMethod_;
     a[CONFIG_TLS_CIPHERS] = tlsCiphers_;
     a[CONFIG_TLS_SERVER_NAME] = tlsServerName_;
-    a[CONFIG_TLS_VERIFY_SERVER] = tlsVerifyServer_ ? "true" : "false";
-    a[CONFIG_TLS_VERIFY_CLIENT] = tlsVerifyClient_ ? "true" : "false";
-    a[CONFIG_TLS_REQUIRE_CLIENT_CERTIFICATE] = tlsRequireClientCertificate_ ? "true" : "false";
+    a[CONFIG_TLS_VERIFY_SERVER] = tlsVerifyServer_ ? TRUE_STR : FALSE_STR;
+    a[CONFIG_TLS_VERIFY_CLIENT] = tlsVerifyClient_ ? TRUE_STR : FALSE_STR;
+    a[CONFIG_TLS_REQUIRE_CLIENT_CERTIFICATE] = tlsRequireClientCertificate_ ? TRUE_STR : FALSE_STR;
     a[CONFIG_TLS_NEGOTIATION_TIMEOUT_SEC] = tlsNegotiationTimeoutSec_;
     a[CONFIG_TLS_NEGOTIATION_TIMEOUT_MSEC] = tlsNegotiationTimeoutMsec_;
 
@@ -627,7 +632,7 @@ void SIPAccount::registerVoIPLink()
         return;
 
     // Init TLS settings if the user wants to use TLS
-    if (tlsEnable_ == "true") {
+    if (tlsEnable_ == TRUE_STR) {
         DEBUG("TLS is enabled for account %s", accountID_.c_str());
         transportType_ = PJSIP_TRANSPORT_TLS;
         initTlsConfiguration();
@@ -728,13 +733,20 @@ pjsip_ssl_method SIPAccount::sslMethodStringToPjEnum(const std::string& method)
     return PJSIP_SSL_UNSPECIFIED_METHOD;
 }
 
+void SIPAccount::displayCipherSuite()
+{
+    CipherArray::const_iterator iter;
+    for (iter = ciphers.begin(); iter != ciphers.end(); ++iter)
+        DEBUG("Cipher: %s", pj_ssl_cipher_name(*iter));
+}
+
 void SIPAccount::initTlsConfiguration()
 {
     pj_status_t status;
     unsigned cipherNum;
 
     // Determine the cipher list supported on this machine
-    cipherNum = PJ_ARRAY_SIZE(ciphers);
+    cipherNum = ciphers.size();
     status = pj_ssl_cipher_get_availables(&ciphers.front(), &cipherNum);
     if (status != PJ_SUCCESS) {
         ERROR("Could not determine cipher list on this system");
@@ -791,16 +803,16 @@ void SIPAccount::loadConfig()
     if (registrationExpire_ == 0)
         registrationExpire_ = DEFAULT_REGISTRATION_TIME; /** Default expire value for registration */
 
-    if (tlsEnable_ == "true") {
+    if (tlsEnable_ == TRUE_STR) {
         initTlsConfiguration();
         transportType_ = PJSIP_TRANSPORT_TLS;
     } else
         transportType_ = PJSIP_TRANSPORT_UDP;
 }
 
-bool SIPAccount::fullMatch(const std::string& username, const std::string& hostname) const
+bool SIPAccount::fullMatch(const std::string& username, const std::string& hostname, pjsip_endpoint *endpt, pj_pool_t *pool) const
 {
-    return userMatch(username) and hostnameMatch(hostname);
+    return userMatch(username) and hostnameMatch(hostname, endpt, pool);
 }
 
 bool SIPAccount::userMatch(const std::string& username) const
@@ -808,17 +820,32 @@ bool SIPAccount::userMatch(const std::string& username) const
     return !username.empty() and username == username_;
 }
 
-bool SIPAccount::hostnameMatch(const std::string& hostname) const
-{
-    return hostname == hostname_;
+namespace {
+    bool haveValueInCommon(const std::vector<std::string> &a, const std::vector<std::string> &b)
+    {
+        for (std::vector<std::string>::const_iterator i = a.begin(); i != a.end(); ++i)
+            if (std::find(b.begin(), b.end(), *i) != b.end())
+                return true;
+        return false;
+    }
 }
 
-bool SIPAccount::proxyMatch(const std::string& hostname) const
+bool SIPAccount::hostnameMatch(const std::string& hostname, pjsip_endpoint * /*endpt*/, pj_pool_t * /*pool*/) const
+{
+    if (hostname == hostname_)
+        return true;
+    const std::vector<std::string> a(sip_utils::getIPList(hostname));
+    const std::vector<std::string> b(sip_utils::getIPList(hostname_));
+    return haveValueInCommon(a, b);
+}
+
+bool SIPAccount::proxyMatch(const std::string& hostname, pjsip_endpoint * /*endpt*/, pj_pool_t * /*pool*/) const
 {
     if (hostname == serviceRoute_)
         return true;
-    const std::list<std::string> ipList(sip_utils::resolveServerDns(serviceRoute_));
-    return std::find(ipList.begin(), ipList.end(), hostname) != ipList.end();
+    const std::vector<std::string> a(sip_utils::getIPList(hostname));
+    const std::vector<std::string> b(sip_utils::getIPList(serviceRoute_));
+    return haveValueInCommon(a, b);
 }
 
 std::string SIPAccount::getLoginName()
@@ -893,23 +920,6 @@ std::string SIPAccount::getServerUri() const
     return "<" + scheme + hostname_ + transport + ">";
 }
 
-void SIPAccount::setContactHeader(std::string address, std::string port)
-{
-    std::string scheme;
-    std::string transport;
-
-    // UDP does not require the transport specification
-    if (transportType_ == PJSIP_TRANSPORT_TLS) {
-        scheme = "sips:";
-        transport = ";transport=" + std::string(pjsip_transport_get_type_name(transportType_));
-    } else
-        scheme = "sip:";
-
-    contactHeader_ = displayName_ + (displayName_.empty() ? "" : " ") + "<" +
-                     scheme + username_ + (username_.empty() ? "":"@") +
-                     address + ":" + port + transport + ">";
-}
-
 
 std::string SIPAccount::getContactHeader() const
 {
@@ -921,10 +931,6 @@ std::string SIPAccount::getContactHeader() const
     if (transportType == PJSIP_TRANSPORT_START_OTHER)
         transportType = PJSIP_TRANSPORT_UDP;
 
-    // Use the CONTACT header provided by the registrar if any
-    if (!contactHeader_.empty())
-        return contactHeader_;
-
     // Else we determine this infor based on transport information
     std::string address, port;
     std::ostringstream portstr;
@@ -953,17 +959,18 @@ std::string SIPAccount::getContactHeader() const
            address + ":" + port + transport + ">";
 }
 
+
 void SIPAccount::keepAliveRegistrationCb(UNUSED pj_timer_heap_t *th, pj_timer_entry *te)
 {
     SIPAccount *sipAccount = static_cast<SIPAccount *>(te->user_data);
 
-    ERROR("Keep alive registration callback for account %s", sipAccount->getAccountID().c_str());
-
     if (sipAccount == NULL) {
         ERROR("SIP account is NULL while registering a new keep alive timer");
         return;
     }
 
+    ERROR("Keep alive registration callback for account %s", sipAccount->getAccountID().c_str());
+
     // IP2IP default does not require keep-alive
     if (sipAccount->isIP2IP())
         return;
@@ -1100,12 +1107,12 @@ std::map<std::string, std::string> SIPAccount::getIp2IpDetails() const
     std::map<std::string, std::string> ip2ipAccountDetails;
     ip2ipAccountDetails[CONFIG_ACCOUNT_ID] = IP2IP_PROFILE;
     ip2ipAccountDetails[CONFIG_SRTP_KEY_EXCHANGE] = srtpKeyExchange_;
-    ip2ipAccountDetails[CONFIG_SRTP_ENABLE] = srtpEnabled_ ? "true" : "false";
-    ip2ipAccountDetails[CONFIG_SRTP_RTP_FALLBACK] = srtpFallback_ ? "true" : "false";
-    ip2ipAccountDetails[CONFIG_ZRTP_DISPLAY_SAS] = zrtpDisplaySas_ ? "true" : "false";
-    ip2ipAccountDetails[CONFIG_ZRTP_HELLO_HASH] = zrtpHelloHash_ ? "true" : "false";
-    ip2ipAccountDetails[CONFIG_ZRTP_NOT_SUPP_WARNING] = zrtpNotSuppWarning_ ? "true" : "false";
-    ip2ipAccountDetails[CONFIG_ZRTP_DISPLAY_SAS_ONCE] = zrtpDisplaySasOnce_ ? "true" : "false";
+    ip2ipAccountDetails[CONFIG_SRTP_ENABLE] = srtpEnabled_ ? TRUE_STR : FALSE_STR;
+    ip2ipAccountDetails[CONFIG_SRTP_RTP_FALLBACK] = srtpFallback_ ? TRUE_STR : FALSE_STR;
+    ip2ipAccountDetails[CONFIG_ZRTP_DISPLAY_SAS] = zrtpDisplaySas_ ? TRUE_STR : FALSE_STR;
+    ip2ipAccountDetails[CONFIG_ZRTP_HELLO_HASH] = zrtpHelloHash_ ? TRUE_STR : FALSE_STR;
+    ip2ipAccountDetails[CONFIG_ZRTP_NOT_SUPP_WARNING] = zrtpNotSuppWarning_ ? TRUE_STR : FALSE_STR;
+    ip2ipAccountDetails[CONFIG_ZRTP_DISPLAY_SAS_ONCE] = zrtpDisplaySasOnce_ ? TRUE_STR : FALSE_STR;
     ip2ipAccountDetails[CONFIG_LOCAL_INTERFACE] = interface_;
     std::stringstream portstr;
     portstr << localPort_;
@@ -1134,9 +1141,9 @@ std::map<std::string, std::string> SIPAccount::getTlsSettings() const
     tlsSettings[CONFIG_TLS_METHOD] = tlsMethod_;
     tlsSettings[CONFIG_TLS_CIPHERS] = tlsCiphers_;
     tlsSettings[CONFIG_TLS_SERVER_NAME] = tlsServerName_;
-    tlsSettings[CONFIG_TLS_VERIFY_SERVER] = tlsVerifyServer_ ? "true" : "false";
-    tlsSettings[CONFIG_TLS_VERIFY_CLIENT] = tlsVerifyClient_ ? "true" : "false";
-    tlsSettings[CONFIG_TLS_REQUIRE_CLIENT_CERTIFICATE] = tlsRequireClientCertificate_ ? "true" : "false";
+    tlsSettings[CONFIG_TLS_VERIFY_SERVER] = tlsVerifyServer_ ? TRUE_STR : FALSE_STR;
+    tlsSettings[CONFIG_TLS_VERIFY_CLIENT] = tlsVerifyClient_ ? TRUE_STR : FALSE_STR;
+    tlsSettings[CONFIG_TLS_REQUIRE_CLIENT_CERTIFICATE] = tlsRequireClientCertificate_ ? TRUE_STR : FALSE_STR;
     tlsSettings[CONFIG_TLS_NEGOTIATION_TIMEOUT_SEC] = tlsNegotiationTimeoutSec_;
     tlsSettings[CONFIG_TLS_NEGOTIATION_TIMEOUT_MSEC] = tlsNegotiationTimeoutMsec_;
 
@@ -1157,7 +1164,7 @@ void set_opt(const std::map<std::string, std::string> &details, const char *key,
     std::map<std::string, std::string>::const_iterator it = details.find(key);
 
     if (it != details.end())
-        val = it->second == "true";
+        val = it->second == TRUE_STR;
 }
 
 void set_opt(const std::map<std::string, std::string> &details, const char *key, pj_uint16_t &val)
@@ -1196,3 +1203,22 @@ bool SIPAccount::isIP2IP() const
 {
     return accountID_ == IP2IP_PROFILE;
 }
+
+bool SIPAccount::matches(const std::string &userName, const std::string &server,
+                         pjsip_endpoint *endpt, pj_pool_t *pool) const
+{
+    if (fullMatch(userName, server, endpt, pool)) {
+        DEBUG("Matching account id in request is a fullmatch %s@%s", userName.c_str(), server.c_str());
+        return true;
+    } else if (hostnameMatch(server, endpt, pool)) {
+        DEBUG("Matching account id in request with hostname %s", server.c_str());
+        return true;
+    } else if (userMatch(userName)) {
+        DEBUG("Matching account id in request with username %s", userName.c_str());
+        return true;
+    } else if (proxyMatch(server, endpt, pool)) {
+        DEBUG("Matching account id in request with proxy %s", server.c_str());
+        return true;
+    } else
+        return false;
+}
