@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 2004, 2005, 2006, 2008, 2009, 2010, 2011 Savoir-Faire Linux Inc.
+ *  Copyright (C) 2004-2012 Savoir-Faire Linux Inc.
  *
  *  Author: Emmanuel Milou <emmanuel.milou@savoirfairelinux.com>
  *  Author: Alexandre Bourget <alexandre.bourget@savoirfairelinux.com>
@@ -18,7 +18,7 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301 USA.
  *
  *  Additional permission under GNU GPL version 3 section 7:
  *
@@ -56,7 +56,6 @@ namespace Conf {
     const char *const SAME_AS_LOCAL_KEY = "sameasLocal";
     const char *const DTMF_TYPE_KEY = "dtmfType";
     const char *const SERVICE_ROUTE_KEY = "serviceRoute";
-    const char *const UPDATE_CONTACT_HEADER_KEY = "updateContact";
     const char *const KEEP_ALIVE_ENABLED = "keepAlive";
 
     // TODO: write an object to store credential which implement serializable
@@ -105,6 +104,7 @@ class SIPAccount : public Account {
         static const char * const IP2IP_PROFILE;
         static const char * const OVERRTP_STR;
         static const char * const SIPINFO_STR;
+        static const char * const ACCOUNT_TYPE;
 
         /**
          * Constructor
@@ -134,7 +134,7 @@ class SIPAccount : public Account {
          * Populate the internal state for this account based on info stored in the configuration file
          * @param The configuration node for this account
          */
-        virtual void unserialize(const Conf::MappingNode &map);
+        virtual void unserialize(const Conf::YamlNode &map);
 
         /**
          * Set the internal state for this account, mainly used to manage account details from the client application.
@@ -249,11 +249,6 @@ class SIPAccount : public Account {
                 registrationExpire_ = 0;
         }
 
-        bool fullMatch(const std::string& username, const std::string& hostname) const;
-        bool userMatch(const std::string& username) const;
-        bool hostnameMatch(const std::string& hostname) const;
-        bool proxyMatch(const std::string& hostname) const;
-
         /**
          * Registration flag
 	 */
@@ -321,9 +316,6 @@ class SIPAccount : public Account {
         pj_uint16_t getStunPort() const {
             return stunPort_;
         }
-        void setStunPort(pj_uint16_t port) {
-            stunPort_ = port;
-        }
 
         /**
          * @return bool Tells if current transport for that
@@ -372,36 +364,11 @@ class SIPAccount : public Account {
          */
         std::string getServerUri() const;
 
-        /**
-         * Set the contact header
-         * @param port Optional port. Otherwise set to the port defined for that account.
-         * @param hostname Optional local address. Otherwise set to the hostname defined for that account.
-         */
-        void setContactHeader(std::string address, std::string port);
-
         /**
          * Get the contact header for
          * @return pj_str_t The contact header based on account information
          */
-        std::string getContactHeader(void) const;
-
-        /**
-         * The contact header can be rewritten based on the contact provided by the registrar in 200 OK
-         */
-        void enableContactUpdate(void) {
-            contactUpdateEnabled_ = true;
-        }
-
-        /**
-         * The contact header is not updated even if the registrar
-         */
-        void disableContactUpdate(void) {
-            contactUpdateEnabled_ = false;
-        }
-
-        bool isContactUpdateEnabled(void) {
-            return contactUpdateEnabled_;
-        }
+        std::string getContactHeader() const;
 
         /**
          * Get the local interface name on which this account is bound.
@@ -472,19 +439,17 @@ class SIPAccount : public Account {
             return publishedIpAddress_;
         }
 
-        /**
-         * Set the public IP address to be used in Contact header.
-         * @param The public IPV4 address in the standard dot notation.
-         * @return void
-         */
-        void setPublishedAddress(const std::string &publishedIpAddress) {
-            publishedIpAddress_ = publishedIpAddress;
+        void setPublishedAddress(const std::string &ip_addr) {
+            publishedIpAddress_ = ip_addr;
         }
 
+
         std::string getServiceRoute() const {
             return serviceRoute_;
         }
 
+        bool hasServiceRoute() const { return not serviceRoute_.empty(); }
+
         std::string getDtmfType() const {
             return dtmfType_;
         }
@@ -507,12 +472,19 @@ class SIPAccount : public Account {
 
         void setReceivedParameter(const std::string &received) {
             receivedParameter_ = received;
+            via_addr_.host.ptr = (char *) receivedParameter_.c_str();
+            via_addr_.host.slen = receivedParameter_.size();
         }
 
         std::string getReceivedParameter() const {
             return receivedParameter_;
         }
 
+        pjsip_host_port *
+        getViaAddr() {
+            return &via_addr_;
+        }
+
         int getRPort() const {
             if (rPort_ == -1)
                 return localPort_;
@@ -520,7 +492,10 @@ class SIPAccount : public Account {
                 return rPort_;
         }
 
-        void setRPort(int rPort) { rPort_ = rPort; }
+        void setRPort(int rPort) {
+            rPort_ = rPort;
+            via_addr_.port = rPort;
+        }
 
         /**
          * Timer used to periodically send re-register request based
@@ -537,9 +512,17 @@ class SIPAccount : public Account {
          */
         pjsip_transport* transport_;
 
+        /* Returns true if the username and/or hostname match this account */
+        bool matches(const std::string &username, const std::string &hostname, pjsip_endpoint *endpt, pj_pool_t *pool) const;
+
     private:
         NON_COPYABLE(SIPAccount);
 
+        bool fullMatch(const std::string &username, const std::string &hostname, pjsip_endpoint *endpt, pj_pool_t *pool) const;
+        bool userMatch(const std::string &username) const;
+        bool hostnameMatch(const std::string &hostname, pjsip_endpoint *endpt, pj_pool_t *pool) const;
+        bool proxyMatch(const std::string &hostname, pjsip_endpoint *endpt, pj_pool_t *pool) const;
+
         /**
          * Map of credential for this account
          */
@@ -558,6 +541,11 @@ class SIPAccount : public Account {
          */
         void initTlsConfiguration();
 
+        /**
+         * Display the list of ciphers currently supported on the
+         */
+        void displayCipherSuite();
+
         /**
          * Initializes STUN config from the config file
          */
@@ -646,18 +634,6 @@ class SIPAccount : public Account {
          */
         CipherArray ciphers;
 
-        /**
-         * The CONTACT header used for registration as provided by the registrar, this value could differ
-         * from the host name in case the registrar is inside a subnetwork (such as a VPN).
-         * The header will be stored
-         */
-        std::string contactHeader_;
-
-        /**
-         * Enble the contact header based on the header received from the registrar in 200 OK
-         */
-        bool contactUpdateEnabled_;
-
         /**
          * The STUN server name (hostname)
          */
@@ -778,6 +754,11 @@ class SIPAccount : public Account {
          * Optional: "rport" parameter from VIA header
          */
         int rPort_;
+
+        /**
+         * Optional: via_addr construct from received parameters
+         */
+        pjsip_host_port via_addr_;
 };
 
 #endif
