@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 2004, 2005, 2006, 2008, 2009, 2010, 2011 Savoir-Faire Linux Inc.
+ *  Copyright (C) 2004-2012 Savoir-Faire Linux Inc.
  *  Author: Alexandre Bourget <alexandre.bourget@savoirfairelinux.com>
  *  Author: Yan Morin <yan.morin@savoirfairelinux.com>
  *  Author : Laurielle Lea <laurielle.lea@savoirfairelinux.com>
@@ -16,7 +16,7 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301 USA.
  *
  *  Additional permission under GNU GPL version 3 section 7:
  *
@@ -44,10 +44,10 @@
 
 #include "noncopyable.h"
 
-class pjsip_evsub;
-class pj_caching_pool;
-class pj_pool_t;
-class pjsip_inv_session;
+struct pjsip_evsub;
+struct pj_caching_pool;
+struct pj_pool_t;
+struct pjsip_inv_session;
 class Sdp;
 
 /**
@@ -63,7 +63,8 @@ class SIPCall : public Call {
          * @param type  The type of the call. Could be Incoming
          *						 Outgoing
          */
-        SIPCall(const std::string& id, Call::CallType type, pj_caching_pool *caching_pool);
+        SIPCall(const std::string& id, Call::CallType type,
+                pj_caching_pool *caching_pool, const std::string &account_id);
 
         /**
          * Destructor
@@ -100,6 +101,8 @@ class SIPCall : public Call {
             return pool_;
         }
 
+        void answer();
+
         /**
          * The invite session to be reused in case of transfer
          */
@@ -110,7 +113,9 @@ class SIPCall : public Call {
         std::map<std::string, std::string>
         getDetails();
 
-        virtual void answer();
+        // override of Call::createHistoryEntry
+        std::map<std::string, std::string>
+        createHistoryEntry() const;
 
         NON_COPYABLE(SIPCall);
 
