@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) [2004, 2012] Savoir-Faire Linux Inc.
+ *  Copyright (C) 2004-2012 Savoir-Faire Linux Inc.
  *
  *  Author: Alexandre Savard <alexandre.savard@savoirfairelinux.com>
  *
@@ -15,7 +15,7 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301 USA.
  *
  *  Additional permission under GNU GPL version 3 section 7:
  *
@@ -109,7 +109,10 @@ std::string SipTransport::getInterfaceAddrFromName(const std::string &ifaceName)
     RETURN_IF_FAIL(fd >= 0, "", "Could not open socket: %m");
 
     ifreq ifr;
-    strcpy(ifr.ifr_name, ifaceName.c_str());
+    strncpy(ifr.ifr_name, ifaceName.c_str(), sizeof ifr.ifr_name);
+    // guarantee that ifr_name is NULL-terminated
+    ifr.ifr_name[sizeof(ifr.ifr_name) - 1] = '\0';
+
     memset(&ifr.ifr_addr, 0, sizeof(ifr.ifr_addr));
     ifr.ifr_addr.sa_family = AF_INET;
 
@@ -262,7 +265,7 @@ pjsip_tpfactory* SipTransport::createTlsListener(SIPAccount &account)
     std::string interface(account.getLocalInterface());
     std::string listeningAddress;
     if (interface == DEFAULT_INTERFACE)
-        listeningAddress = getSIPLocalIP();
+        listeningAddress = ANY_HOSTS;
     else
         listeningAddress = getInterfaceAddrFromName(interface);
 
@@ -313,9 +316,10 @@ SipTransport::createTlsTransport(SIPAccount &account)
 
     DEBUG("Get new tls transport from transport manager");
     pjsip_transport *transport = NULL;
-    pjsip_endpt_acquire_transport(endpt_, PJSIP_TRANSPORT_TLS, &rem_addr,
+    pj_status_t status = pjsip_endpt_acquire_transport(endpt_, PJSIP_TRANSPORT_TLS, &rem_addr,
                                   sizeof rem_addr, NULL, &transport);
-    RETURN_IF_FAIL(transport != NULL, NULL, "Could not create new TLS transport");
+    RETURN_IF_FAIL(transport != NULL and status == PJ_SUCCESS, NULL,
+                   "Could not create new TLS transport");
     return transport;
 }
 #endif
@@ -376,7 +380,7 @@ SipTransport::createUdpTransport(const std::string &interface, unsigned int port
     // determine the IP address for this transport
     std::string listeningAddress;
     if (interface == DEFAULT_INTERFACE)
-        listeningAddress = getSIPLocalIP();
+        listeningAddress = ANY_HOSTS;
     else
         listeningAddress = getInterfaceAddrFromName(interface);
 
@@ -457,6 +461,27 @@ pjsip_tpselector *SipTransport::createTransportSelector(pjsip_transport *transpo
     return tp;
 }
 
+std::vector<pj_sockaddr_in>
+SipTransport::getSTUNAddresses(const SIPAccount &account,
+        std::vector<long> &socketDescriptors) const
+{
+    const pj_str_t serverName = account.getStunServerName();
+    const pj_uint16_t port = account.getStunPort();
+
+    std::vector<pj_sockaddr_in> result(socketDescriptors.size());
+
+    if (pjstun_get_mapped_addr(&cp_->factory, socketDescriptors.size(), &socketDescriptors[0],
+                &serverName, port, &serverName, port, &result[0]) != PJ_SUCCESS)
+        throw std::runtime_error("Can't contact STUN server");
+
+    for (std::vector<pj_sockaddr_in>::const_iterator it = result.begin();
+            it != result.end(); ++it)
+        WARN("STUN PORTS: %ld", pj_ntohs(it->sin_port));
+
+    return result;
+}
+
+
 pjsip_transport *SipTransport::createStunTransport(SIPAccount &account)
 {
 #define RETURN_IF_STUN_FAIL(A, M, ...) \
@@ -468,7 +493,6 @@ pjsip_transport *SipTransport::createStunTransport(SIPAccount &account)
     pj_str_t serverName = account.getStunServerName();
     pj_uint16_t port = account.getStunPort();
 
-    DEBUG("Create STUN transport  server name: %s, port: %d", serverName, port);
     RETURN_IF_STUN_FAIL(createStunResolver(serverName, port) == PJ_SUCCESS, "Can't resolve STUN server");
 
     pj_sock_t sock = PJ_INVALID_SOCKET;
@@ -506,14 +530,18 @@ pjsip_transport *SipTransport::createStunTransport(SIPAccount &account)
 #undef RETURN_IF_STUN_FAIL
 }
 
-void SipTransport::shutdownSipTransport(SIPAccount &account)
+void SipTransport::shutdownSTUNResolver(SIPAccount &account)
 {
     if (account.isStunEnabled()) {
         pj_str_t stunServerName = account.getStunServerName();
         std::string server(stunServerName.ptr, stunServerName.slen);
         destroyStunResolver(server);
     }
+}
 
+void SipTransport::shutdownSipTransport(SIPAccount &account)
+{
+    shutdownSTUNResolver(account);
     if (account.transport_) {
         pjsip_transport_dec_ref(account.transport_);
         account.transport_ = NULL;
@@ -558,10 +586,6 @@ void SipTransport::findLocalAddressFromTransport(pjsip_transport *transport, pjs
     // Update local address based on the transport type
     addr = std::string(localAddress.ptr, localAddress.slen);
 
-    // Fallback on local ip provided by pj_gethostip()
-    if (addr == ANY_HOSTS)
-        addr = getSIPLocalIP();
-
     // Determine the local port based on transport information
     ss.str("");
     ss << i_port;
