@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) [2004, 2012] Savoir-Faire Linux Inc.
+ *  Copyright (C) 2004-2012 Savoir-Faire Linux Inc.
  *
  *  Author: Alexandre Savard <alexandre.savard@savoirfairelinux.com>
  *
@@ -15,7 +15,7 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301 USA.
  *
  *  Additional permission under GNU GPL version 3 section 7:
  *
@@ -107,6 +107,18 @@ class SipTransport {
         pjsip_tpselector *
         createTransportSelector(pjsip_transport *transport, pj_pool_t *tp_pool) const;
 
+        /**
+         * This function unset the STUN resolver for a given account.
+         */
+        void shutdownSTUNResolver(SIPAccount &account);
+
+        /**
+         * This function returns a list of STUN mapped sockets for
+         * a given set of socket file descriptors */
+        std::vector<pj_sockaddr_in>
+        getSTUNAddresses(const SIPAccount &account,
+                         std::vector<long> &socks) const;
+
         /**
          * This function unset the transport for a given account.
          */
