@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 2004, 2005, 2006, 2008, 2009, 2010, 2011 Savoir-Faire Linux Inc.
+ *  Copyright (C) 2004-2012 Savoir-Faire Linux Inc.
  *
  *  Author: Emmanuel Milou <emmanuel.milou@savoirfairelinux.com>
  *  Author: Alexandre Bourget <alexandre.bourget@savoirfairelinux.com>
@@ -17,7 +17,7 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301 USA.
  *
  *  Additional permission under GNU GPL version 3 section 7:
  *
@@ -35,15 +35,11 @@
 #define __VOIP_LINK_H__
 
 #include <stdexcept>
-#include <map>
-#include "cc_thread.h" // for ost::Mutex
+#include <string>
 
 class Call;
 class Account;
 
-/** Define a map that associate a Call object to a call identifier */
-typedef std::map<std::string, Call*> CallMap;
-
 class VoipLinkException : public std::runtime_error {
     public:
         VoipLinkException(const std::string &str = "") :
@@ -84,7 +80,8 @@ class VoIPLink {
          * @return Call* The current call
          */
         virtual Call* newOutgoingCall(const std::string &id,
-                                      const std::string &toUrl) = 0;
+                                      const std::string &toUrl,
+                                      const std::string &account_id) = 0;
 
         /**
          * Answer the call
@@ -96,7 +93,7 @@ class VoIPLink {
          * Hang up a call
          * @param id The call identifier
          */
-        virtual void hangup(const std::string &id) = 0;
+        virtual void hangup(const std::string &id, int reason) = 0;
 
         /**
         * Peer Hung up a call
@@ -151,7 +148,7 @@ class VoIPLink {
          * @param call The call
          */
         virtual std::string getCurrentVideoCodecName(Call *call) const = 0;
-        virtual std::string getCurrentAudioCodecName(Call *call) const = 0;
+        virtual std::string getCurrentAudioCodecNames(Call *call) const = 0;
 
         /**
          * Send a message to a call identified by its callid
@@ -166,32 +163,9 @@ class VoIPLink {
                                      const std::string &from) = 0;
 #endif
 
-        /** Add a call to the call map (protected by mutex)
-         * @param call A call pointer with a unique pointer
-         * @return bool True if the call was unique and added
-         */
-        void addCall(Call* call);
-
-        /**
-         * Get the call pointer from the call map (protected by mutex)
-         * @param id A Call ID
-         * @return Call*  Call pointer or 0
-         */
-        Call* getCall(const std::string &id);
-
     protected:
-        /** Contains all the calls for this Link, protected by mutex */
-        CallMap callMap_;
-
-        /** Mutex to protect call map */
-        ost::Mutex callMapMutex_;
-
+        static void unloadAccount(std::pair<const std::string, Account*> &item);
         bool handlingEvents_;
-
-        /** Remove a call from the call map (protected by mutex)
-         * @param id A Call ID
-         */
-        void removeCall(const std::string &id);
 };
 
 #endif // __VOIP_LINK_H__
