@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 2004, 2005, 2006, 2008, 2009, 2010 Savoir-Faire Linux Inc.
+ *  Copyright (C) 2004-2012 Savoir-Faire Linux Inc.
  *  Author: Emmanuel Milou <emmanuel.milou@savoirfairelinux.com>
  *
  *  This program is free software; you can redistribute it and/or modify
@@ -14,7 +14,7 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301 USA.
  *
  *  Additional permission under GNU GPL version 3 section 7:
  *
@@ -53,32 +53,6 @@ class ConfigurationTest: public CppUnit::TestFixture {
         CPPUNIT_TEST_SUITE_END();
 
     public:
-        /*
-         * Unit tests related to the audio preferences
-         */
-        void testDefaultValueAudio();
-
-        /*
-         * Unit tests related to the global settings
-         */
-        void testDefaultValuePreferences();
-
-        /*
-         * Unit tests related to the global settings
-         */
-        void testDefaultValueSignalisation();
-
-        /*
-         * Try to load one SIP account.
-         * So be sure to have only one SIP account so that the test could succeed
-         */
-        void testLoadSIPAccount();
-
-        void testUnloadSIPAccount();
-
-        void testInitAudioDriver();
-
-        void testYamlParser();
 
         void testYamlEmitter();
 };
