@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 2004, 2005, 2006, 2008, 2009, 2010 Savoir-Faire Linux Inc.
+ *  Copyright (C) 2004-2012 Savoir-Faire Linux Inc.
  *  Author: Emmanuel Milou <emmanuel.milou@savoirfairelinux.com>
  *
  *  This program is free software; you can redistribute it and/or modify
@@ -14,7 +14,7 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301 USA.
  *
  *  Additional permission under GNU GPL version 3 section 7:
  *
@@ -39,6 +39,7 @@
 #include "siptest.h"
 #include "manager.h"
 #include "sip/sipvoiplink.h"
+#include "sip/sip_utils.h"
 
 // anonymous namespace
 namespace {
@@ -177,8 +178,8 @@ void SIPTest::testSimpleIncomingIpCall()
     // gtrab call id from sipvoiplink
     SIPVoIPLink *siplink = SIPVoIPLink::instance();
 
-    CPPUNIT_ASSERT(siplink->callMap_.size() == 1);
-    CallMap::iterator iterCallId = siplink->callMap_.begin();
+    CPPUNIT_ASSERT(siplink->sipCallMap_.size() == 1);
+    SipCallMap::iterator iterCallId = siplink->sipCallMap_.begin();
     std::string testcallid = iterCallId->first;
 
     // Answer this call
@@ -285,8 +286,8 @@ void SIPTest::testTwoIncomingIpCall()
     // gtrab call id from sipvoiplink
     SIPVoIPLink *sipLink = SIPVoIPLink::instance();
 
-    CPPUNIT_ASSERT(sipLink->callMap_.size() == 1);
-    CallMap::iterator iterCallId = sipLink->callMap_.begin();
+    CPPUNIT_ASSERT(sipLink->sipCallMap_.size() == 1);
+    SipCallMap::iterator iterCallId = sipLink->sipCallMap_.begin();
     std::string firstCallID = iterCallId->first;
 
     // Answer this call
@@ -301,8 +302,8 @@ void SIPTest::testTwoIncomingIpCall()
 
     sleep(1);
 
-    CPPUNIT_ASSERT(sipLink->callMap_.size() == 2);
-    iterCallId = sipLink->callMap_.begin();
+    CPPUNIT_ASSERT(sipLink->sipCallMap_.size() == 2);
+    iterCallId = sipLink->sipCallMap_.begin();
 
     if (iterCallId->first == firstCallID)
         ++iterCallId;
@@ -358,6 +359,13 @@ void SIPTest::testHoldIpCall()
     Manager::instance().hangupCall(testCallID);
 }
 
+void SIPTest::testSIPURI()
+{
+    std::string foo("<sip:17771234567@callcentric.com>");
+    sip_utils::stripSipUriPrefix(foo);
+    CPPUNIT_ASSERT(foo == "17771234567");
+}
+
 
 void SIPTest::testIncomingIpCallSdp()
 {
@@ -377,8 +385,8 @@ void SIPTest::testIncomingIpCallSdp()
     // gtrab call id from sipvoiplink
     SIPVoIPLink *siplink = SIPVoIPLink::instance();
 
-    CPPUNIT_ASSERT(siplink->callMap_.size() == 1);
-    CallMap::iterator iterCallId = siplink->callMap_.begin();
+    CPPUNIT_ASSERT(siplink->sipCallMap_.size() == 1);
+    SipCallMap::iterator iterCallId = siplink->sipCallMap_.begin();
     std::string testcallid = iterCallId->first;
 
     // TODO: hmmm, should IP2IP call be stored in call list....
