@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 2004, 2005, 2006, 2008, 2009, 2010, 2011 Savoir-Faire Linux Inc.
+ *  Copyright (C) 2004-2012 Savoir-Faire Linux Inc.
  *  Author: Pierre-Luc Beaudoin <pierre-luc.beaudoin@savoirfairelinux.com>
  *  Author: Emmanuel Milou <emmanuel.milou@savoirfairelinux.com>
  *
@@ -15,7 +15,7 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301 USA.
  *
  *  Additional permission under GNU GPL version 3 section 7:
  *
@@ -34,9 +34,7 @@
 #include "dbus.h"
 #include "accountlist.h"
 #include "account_schema.h"
-#include "logger.h"
 #include "actions.h"
-#include "unused.h"
 
 static GQueue * accountQueue;
 
@@ -102,7 +100,7 @@ account_t *
 account_list_get_by_id(const gchar * const accountID)
 {
     if (!accountID) {
-        DEBUG("AccountID is NULL");
+        g_debug("AccountID is NULL");
         return NULL;
     }
 
@@ -167,6 +165,8 @@ const gchar * account_state_name(account_state_t s)
             return _("Network unreachable");
         case ACCOUNT_STATE_ERROR_HOST:
             return _("Host unreachable");
+        case ACCOUNT_STATE_ERROR_SERVICE_UNAVAILABLE:
+            return _("Service unavailable");
         case ACCOUNT_STATE_ERROR_NOT_ACCEPTABLE:
             return _("Not acceptable");
         case ACCOUNT_STATE_ERROR_EXIST_STUN:
@@ -178,7 +178,7 @@ const gchar * account_state_name(account_state_t s)
     }
 }
 
-void account_list_free_elm(gpointer elm, gpointer data UNUSED)
+void account_list_free_elm(gpointer elm, G_GNUC_UNUSED gpointer data)
 {
     account_t *a = elm;
     g_free(a->accountID);
@@ -241,7 +241,7 @@ void account_list_remove(const gchar *accountID)
     if (target) {
 #if GLIB_CHECK_VERSION(2, 30, 0)
         if (!g_queue_remove(accountQueue, target))
-            ERROR("Could not remove account with ID %s", accountID);
+            g_warning("Could not remove account with ID %s", accountID);
 #else
         g_queue_remove(accountQueue, target);
 #endif
@@ -303,6 +303,11 @@ gboolean current_account_has_new_message(void)
     return current && current->_messages_number > 0;
 }
 
+gboolean account_has_autoanswer_on(const account_t *account)
+{
+    return g_strcmp0(account_lookup(account, CONFIG_ACCOUNT_AUTOANSWER), "true") == 0;
+}
+
 gboolean account_is_IP2IP(const account_t *account)
 {
     g_assert(account);
