@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 2004, 2005, 2006, 2008, 2009, 2010, 2011 Savoir-Faire Linux Inc.
+ *  Copyright (C) 2004-2012 Savoir-Faire Linux Inc.
  *  Author: Emmanuel Milou <emmanuel.milou@savoirfairelinux.com>
  *  Author: Pierre-Luc Beaudoin <pierre-luc.beaudoin@savoirfairelinux.com>
  *
@@ -15,7 +15,7 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301 USA.
  *
  *  Additional permission under GNU GPL version 3 section 7:
  *
@@ -35,14 +35,11 @@
 
 #include <glib/gi18n.h>
 #include <gtk/gtk.h>
-/* Backward compatibility for gtk < 2.22.0 */
-#if GTK_CHECK_VERSION(2,22,0)
-#include <gdk/gdkkeysyms-compat.h>
-#else
-#include <gdk/gdkkeysyms.h>
-#endif
 
 #include "str_utils.h"
+#include "uimanager.h"
+#include "mainwindow.h"
+#include "calltree.h"
 #include <glib.h>
 #include <stdlib.h>
 #include <string.h>
@@ -60,16 +57,15 @@
 
 #include "actions.h"
 #include "dbus/dbus.h"
-#include "logger.h"
 #include "account_schema.h"
 #include "contacts/calltab.h"
 #include "contacts/searchbar.h"
 #include "contacts/addrbookfactory.h"
 #include "icons/icon_factory.h"
 #include "statusicon.h"
-#include "unused.h"
 #include "sliders.h"
 #include "messaging/message_tab.h"
+#include "history_loader.h"
 #ifdef SFL_VIDEO
 #include "video/video_callbacks.h"
 #endif
@@ -77,13 +73,13 @@
 static GHashTable * ip2ip_profile;
 
 void
-sflphone_notify_voice_mail(const gchar* accountID , guint count)
+sflphone_notify_voice_mail(const gchar* accountID , guint count, SFLPhoneClient *client)
 {
     // We want to notify only the current account; ie the first in the list
     gchar *id = g_strdup(accountID);
     const gchar * const current_id = account_list_get_current_id();
 
-    DEBUG("sflphone_notify_voice_mail begin");
+    g_debug("sflphone_notify_voice_mail begin");
 
     if (g_ascii_strcasecmp(id, current_id) != 0 ||
         account_list_get_size() == 0)
@@ -97,9 +93,9 @@ sflphone_notify_voice_mail(const gchar* accountID , guint count)
     update_voicemail_status();
 
     if (current)
-        notify_voice_mails(count, current);
+        notify_voice_mails(count, current, client);
 
-    DEBUG("sflphone_notify_voice_mail end");
+    g_debug("sflphone_notify_voice_mail end");
 }
 
 /*
@@ -150,9 +146,9 @@ status_bar_display_account()
 
 
 void
-sflphone_quit(gboolean force_quit)
+sflphone_quit(gboolean force_quit, SFLPhoneClient *client)
 {
-    if (force_quit || calllist_get_size(current_calls_tab) == 0 || main_window_ask_quit()) {
+    if (force_quit || calllist_get_size(current_calls_tab) == 0 || main_window_ask_quit(client)) {
 #ifdef SFL_VIDEO
         video_cleanup();
 #endif
@@ -162,36 +158,39 @@ sflphone_quit(gboolean force_quit)
         calllist_clean(current_calls_tab);
         calllist_clean(contacts_tab);
         calllist_clean(history_tab);
-        gtk_main_quit();
+        free_addressbook();
+
+#if GLIB_CHECK_VERSION(2,32,0)
+        g_application_quit(G_APPLICATION(client));
+#else
+        g_application_release(G_APPLICATION(client));
+#endif
     }
 }
 
 void
-sflphone_hold(callable_obj_t * c)
+sflphone_hold(callable_obj_t * c, SFLPhoneClient *client)
 {
     c->_state = CALL_STATE_HOLD;
-    calltree_update_call(current_calls_tab, c);
-    update_actions();
+    calltree_update_call(current_calls_tab, c, client, FALSE);
 }
 
 void
-sflphone_ringing(callable_obj_t * c)
+sflphone_ringing(callable_obj_t * c, SFLPhoneClient *client)
 {
     c->_state = CALL_STATE_RINGING;
-    calltree_update_call(current_calls_tab, c);
-    update_actions();
+    calltree_update_call(current_calls_tab, c, client, TRUE);
 }
 
 void
-sflphone_hung_up(callable_obj_t * c)
+sflphone_hung_up(callable_obj_t * c, SFLPhoneClient *client)
 {
-    DEBUG("%s", __PRETTY_FUNCTION__);
     disable_messaging_tab(c->_callID);
-    calllist_remove_call(current_calls_tab, c->_callID);
+    calllist_remove_call(current_calls_tab, c->_callID, client);
     calltree_remove_call(current_calls_tab, c->_callID);
     c->_state = CALL_STATE_DIALING;
     call_remove_all_errors(c);
-    update_actions();
+    update_actions(client);
 
     status_tray_icon_blink(FALSE);
 
@@ -206,8 +205,8 @@ void sflphone_fill_account_list(void)
     for (gchar **accountID = array; accountID && *accountID; ++accountID) {
         account_t *acc = create_account_with_ID(*accountID);
         if (acc->properties == NULL) {
-            ERROR("SFLphone: Error: Could not fetch details for account %s",
-                  accountID);
+            g_warning("SFLphone: Error: Could not fetch details for account %s",
+                      *accountID);
             break;
         }
         account_list_add(acc);
@@ -221,17 +220,17 @@ void sflphone_fill_account_list(void)
             acc->state = ACCOUNT_STATE_UNREGISTERED;
         else if (g_strcmp0(status, "TRYING") == 0)
             acc->state = ACCOUNT_STATE_TRYING;
-        else if (g_strcmp0(status, "ERROR") == 0)
+        else if (g_strcmp0(status, "g_warning") == 0)
             acc->state = ACCOUNT_STATE_ERROR;
-        else if (g_strcmp0(status, "ERROR_AUTH") == 0)
+        else if (g_strcmp0(status, "g_warning_AUTH") == 0)
             acc->state = ACCOUNT_STATE_ERROR_AUTH;
-        else if (g_strcmp0(status, "ERROR_NETWORK") == 0)
+        else if (g_strcmp0(status, "g_warning_NETWORK") == 0)
             acc->state = ACCOUNT_STATE_ERROR_NETWORK;
-        else if (g_strcmp0(status, "ERROR_HOST") == 0)
+        else if (g_strcmp0(status, "g_warning_HOST") == 0)
             acc->state = ACCOUNT_STATE_ERROR_HOST;
-        else if (g_strcmp0(status, "ERROR_NOT_ACCEPTABLE") == 0)
+        else if (g_strcmp0(status, "g_warning_NOT_ACCEPTABLE") == 0)
             acc->state = ACCOUNT_STATE_ERROR_NOT_ACCEPTABLE;
-        else if (g_strcmp0(status, "ERROR_EXIST_STUN") == 0)
+        else if (g_strcmp0(status, "g_warning_EXIST_STUN") == 0)
             acc->state = ACCOUNT_STATE_ERROR_EXIST_STUN;
         else if (g_strcmp0(status, "ACCOUNT_STATE_IP2IP_READY") == 0)
             acc->state = ACCOUNT_STATE_IP2IP_READY;
@@ -250,9 +249,9 @@ void sflphone_fill_account_list(void)
     current_account_set_message_number(current_account_get_message_number());
 }
 
-gboolean sflphone_init(GError **error)
+gboolean sflphone_init(GError **error, SFLPhoneClient *client)
 {
-    if (!dbus_connect(error) || !dbus_register(getpid(), "Gtk+ Client", error))
+    if (!dbus_connect(error, client) || !dbus_register(getpid(), "Gtk+ Client", error))
         return FALSE;
 
     abook_init();
@@ -260,9 +259,9 @@ gboolean sflphone_init(GError **error)
     // Init icons factory
     init_icon_factory();
 
-    current_calls_tab = calltab_init(FALSE, CURRENT_CALLS);
-    contacts_tab = calltab_init(TRUE, CONTACTS);
-    history_tab = calltab_init(TRUE, HISTORY);
+    current_calls_tab = calltab_init(FALSE, CURRENT_CALLS, client);
+    contacts_tab = calltab_init(TRUE, CONTACTS, client);
+    history_tab = calltab_init(TRUE, HISTORY, client);
 
     codecs_load();
     conferencelist_init(current_calls_tab);
@@ -287,13 +286,11 @@ GHashTable *sflphone_get_ip2ip_properties(void)
 }
 
 void
-sflphone_hang_up()
+sflphone_hang_up(SFLPhoneClient *client)
 {
     callable_obj_t * selectedCall = calltab_get_selected_call(current_calls_tab);
     conference_obj_t * selectedConf = calltab_get_selected_conf(active_calltree_tab);
 
-    DEBUG("%s", __PRETTY_FUNCTION__);
-
     if (selectedConf) {
         disable_messaging_tab(selectedConf->_confID);
         dbus_hang_up_conference(selectedConf);
@@ -326,7 +323,7 @@ sflphone_hang_up()
                 dbus_refuse(selectedCall);
                 call_remove_all_errors(selectedCall);
                 selectedCall->_state = CALL_STATE_DIALING;
-                DEBUG("from sflphone_hang_up : ");
+                g_debug("from sflphone_hang_up : ");
                 break;
             case CALL_STATE_TRANSFER:
                 dbus_hang_up(selectedCall);
@@ -334,12 +331,12 @@ sflphone_hang_up()
                 time(&selectedCall->_time_stop);
                 break;
             default:
-                WARN("Should not happen in sflphone_hang_up()!");
+                g_warning("Should not happen in sflphone_hang_up()!");
                 break;
         }
     }
 
-    calltree_update_call(history_tab, selectedCall);
+    calltree_update_call(history_tab, selectedCall, client, FALSE);
 
     statusbar_update_clock("");
 
@@ -350,7 +347,7 @@ sflphone_hang_up()
 }
 
 void
-sflphone_pick_up()
+sflphone_pick_up(SFLPhoneClient *client)
 {
     callable_obj_t *selectedCall = calltab_get_selected_call(active_calltree_tab);
 
@@ -360,35 +357,30 @@ sflphone_pick_up()
         dbus_screensaver_inhibit();
 
     if (!selectedCall) {
-        sflphone_new_call();
+        sflphone_new_call(client);
         return;
     }
 
     switch (selectedCall->_state) {
         case CALL_STATE_DIALING:
-            sflphone_place_call(selectedCall);
-
+            sflphone_place_call(selectedCall, client);
             break;
         case CALL_STATE_INCOMING:
             selectedCall->_history_state = g_strdup(INCOMING_STRING);
-            calltree_update_call(history_tab, selectedCall);
+            calltree_update_call(history_tab, selectedCall, client, TRUE);
 
             dbus_accept(selectedCall);
             break;
         case CALL_STATE_TRANSFER:
             dbus_transfer(selectedCall);
-            time(&selectedCall->_time_stop);
-            calltree_remove_call(current_calls_tab, selectedCall->_callID);
-            update_actions();
-            calllist_remove_call(current_calls_tab, selectedCall->_callID);
             break;
         case CALL_STATE_CURRENT:
         case CALL_STATE_HOLD:
         case CALL_STATE_RINGING:
-            sflphone_new_call();
+            sflphone_new_call(client);
             break;
         default:
-            WARN("Should not happen in sflphone_pick_up()!");
+            g_warning("Should not happen in sflphone_pick_up()!");
             break;
     }
 }
@@ -405,7 +397,7 @@ sflphone_on_hold()
                 dbus_hold(selectedCall);
                 break;
             default:
-                WARN("Should not happen in sflphone_on_hold!");
+                g_warning("Should not happen in sflphone_on_hold!");
                 break;
         }
     } else if (selectedConf)
@@ -415,7 +407,7 @@ sflphone_on_hold()
 void
 sflphone_off_hold()
 {
-    DEBUG("%s", __PRETTY_FUNCTION__);
+    g_debug("%s", __PRETTY_FUNCTION__);
     callable_obj_t * selectedCall = calltab_get_selected_call(current_calls_tab);
     conference_obj_t * selectedConf = calltab_get_selected_conf(active_calltree_tab);
 
@@ -425,7 +417,7 @@ sflphone_off_hold()
                 dbus_unhold(selectedCall);
                 break;
             default:
-                WARN("Should not happen in sflphone_off_hold ()!");
+                g_warning("Should not happen in sflphone_off_hold ()!");
                 break;
         }
     } else if (selectedConf)
@@ -434,34 +426,31 @@ sflphone_off_hold()
 
 
 void
-sflphone_fail(callable_obj_t * c)
+sflphone_fail(callable_obj_t * c, SFLPhoneClient *client)
 {
     c->_state = CALL_STATE_FAILURE;
-    calltree_update_call(current_calls_tab, c);
-    update_actions();
+    calltree_update_call(current_calls_tab, c, client, FALSE);
 }
 
 void
-sflphone_busy(callable_obj_t * c)
+sflphone_busy(callable_obj_t * c, SFLPhoneClient *client)
 {
     c->_state = CALL_STATE_BUSY;
-    calltree_update_call(current_calls_tab, c);
-    update_actions();
+    calltree_update_call(current_calls_tab, c, client, FALSE);
 }
 
 void
-sflphone_current(callable_obj_t * c)
+sflphone_current(callable_obj_t * c, SFLPhoneClient *client)
 {
     if (c->_state != CALL_STATE_HOLD)
         time(&c->_time_start);
 
     c->_state = CALL_STATE_CURRENT;
-    calltree_update_call(current_calls_tab, c);
-    update_actions();
+    calltree_update_call(current_calls_tab, c, client, TRUE);
 }
 
 void
-sflphone_set_transfer()
+sflphone_set_transfer(SFLPhoneClient *client)
 {
     callable_obj_t * c = calltab_get_selected_call(current_calls_tab);
 
@@ -469,14 +458,14 @@ sflphone_set_transfer()
         c->_state = CALL_STATE_TRANSFER;
         g_free(c->_trsft_to);
         c->_trsft_to = g_strdup("");
-        calltree_update_call(current_calls_tab, c);
+        calltree_update_call(current_calls_tab, c, client, FALSE);
+    } else {
+        update_actions(client);
     }
-
-    update_actions();
 }
 
 void
-sflphone_unset_transfer()
+sflphone_unset_transfer(SFLPhoneClient *client)
 {
     callable_obj_t * c = calltab_get_selected_call(current_calls_tab);
 
@@ -484,10 +473,10 @@ sflphone_unset_transfer()
         c->_state = CALL_STATE_CURRENT;
         g_free(c->_trsft_to);
         c->_trsft_to = g_strdup("");
-        calltree_update_call(current_calls_tab, c);
+        calltree_update_call(current_calls_tab, c, client, FALSE);
+    } else {
+        update_actions(client);
     }
-
-    update_actions();
 }
 
 void
@@ -497,14 +486,14 @@ sflphone_display_transfer_status(const gchar* message)
 }
 
 void
-sflphone_incoming_call(callable_obj_t * c)
+sflphone_incoming_call(callable_obj_t * c, SFLPhoneClient *client)
 {
     c->_history_state = g_strdup(MISSED_STRING);
     calllist_add_call(current_calls_tab, c);
     calltree_add_call(current_calls_tab, c, NULL);
 
-    update_actions();
-    calltree_display(current_calls_tab);
+    update_actions(client);
+    calltree_display(current_calls_tab, client);
 
     // Change the status bar if we are dealing with a direct SIP call
     if (is_direct_call(c)) {
@@ -513,31 +502,38 @@ sflphone_incoming_call(callable_obj_t * c)
         statusbar_push_message(msg , NULL, __MSG_ACCOUNT_DEFAULT);
         g_free(msg);
     }
+    account_t *account = account_list_get_by_id(c->_accountID);
+    if (!account) {
+        g_warning("Account is NULL");
+    } else if (account_has_autoanswer_on(account)) {
+        calltab_set_selected_call(active_calltree_tab, c);
+        sflphone_pick_up(client);
+    }
 }
 
 static void
-process_dialing(callable_obj_t *c, guint keyval, gchar *key)
+process_dialing(callable_obj_t *c, guint keyval, const gchar *key, SFLPhoneClient *client)
 {
     // We stop the tone
     if (!*c->_peer_number && c->_state != CALL_STATE_TRANSFER)
         dbus_start_tone(FALSE, 0);
 
     switch (keyval) {
-        case GDK_Return:
-        case GDK_KP_Enter:
-            sflphone_place_call(c);
+        case GDK_KEY_Return:
+        case GDK_KEY_KP_Enter:
+            sflphone_place_call(c, client);
             break;
-        case GDK_Escape:
-            sflphone_hang_up();
+        case GDK_KEY_Escape:
+            sflphone_hang_up(client);
             break;
-        case GDK_BackSpace: {
+        case GDK_KEY_BackSpace: {
             gchar *num = (c->_state == CALL_STATE_TRANSFER) ? c->_trsft_to : c->_peer_number;
             size_t len = strlen(num);
 
             if (len) {
                 len--; // delete one character
                 num[len] = '\0';
-                calltree_update_call(current_calls_tab, c);
+                calltree_update_call(current_calls_tab, c, client, FALSE);
 
                 /* If number is now empty, hang up immediately */
                 if (c->_state != CALL_STATE_TRANSFER && len == 0)
@@ -546,16 +542,19 @@ process_dialing(callable_obj_t *c, guint keyval, gchar *key)
 
             break;
         }
-        case GDK_Tab:
-        case GDK_Alt_L:
-        case GDK_Control_L:
-        case GDK_Super_L:
-        case GDK_Caps_Lock:
+        case GDK_KEY_Tab:
+        case GDK_KEY_Alt_L:
+        case GDK_KEY_Alt_R:
+        case GDK_KEY_Control_L:
+        case GDK_KEY_Control_R:
+        case GDK_KEY_Super_L:
+        case GDK_KEY_Super_R:
+        case GDK_KEY_Caps_Lock:
             break;
         default:
 
             if (keyval < 127 /* ascii */ ||
-                    (keyval >= GDK_Mode_switch && keyval <= GDK_KP_9) /* num keypad */) {
+                    (keyval >= GDK_KEY_Mode_switch && keyval <= GDK_KEY_KP_9) /* num keypad */) {
 
                 if (c->_state == CALL_STATE_TRANSFER) {
                     gchar *new_trsft = g_strconcat(c->_trsft_to, key, NULL);
@@ -568,7 +567,7 @@ process_dialing(callable_obj_t *c, guint keyval, gchar *key)
                     c->_peer_number = new_peer_number;
                 }
 
-                calltree_update_call(current_calls_tab, c);
+                calltree_update_call(current_calls_tab, c, client, FALSE);
             }
 
             break;
@@ -577,7 +576,7 @@ process_dialing(callable_obj_t *c, guint keyval, gchar *key)
 
 
 callable_obj_t *
-sflphone_new_call()
+sflphone_new_call(SFLPhoneClient *client)
 {
     // Disable screensaver if the list is empty call
     guint nbcall = calllist_get_size(current_calls_tab);
@@ -603,42 +602,42 @@ sflphone_new_call()
 
     calllist_add_call(current_calls_tab, c);
     calltree_add_call(current_calls_tab, c, NULL);
-    update_actions();
+    update_actions(client);
 
     return c;
 }
 
 
 void
-sflphone_keypad(guint keyval, gchar * key)
+sflphone_keypad(guint keyval, const gchar * key, SFLPhoneClient *client)
 {
     callable_obj_t * c = calltab_get_selected_call(current_calls_tab);
 
     const gboolean current_is_active_tab = calltab_has_name(active_calltree_tab, CURRENT_CALLS);
     if (!current_is_active_tab || (current_is_active_tab && !c)) {
         switch (keyval) {
-            case GDK_Return:
-            case GDK_KP_Enter:
-            case GDK_Escape:
-            case GDK_BackSpace:
+            case GDK_KEY_Return:
+            case GDK_KEY_KP_Enter:
+            case GDK_KEY_Escape:
+            case GDK_KEY_BackSpace:
                 break;
             default:
-                calltree_display(current_calls_tab);
-                process_dialing(sflphone_new_call(), keyval, key);
+                calltree_display(current_calls_tab, client);
+                process_dialing(sflphone_new_call(client), keyval, key, client);
                 break;
         }
     } else if (c) {
         switch (c->_state) {
             case CALL_STATE_DIALING: // Currently dialing => edit number
-                process_dialing(c, keyval, key);
+                process_dialing(c, keyval, key, client);
                 break;
             case CALL_STATE_CURRENT:
 
                 switch (keyval) {
-                    case GDK_Escape:
+                    case GDK_KEY_Escape:
                         dbus_hang_up(c);
                         time(&c->_time_stop);
-                        calltree_update_call(history_tab, c);
+                        calltree_update_call(history_tab, c, client, FALSE);
                         break;
                     default:
                         // To play the dtmf when calling mail box for instance
@@ -650,13 +649,13 @@ sflphone_keypad(guint keyval, gchar * key)
             case CALL_STATE_INCOMING:
 
                 switch (keyval) {
-                    case GDK_Return:
-                    case GDK_KP_Enter:
+                    case GDK_KEY_Return:
+                    case GDK_KEY_KP_Enter:
                         c->_history_state = g_strdup(INCOMING_STRING);
-                        calltree_update_call(history_tab, c);
+                        calltree_update_call(history_tab, c, client, TRUE);
                         dbus_accept(c);
                         break;
-                    case GDK_Escape:
+                    case GDK_KEY_Escape:
                         dbus_refuse(c);
                         break;
                 }
@@ -665,18 +664,15 @@ sflphone_keypad(guint keyval, gchar * key)
             case CALL_STATE_TRANSFER:
 
                 switch (keyval) {
-                    case GDK_Return:
-                    case GDK_KP_Enter:
+                    case GDK_KEY_Return:
+                    case GDK_KEY_KP_Enter:
                         dbus_transfer(c);
-                        time(&c->_time_stop);
-                        calltree_remove_call(current_calls_tab, c->_callID);
-                        update_actions();
                         break;
-                    case GDK_Escape:
-                        sflphone_unset_transfer();
+                    case GDK_KEY_Escape:
+                        sflphone_unset_transfer(client);
                         break;
                     default: // When a call is on transfer, typing new numbers will add it to c->_peer_number
-                        process_dialing(c, keyval, key);
+                        process_dialing(c, keyval, key, client);
                         break;
                 }
 
@@ -684,15 +680,15 @@ sflphone_keypad(guint keyval, gchar * key)
             case CALL_STATE_HOLD:
 
                 switch (keyval) {
-                    case GDK_Return:
-                    case GDK_KP_Enter:
+                    case GDK_KEY_Return:
+                    case GDK_KEY_KP_Enter:
                         dbus_unhold(c);
                         break;
-                    case GDK_Escape:
+                    case GDK_KEY_Escape:
                         dbus_hang_up(c);
                         break;
                     default: // When a call is on hold, typing new numbers will create a new call
-                        process_dialing(sflphone_new_call(), keyval, key);
+                        process_dialing(sflphone_new_call(client), keyval, key, client);
                         break;
                 }
 
@@ -702,9 +698,9 @@ sflphone_keypad(guint keyval, gchar * key)
             case CALL_STATE_FAILURE:
 
                 switch (keyval) {
-                    case GDK_Escape:
+                    case GDK_KEY_Escape:
                         dbus_hang_up(c);
-                        calltree_update_call(history_tab, c);
+                        calltree_update_call(history_tab, c, client, FALSE);
                         break;
                 }
 
@@ -712,39 +708,37 @@ sflphone_keypad(guint keyval, gchar * key)
             default:
                 break;
         }
-
-    } else
-        sflphone_new_call();
+    }
 }
 
 int
-sflphone_place_call(callable_obj_t * c)
+sflphone_place_call(callable_obj_t * c, SFLPhoneClient *client)
 {
     account_t * account = NULL;
 
     if (c == NULL) {
-        ERROR("Callable object is NULL while making new call");
+        g_warning("Callable object is NULL while making new call");
         return -1;
     }
 
-    DEBUG("Placing call from %s to %s using account %s", c->_display_name, c->_peer_number, c->_accountID);
+    g_debug("Placing call from %s to %s using account %s", c->_display_name, c->_peer_number, c->_accountID);
 
     if (c->_state != CALL_STATE_DIALING) {
-        ERROR("Call not in state dialing, cannot place call");
+        g_warning("Call not in state dialing, cannot place call");
         return -1;
     }
 
     if (!c->_peer_number || strlen(c->_peer_number) == 0) {
-        ERROR("No peer number set for this call");
+        g_warning("No peer number set for this call");
         return -1;
     }
 
     // Get the account for this call
     if (strlen(c->_accountID) != 0) {
-        DEBUG("Account %s already set for this call", c->_accountID);
+        g_debug("Account %s already set for this call", c->_accountID);
         account = account_list_get_by_id(c->_accountID);
     } else {
-        DEBUG("No account set for this call, use first of the list");
+        g_debug("No account set for this call, use first of the list");
         account = account_list_get_current();
     }
 
@@ -759,10 +753,10 @@ sflphone_place_call(callable_obj_t * c)
 
     // If there is no account specified or found, fallback on IP2IP call
     if(account == NULL) {
-        DEBUG("Could not find an account for this call, making ip to ip call");
+        g_debug("Could not find an account for this call, making ip to ip call");
         account = account_list_get_by_id("IP2IP");
         if (account == NULL) {
-            ERROR("Actions: Could not determine any account for this call");
+            g_warning("Actions: Could not determine any account for this call");
             return -1;
         }
     }
@@ -771,7 +765,7 @@ sflphone_place_call(callable_obj_t * c)
     g_free(c->_accountID);
     c->_accountID = g_strdup(account->accountID);
     dbus_place_call(c);
-    notify_current_account(account);
+    notify_current_account(account, client);
 
     c->_history_state = g_strdup(OUTGOING_STRING);
 
@@ -788,7 +782,7 @@ sflphone_detach_participant(const gchar* callID)
     else
         selectedCall = calllist_get_call(current_calls_tab, callID);
 
-    DEBUG("Detach participant %s", selectedCall->_callID);
+    g_debug("Detach participant %s", selectedCall->_callID);
 
     /*TODO elepage(2012) correct IM conversation*/
     calltree_remove_call(current_calls_tab, selectedCall->_callID);
@@ -799,12 +793,12 @@ sflphone_detach_participant(const gchar* callID)
 void
 sflphone_add_participant(const gchar* callID, const gchar* confID)
 {
-    DEBUG("Add participant %s to conference %s", callID, confID);
+    g_debug("Add participant %s to conference %s", callID, confID);
 
     callable_obj_t *call = calllist_get_call(current_calls_tab, callID);
 
     if (call == NULL) {
-        ERROR("Could not find call");
+        g_warning("Could not find call");
         return;
     }
 
@@ -814,22 +808,22 @@ sflphone_add_participant(const gchar* callID, const gchar* confID)
 void
 sflphone_add_main_participant(const conference_obj_t * c)
 {
-    DEBUG("%s", __PRETTY_FUNCTION__);
+    g_debug("%s", __PRETTY_FUNCTION__);
     dbus_add_main_participant(c->_confID);
 }
 
 void
-sflphone_rec_call()
+sflphone_rec_call(SFLPhoneClient *client)
 {
     callable_obj_t * selectedCall = calltab_get_selected_call(current_calls_tab);
     conference_obj_t * selectedConf = calltab_get_selected_conf(current_calls_tab);
 
     if (selectedCall) {
-        DEBUG("Set record for selected call");
+        g_debug("Set record for selected call");
         dbus_set_record(selectedCall->_callID);
-        calltree_update_call(current_calls_tab, selectedCall);
+        calltree_update_call(current_calls_tab, selectedCall, client, TRUE);
     } else if (selectedConf) {
-        DEBUG("Set record for selected conf");
+        g_debug("Set record for selected conf");
         dbus_set_record(selectedConf->_confID);
 
         switch (selectedConf->_state) {
@@ -846,22 +840,23 @@ sflphone_rec_call()
                 selectedConf->_state = CONFERENCE_STATE_ACTIVE_DETACHED_RECORD;
                 break;
             default:
-                WARN("Should not happen in sflphone_off_hold ()!");
+                g_warning("Should not happen in sflphone_off_hold ()!");
                 break;
         }
 
-        DEBUG("Remove and add conference %s", selectedConf->_confID);
-        calltree_remove_conference(current_calls_tab, selectedConf);
-        calltree_add_conference_to_current_calls(selectedConf);
+        g_debug("Remove and add conference %s", selectedConf->_confID);
+        calltree_remove_conference(current_calls_tab, selectedConf, client);
+        /* This calls update actions */
+        calltree_add_conference_to_current_calls(selectedConf, client);
+    } else {
+        update_actions(client);
     }
-
-    update_actions();
 }
 
 void
 sflphone_mute_call()
 {
-    DEBUG("%s", __PRETTY_FUNCTION__);
+    g_debug("%s", __PRETTY_FUNCTION__);
 
     toggle_slider_mute_microphone();
 }
@@ -882,10 +877,11 @@ sflphone_fill_audio_codec_list_per_account(account_t *account)
         codec_t *orig = codec_list_get_by_payload(payload, system_acodecs);
         codec_t *c = codec_create_new_from_caps(orig);
 
-        if (c)
+        if (c) {
+            c->is_active = TRUE;
             g_queue_push_tail(account->acodecs, c);
-        else
-            ERROR("Couldn't find codec %d %p", payload, orig);
+        } else
+            g_warning("Couldn't find codec %d %p", payload, orig);
     }
     g_array_unref(order);
 
@@ -927,7 +923,7 @@ void sflphone_fill_call_list(void)
 }
 
 
-void sflphone_fill_conference_list(void)
+void sflphone_fill_conference_list(SFLPhoneClient *client)
 {
     // TODO Fetch the active conferences at client startup
 
@@ -940,86 +936,55 @@ void sflphone_fill_conference_list(void)
         conference_obj_t *conf = create_new_conference_from_details(conf_id, conference_details);
 
         conferencelist_add(current_calls_tab, conf);
-        calltree_add_conference_to_current_calls(conf);
+        calltree_add_conference_to_current_calls(conf, client);
     }
 
     g_strfreev(conferences);
 }
 
-static void
-create_callable_from_entry(gpointer data, gpointer user_data UNUSED)
+void sflphone_fill_history_lazy()
 {
-    GHashTable *entry = (GHashTable *) data;
-    callable_obj_t *history_call = create_history_entry_from_hashtable(entry);
-
-    /* Add it and update the GUI */
-    calllist_add_call_to_front(history_tab, history_call);
-}
-
-static void fill_treeview_with_calls(void)
-{
-    guint n = calllist_get_size(history_tab);
-
-    for (guint i = 0; i < n; ++i) {
-        callable_obj_t *call = calllist_get_nth(history_tab, i);
-        if (call)
-            calltree_add_history_entry(call);
-    }
-}
-
-void sflphone_fill_history(void)
-{
-    GPtrArray *entries = dbus_get_history();
-    if (entries)
-        g_ptr_array_foreach(entries, create_callable_from_entry, NULL);
-
-    fill_treeview_with_calls();
+    lazy_load_items(history_tab);
 }
 
 void
-sflphone_srtp_sdes_on(callable_obj_t * c)
+sflphone_srtp_sdes_on(callable_obj_t * c, SFLPhoneClient *client)
 {
     c->_srtp_state = SRTP_STATE_SDES_SUCCESS;
 
-    calltree_update_call(current_calls_tab, c);
-    update_actions();
+    calltree_update_call(current_calls_tab, c, client, TRUE);
 }
 
 void
-sflphone_srtp_sdes_off(callable_obj_t * c)
+sflphone_srtp_sdes_off(callable_obj_t * c, SFLPhoneClient *client)
 {
     c->_srtp_state = SRTP_STATE_UNLOCKED;
-
-    calltree_update_call(current_calls_tab, c);
-    update_actions();
+    calltree_update_call(current_calls_tab, c, client, TRUE);
 }
 
 
 void
-sflphone_srtp_zrtp_on(callable_obj_t * c)
+sflphone_srtp_zrtp_on(callable_obj_t * c, SFLPhoneClient *client)
 {
     c->_srtp_state = SRTP_STATE_ZRTP_SAS_UNCONFIRMED;
 
-    calltree_update_call(current_calls_tab, c);
-    update_actions();
+    calltree_update_call(current_calls_tab, c, client, TRUE);
 }
 
 void
-sflphone_srtp_zrtp_off(callable_obj_t * c)
+sflphone_srtp_zrtp_off(callable_obj_t * c, SFLPhoneClient *client)
 {
     c->_srtp_state = SRTP_STATE_UNLOCKED;
-    calltree_update_call(current_calls_tab, c);
-    update_actions();
+    calltree_update_call(current_calls_tab, c, client, TRUE);
 }
 
 void
-sflphone_srtp_zrtp_show_sas(callable_obj_t * c, const gchar* sas, const gboolean verified)
+sflphone_srtp_zrtp_show_sas(callable_obj_t * c, const gchar* sas, const gboolean verified, SFLPhoneClient *client)
 {
     c->_sas = g_strdup(sas);
     c->_srtp_state = verified ? SRTP_STATE_ZRTP_SAS_CONFIRMED : SRTP_STATE_ZRTP_SAS_UNCONFIRMED;
 
-    calltree_update_call(current_calls_tab, c);
-    update_actions();
+    calltree_update_call(current_calls_tab, c, client, TRUE);
 }
 
 void
@@ -1032,12 +997,12 @@ sflphone_request_go_clear(void)
 }
 
 void
-sflphone_call_state_changed(callable_obj_t * c, const gchar * description, const guint code)
+sflphone_call_state_changed(callable_obj_t * c, const gchar * description, const guint code, SFLPhoneClient *client)
 {
-    DEBUG("Call State changed %s", description);
+    g_debug("Call State changed %s", description);
 
     if (c == NULL) {
-        ERROR("SFLphone: Error: callable obj is NULL in %s at %d", __FILE__, __LINE__);
+        g_warning("SFLphone: Error: callable obj is NULL in %s at %d", __FILE__, __LINE__);
         return;
     }
 
@@ -1045,7 +1010,6 @@ sflphone_call_state_changed(callable_obj_t * c, const gchar * description, const
     c->_state_code_description = g_strdup(description);
     c->_state_code = code;
 
-    calltree_update_call(current_calls_tab, c);
-    update_actions();
+    calltree_update_call(current_calls_tab, c, client, TRUE);
 }
 
