@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 2004, 2005, 2006, 2008, 2009, 2010, 2011 Savoir-Faire Linux Inc.
+ *  Copyright (C) 2004-2012 Savoir-Faire Linux Inc.
  *  Author: Julien Bonjean <julien.bonjean@savoirfairelinux.com>
  *
  *  This program is free software; you can redistribute it and/or modify
@@ -14,7 +14,7 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301 USA.
  *
  *  Additional permission under GNU GPL version 3 section 7:
  *
@@ -40,7 +40,6 @@
 #include <glib/gi18n.h>
 #include "contacts/calltab.h"
 #include "contacts/calltree.h"
-#include "logger.h"
 #include "dbus.h"
 #include <unistd.h>
 
@@ -89,6 +88,12 @@ gchar* call_get_audio_codec(callable_obj_t *obj)
     if (!audio_codec)
         goto out;
 
+    /* Codec may contain multiple codecs depending on the call */
+    gchar **split_codecs = g_strsplit(audio_codec, " ", 0);
+    if (g_strv_length(split_codecs) >= 1)
+        ret = g_strdup(split_codecs[0]);
+    g_strfreev(split_codecs);
+
     account_t *acc = account_list_get_by_id(obj->_accountID);
 
     if (!acc)
@@ -99,6 +104,9 @@ gchar* call_get_audio_codec(callable_obj_t *obj)
     if (!codec)
         goto out;
 
+    if (ret)
+        g_free(ret);
+
     ret = g_strdup_printf("%s/%i", audio_codec, codec->sample_rate);
 
 out:
@@ -319,11 +327,11 @@ gboolean call_was_outgoing(callable_obj_t * obj)
 
 void restore_call(const gchar *id)
 {
-    DEBUG("Restoring call %s", id);
+    g_debug("Restoring call %s", id);
     // We fetch the details associated to the specified call
     GHashTable *call_details = dbus_get_call_details(id);
     if (!call_details) {
-        ERROR("Invalid call ID");
+        g_warning("Invalid call ID");
         return;
     }
     callable_obj_t *new_call = create_new_call_from_details(id, call_details);
