@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 2004, 2005, 2006, 2008, 2009, 2010, 2011 Savoir-Faire Linux Inc.
+ *  Copyright (C) 2004-2012 Savoir-Faire Linux Inc.
  *  Author: Emmanuel Milou <emmanuel.milou@savoirfairelinux.net>
  *
  *  This program is free software; you can redistribute it and/or modify
@@ -14,7 +14,7 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301 USA.
  *
  *  Additional permission under GNU GPL version 3 section 7:
  *
@@ -33,8 +33,6 @@
 #endif
 
 #include "codeclist.h"
-#include "unused.h"
-#include "logger.h"
 #include <string.h>
 #include <stdlib.h>
 #include <stdint.h>
@@ -100,7 +98,7 @@ static gboolean codecs_audio_load(void)
 }
 
 static void
-codec_free(gpointer data, gpointer user_data UNUSED)
+codec_free(gpointer data, G_GNUC_UNUSED gpointer user_data)
 {
     codec_t *codec = (codec_t*) data;
     g_free(codec->name);
