@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 2004, 2005, 2006, 2008, 2009, 2010, 2011 Savoir-Faire Linux Inc.
+ *  Copyright (C) 2004-2012 Savoir-Faire Linux Inc.
  *  Author: Emmanuel Milou <emmanuel.milou@savoirfairelinux.com>
  *
  *  This program is free software; you can redistribute it and/or modify
@@ -14,7 +14,7 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301 USA.
  *
  *  Additional permission under GNU GPL version 3 section 7:
  *
@@ -32,38 +32,23 @@
 #define _ADDRESS_BOOK_CONFIG
 
 #include <gtk/gtk.h>
-#include <glib.h>
 
 #include "addressbook.h"
-#include "actions.h"
-#include "utils.h"
-
-G_BEGIN_DECLS
-
-#define ADDRESSBOOK_ENABLE                  "ADDRESSBOOK_ENABLE"
-#define ADDRESSBOOK_MAX_RESULTS             "ADDRESSBOOK_MAX_RESULTS"
-#define ADDRESSBOOK_DISPLAY_CONTACT_PHOTO   "ADDRESSBOOK_DISPLAY_CONTACT_PHOTO"
-#define ADDRESSBOOK_DISPLAY_PHONE_BUSINESS   "ADDRESSBOOK_DISPLAY_PHONE_BUSINESS"
-#define ADDRESSBOOK_DISPLAY_PHONE_HOME       "ADDRESSBOOK_DISPLAY_PHONE_HOME"
-#define ADDRESSBOOK_DISPLAY_PHONE_MOBILE     "ADDRESSBOOK_DISPLAY_PHONE_MOBILE"
+#include "sflphone_client.h"
 
 /**
  * Save the parameters through D-BUS
  */
 void
-addressbook_config_save_parameters (void);
+addressbook_config_save_parameters(GSettings *settings);
 
 /**
  * Return the saved parameters through D-Bus
  */
-AddressBook_Config *addressbook_config_load_parameters();
-
-gboolean
-addressbook_display (AddressBook_Config *settings, const gchar *field);
+AddressBook_Config *
+addressbook_config_load_parameters(GSettings *settings);
 
 GtkWidget*
-create_addressbook_settings();
-
-G_END_DECLS
+create_addressbook_settings(SFLPhoneClient *client);
 
 #endif // _ADDRESS_BOOK_CONFIG
