@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 2004, 2005, 2006, 2008, 2009, 2010, 2011 Savoir-Faire Linux Inc.
+ *  Copyright (C) 2004-2012 Savoir-Faire Linux Inc.
  *  Author: Pierre-Luc Beaudoin <pierre-luc.beaudoin@savoirfairelinux.com>
  *
  *  This program is free software; you can redistribute it and/or modify
@@ -14,7 +14,7 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301 USA.
  *
  *  Additional permission under GNU GPL version 3 section 7:
  *
@@ -31,7 +31,8 @@
 #ifndef __CONFIGWINDOW_H__
 #define __CONFIGWINDOW_H__
 
-#include <calllist.h>
+#include "calllist.h"
+#include "sflphone_client.h"
 
 /**
  * @file preferencesdialog.h
@@ -102,14 +103,10 @@ GtkWidget * create_recording_settings();
 /**
  * Display the main configuration window
  */
-guint show_preferences_dialog();
+guint show_preferences_dialog(SFLPhoneClient *client);
 
 void preferences_dialog_set_stun_visible();
 
-void save_configuration_parameters (void);
-
-void history_load_configuration (void);
-
-void instant_messaging_load_configuration (void);
+void save_configuration_parameters(SFLPhoneClient *client);
 
 #endif
