@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 2004, 2005, 2006, 2008, 2009, 2010, 2011 Savoir-Faire Linux Inc.
+ *  Copyright (C) 2004-2012 Savoir-Faire Linux Inc.
  *  Author: Julien Bonjean <julien.bonjean@savoirfairelinux.com>
  *
  *  This program is free software; you can redistribute it and/or modify
@@ -14,7 +14,7 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301 USA.
  *
  *  Additional permission under GNU GPL version 3 section 7:
  *
@@ -37,8 +37,6 @@
 #include "actions.h"
 #include <utils.h>
 
-G_BEGIN_DECLS
-
 enum {
     ACTION = 0, MASK, VALUE, COLUMNS
 };
@@ -46,6 +44,4 @@ enum {
 GtkWidget*
 create_shortcuts_settings ();
 
-G_END_DECLS
-
 #endif // _SHORTCUTS_CONFIG
