@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 2004, 2005, 2006, 2008, 2009, 2010, 2011 Savoir-Faire Linux Inc.
+ *  Copyright (C) 2004-2012 Savoir-Faire Linux Inc.
  *  Author: Alexandre Savard <alexandre.savard@savoirfairelinux.com>
  *
  *  This program is free software; you can redistribute it and/or modify
@@ -14,7 +14,7 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301 USA.
  *
  *  Additional permission under GNU GPL version 3 section 7:
  *
@@ -30,7 +30,6 @@
 
 #include "addrbookfactory.h"
 #include "addressbook-config.h"
-#include "logger.h"
 #include "calltab.h"
 #include "calltree.h"
 
@@ -57,22 +56,18 @@ handler_async_search(GList *hits, gpointer user_data)
         if (!entry)
             continue;
 
-        if (addressbook_display(addressbook_config,
-                                ADDRESSBOOK_DISPLAY_CONTACT_PHOTO))
+        if (addressbook_config->display_contact_photo)
             photo = entry->photo;
 
-        if (addressbook_display(addressbook_config,
-                                ADDRESSBOOK_DISPLAY_PHONE_BUSINESS))
+        if (addressbook_config->search_phone_business)
             calllist_add_contact(entry->name, entry->phone_business,
                                  CONTACT_PHONE_BUSINESS, photo);
 
-        if (addressbook_display(addressbook_config,
-                                ADDRESSBOOK_DISPLAY_PHONE_HOME))
+        if (addressbook_config->search_phone_home)
             calllist_add_contact(entry->name, entry->phone_home,
                                  CONTACT_PHONE_HOME, photo);
 
-        if (addressbook_display(addressbook_config,
-                                ADDRESSBOOK_DISPLAY_PHONE_MOBILE))
+        if (addressbook_config->search_phone_mobile)
             calllist_add_contact(entry->name, entry->phone_mobile,
                                  CONTACT_PHONE_MOBILE, photo);
 
@@ -89,20 +84,31 @@ handler_async_search(GList *hits, gpointer user_data)
 
 void abook_init()
 {
+    /* Clear any existing error */
+    dlerror();
+
     const gchar *addrbook_path = PLUGINS_DIR "/libevladdrbook.so";
+    /* FIXME: handle should be unloaded with dlclose on exit */
     void *handle = dlopen(addrbook_path, RTLD_LAZY);
 
     if (handle == NULL) {
-        DEBUG("Did not load addressbook from path %s", addrbook_path);
+        g_debug("Did not load addressbook from path %s:%s", addrbook_path, dlerror());
         return;
     }
 
-    addrbook = g_malloc(sizeof(AddrBookHandle));
+    addrbook = g_new0(AddrBookHandle, 1);
+    /* Keep the handle around to dlclose it later */
+    addrbook->handle = handle;
 
-#define LOAD(func) do { \
-        addrbook-> func = dlsym(handle, "addressbook_" #func); \
-        if (addrbook-> func == NULL) \
-            ERROR("Couldn't load " # func); \
+#define LOAD(func) do {                                         \
+        addrbook-> func = dlsym(handle, "addressbook_" #func);  \
+        if (addrbook-> func == NULL) {                          \
+            g_warning("Couldn't load " # func ":%s", dlerror());\
+            dlclose(handle);                                    \
+            g_free(addrbook);                                   \
+            addrbook = NULL;                                    \
+            return;                                             \
+        }                                                       \
     } while(0)
 
 
@@ -117,3 +123,15 @@ void abook_init()
 
     addrbook->search_cb = handler_async_search;
 }
+
+void
+free_addressbook()
+{
+    if (!addrbook)
+        return;
+
+    if (addrbook->handle)
+        dlclose(addrbook->handle);
+
+    g_free(addrbook);
+}
