@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 2004, 2005, 2006, 2008, 2009, 2010, 2011 Savoir-Faire Linux Inc.
+ *  Copyright (C) 2004-2012 Savoir-Faire Linux Inc.
  *  Author: Antoine Reversat <antoine.reversat@savoirfairelinux.com>
  *
  *  This program is free software; you can redistribute it and/or modify
@@ -14,7 +14,7 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301 USA.
  *
  *  Additional permission under GNU GPL version 3 section 7:
  *
@@ -34,14 +34,14 @@
 #include "str_utils.h"
 #include "calltree.h"
 #include "contacts/searchbar.h"
-#include "logger.h"
 
-calltab_t* calltab_init(gboolean searchbar_type, const gchar * const name)
+calltab_t*
+calltab_init(gboolean has_searchbar, const gchar * const name, SFLPhoneClient *client)
 {
     calltab_t* ret = g_new0(calltab_t, 1);
     ret->name = g_strdup(name);
 
-    calltree_create(ret, searchbar_type);
+    calltree_create(ret, has_searchbar, client);
 
     ret->callQueue = g_queue_new();
     ret->selectedCall = NULL;
@@ -54,7 +54,7 @@ void
 calltab_select_call(calltab_t* tab, callable_obj_t * c)
 {
     g_assert(tab);
-    DEBUG("Select call %s", c ? c->_callID : "");
+    g_debug("Select call %s", c ? c->_callID : "");
 
     tab->selectedType = A_CALL;
     tab->selectedCall = c;
@@ -66,7 +66,7 @@ void
 calltab_select_conf(calltab_t *tab, conference_obj_t * c)
 {
     g_assert(tab);
-    DEBUG("Selected conf %s", c ? c->_confID : "");
+    g_debug("Selected conf %s", c ? c->_confID : "");
 
     tab->selectedType = A_CONFERENCE;
     tab->selectedConf = c;
@@ -80,6 +80,13 @@ calltab_get_selected_type(calltab_t* tab)
     return tab->selectedType;
 }
 
+void
+calltab_set_selected_call(calltab_t *tab, callable_obj_t *call)
+{
+    g_assert(tab);
+    tab->selectedCall = call;
+}
+
 callable_obj_t *
 calltab_get_selected_call(calltab_t *tab)
 {
@@ -95,16 +102,16 @@ calltab_get_selected_conf(calltab_t *tab)
 }
 
 void
-calltab_create_searchbar(calltab_t* tab)
+calltab_create_searchbar(calltab_t* tab, SFLPhoneClient *client)
 {
     g_assert(tab);
 
     if (calltab_has_name(tab, HISTORY))
         tab->searchbar = history_searchbar_new();
     else if (calltab_has_name(tab, CONTACTS))
-        tab->searchbar = contacts_searchbar_new();
+        tab->searchbar = contacts_searchbar_new(client->settings);
     else
-        ERROR("Current calls tab does not need a searchbar\n");
+        g_warning("Current calls tab does not need a searchbar\n");
 }
 
 gboolean
