@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 2004, 2005, 2006, 2008, 2009, 2010, 2011 Savoir-Faire Linux Inc.
+ *  Copyright (C) 2004-2012 Savoir-Faire Linux Inc.
  *  Author: Antoine Reversat <antoine.reversat@savoirfairelinux.com>
  *
  *  This program is free software; you can redistribute it and/or modify
@@ -14,7 +14,7 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301 USA.
  *
  *  Additional permission under GNU GPL version 3 section 7:
  *
@@ -33,6 +33,7 @@
 
 #include "calllist.h"
 #include "conferencelist.h"
+#include "sflphone_client.h"
 #include <gtk/gtk.h>
 
 calltab_t* active_calltree_tab;
@@ -40,30 +41,33 @@ calltab_t* current_calls_tab;
 calltab_t* history_tab;
 calltab_t* contacts_tab;
 
-calltab_t* calltab_init (gboolean, const gchar * const);
+calltab_t* calltab_init(gboolean, const gchar * const, SFLPhoneClient *client);
 
 /** Mark a call as selected.  There can be only one selected call.  This call
   * is the currently highlighted one in the list.
   * @param c The call */
 void
-calltab_select_call (calltab_t *, callable_obj_t *);
+calltab_select_call(calltab_t *, callable_obj_t *);
 
 void
-calltab_select_conf (calltab_t *, conference_obj_t *);
+calltab_select_conf(calltab_t *, conference_obj_t *);
 
 gint
-calltab_get_selected_type (calltab_t *);
+calltab_get_selected_type(calltab_t *);
 
 /** Return the selected call.
   * @return The number of the caller */
 callable_obj_t *
-calltab_get_selected_call (calltab_t *);
-
-conference_obj_t *
-calltab_get_selected_conf (calltab_t *);
+calltab_get_selected_call(calltab_t *);
 
 void
-calltab_create_searchbar (calltab_t *);
+calltab_set_selected_call(calltab_t *, callable_obj_t *call);
+
+conference_obj_t *
+calltab_get_selected_conf(calltab_t *);
+
+void
+calltab_create_searchbar(calltab_t *, SFLPhoneClient *client);
 
 gboolean
 calltab_has_name(calltab_t *tab, const gchar *name);
