@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 2004, 2005, 2006, 2008, 2009, 2010, 2011 Savoir-Faire Linux Inc.
+ *  Copyright (C) 2004-2012 Savoir-Faire Linux Inc.
  *  Author: Julien Bonjean <julien.bonjean@savoirfairelinux.com>
  *
  *  This program is free software; you can redistribute it and/or modify
@@ -14,7 +14,7 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301 USA.
  *
  *  Additional permission under GNU GPL version 3 section 7:
  *
@@ -30,9 +30,9 @@
 
 #include <string.h>
 #include "history.h"
+#include "calltree.h"
 #include "searchbar.h"
 #include "calltab.h"
-#include "unused.h"
 
 static GtkTreeModel *history_filter;
 static GtkEntry *history_searchbar_widget;
@@ -52,19 +52,18 @@ search_type_matches_state(SearchType type, const gchar *state)
     }
 }
 
-static gboolean history_is_visible(GtkTreeModel* model, GtkTreeIter* iter, gpointer data UNUSED)
+static gboolean
+history_is_visible(GtkTreeModel* model, GtkTreeIter* iter, G_GNUC_UNUSED gpointer data)
 {
-    /* Skip conferences */
-    if (is_conference(model, iter))
-        return TRUE;
-
+    gboolean visible = TRUE;
     // Fetch the call description
     const gchar *text = NULL;
     const gchar *id = NULL;
     gtk_tree_model_get(model, iter, COLUMN_ACCOUNT_DESC, &text, COLUMN_ID, &id, -1);
+    if (!id)
+        return visible;
     callable_obj_t *history_entry = calllist_get_call(history_tab, id);
 
-    gboolean ret = TRUE;
     if (text && history_entry) {
         // Filter according to the type of call
         // MISSED, INCOMING, OUTGOING, ALL
@@ -74,15 +73,15 @@ static gboolean history_is_visible(GtkTreeModel* model, GtkTreeIter* iter, gpoin
             return TRUE;
 
         SearchType search_type = get_current_history_search_type();
-        ret = g_regex_match_simple(search, text, G_REGEX_CASELESS, 0);
+        visible = g_regex_match_simple(search, text, G_REGEX_CASELESS, 0);
 
         if (search_type == SEARCH_ALL)
-            return ret;
+            return visible;
         else // We need a match on the history_state and the current search type
-            ret = ret && search_type_matches_state(search_type, history_entry->_history_state);
+            visible = visible && search_type_matches_state(search_type, history_entry->_history_state);
     }
 
-    return ret;
+    return visible;
 }
 
 static GtkTreeModel* history_create_filter(GtkTreeModel* child)
@@ -92,7 +91,7 @@ static GtkTreeModel* history_create_filter(GtkTreeModel* child)
     return GTK_TREE_MODEL(ret);
 }
 
-void history_search(void)
+void history_search()
 {
     if (history_filter != NULL)
         gtk_tree_model_filter_refilter(GTK_TREE_MODEL_FILTER(history_filter));
