@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 2004, 2005, 2006, 2008, 2009, 2010, 2011 Savoir-Faire Linux Inc.
+ *  Copyright (C) 2004-2012 Savoir-Faire Linux Inc.
  *
  *  Author: Antoine Reversat <antoine.reversat@savoirfairelinux.com>
  *  Author: Emmanuel Milou <emmanuel.milou@savoirfairelinux.com>
@@ -17,7 +17,7 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301 USA.
  *
  *  Additional permission under GNU GPL version 3 section 7:
  *
@@ -32,19 +32,18 @@
  */
 
 #include <glib/gi18n.h>
-#include "gtk2_wrappers.h"
 #include "searchbar.h"
 #include "calltree.h"
 #include "calltab.h"
 #include "dbus.h"
-#include "logger.h"
-#include "unused.h"
+#include "mainwindow.h"
 #include "config/addressbook-config.h"
 #include "contacts/addressbook.h"
 #include "contacts/addrbookfactory.h"
 
 static GtkWidget * searchbox;
 static GtkWidget * addressbookentry;
+static SearchType HistorySearchType;
 
 static GtkWidget * cbox;
 static GtkListStore * liststore;
@@ -60,20 +59,24 @@ static GdkPixbuf *incoming_pixbuf;
 static GdkPixbuf *outgoing_pixbuf;
 static GdkPixbuf *missed_pixbuf;
 
-void searchbar_addressbook_activated(GtkEntry *entry, gchar *arg1 UNUSED, gpointer data UNUSED)
+static void
+searchbar_addressbook_activated(GtkEntry *entry, gpointer data)
 {
     if (addrbook)
-        addrbook->search(addrbook->search_cb, entry, addressbook_config_load_parameters());
+        addrbook->search(addrbook->search_cb, entry,
+                addressbook_config_load_parameters(data));
 }
 
-void searchbar_entry_changed(GtkEntry* entry UNUSED, gchar* arg1 UNUSED, gpointer data UNUSED)
+static void
+searchbar_entry_changed(G_GNUC_UNUSED GtkEntry* entry, G_GNUC_UNUSED gchar* arg1, G_GNUC_UNUSED gpointer data)
 {
-    DEBUG("Searchbar: Entry changed");
+    g_debug("Searchbar: Entry changed");
     if (calltab_has_name(active_calltree_tab, HISTORY))
         history_search();
 }
 
-static gchar *get_combobox_active_text(GtkWidget *widget)
+static gchar *
+get_combobox_active_text(GtkWidget *widget)
 {
     GtkTreeIter iter;
     if (!gtk_combo_box_get_active_iter(GTK_COMBO_BOX(widget), &iter))
@@ -86,42 +89,49 @@ static gchar *get_combobox_active_text(GtkWidget *widget)
     return string;
 }
 
-static void cbox_changed_cb(GtkWidget *widget, gpointer user_data UNUSED)
+static void
+update_current_addressbook(GtkWidget *widget, GSettings *settings)
 {
     if (!addrbook)
         return;
-
     gchar *string = get_combobox_active_text(widget);
     if (string) {
         addrbook->set_current_book(string);
         g_free(string);
     }
 
-    AddressBook_Config *addressbook_config = addressbook_config_load_parameters();
+    AddressBook_Config *addressbook_config = addressbook_config_load_parameters(settings);
     addrbook->search(addrbook->search_cb, GTK_ENTRY(addressbookentry), addressbook_config);
 }
 
-void set_focus_on_addressbook_searchbar()
+static void
+cbox_changed_cb(GtkWidget *widget, gpointer user_data)
+{
+    if (!addrbook)
+        return;
+    update_current_addressbook(widget, user_data);
+}
+
+void
+set_focus_on_addressbook_searchbar()
 {
     gtk_widget_grab_focus(addressbookentry);
 }
 
-void update_searchbar_addressbook_list()
+void
+update_searchbar_addressbook_list(GSettings *settings)
 {
-    GtkTreeIter iter, activeIter;
-    GSList *book_list_iterator;
-    book_data_t *book_data;
     GSList *books_data = NULL;
 
     if (addrbook)
-        books_data = addrbook->get_books_data(dbus_get_addressbook_list());
+        books_data = addrbook->get_books_data();
 
     if (books_data == NULL) {
-        ERROR("Searchbar: No books data found");
+        g_warning("Searchbar: No books data found");
         return;
     }
 
-    DEBUG("Searchbar: Update addressbook list");
+    g_debug("Searchbar: Update addressbook list");
 
     // we must disconnect signal from the cbox while updating its content
     g_signal_handler_disconnect(cbox, cboxSignalId);
@@ -137,9 +147,10 @@ void update_searchbar_addressbook_list()
     // Populate menu
     gboolean activeIsSet = FALSE;
 
-    for (book_list_iterator = books_data; book_list_iterator != NULL; book_list_iterator
-            = book_list_iterator->next) {
-        book_data = (book_data_t *) book_list_iterator->data;
+    GtkTreeIter iter, activeIter;
+    for (GSList *book_list_iterator = books_data; book_list_iterator != NULL;
+            book_list_iterator = book_list_iterator->next) {
+        book_data_t *book_data = (book_data_t *) book_list_iterator->data;
 
         if (book_data && book_data->active) {
 
@@ -159,112 +170,115 @@ void update_searchbar_addressbook_list()
             addrbook->set_current_book(activeText);
         } else {
             gtk_combo_box_set_active(GTK_COMBO_BOX(cbox), 0);
-            addrbook->set_current_book(get_combobox_active_text(cbox));
+            update_current_addressbook(cbox, settings);
         }
     }
 
     g_free(activeText);
-    cboxSignalId = g_signal_connect(G_OBJECT(cbox), "changed", G_CALLBACK(cbox_changed_cb), NULL);
+    cboxSignalId = g_signal_connect(G_OBJECT(cbox), "changed",
+            G_CALLBACK(cbox_changed_cb), settings);
 }
 
-
-static void select_search_type(GtkWidget *item, GtkEntry  *entry UNUSED)
+static gboolean
+label_matches(const gchar *label, GtkWidget *item)
 {
-    if (addrbook) {
-        DEBUG("Searchbar: %s", gtk_menu_item_get_label(GTK_MENU_ITEM(item)));
-
-        gtk_entry_set_icon_tooltip_text(GTK_ENTRY(addressbookentry), GTK_ENTRY_ICON_PRIMARY,
-                                        gtk_menu_item_get_label(GTK_MENU_ITEM(item)));
-
-
-        if (g_strcmp0("Search is", gtk_menu_item_get_label(GTK_MENU_ITEM(item))) == 0) {
-            addrbook->set_search_type(ABOOK_QUERY_IS);
-        } else if (g_strcmp0("Search begins with", gtk_menu_item_get_label(GTK_MENU_ITEM(item))) == 0) {
-            addrbook->set_search_type(ABOOK_QUERY_BEGINS_WITH);
-        } else if (g_strcmp0("Search contains", gtk_menu_item_get_label(GTK_MENU_ITEM(item))) == 0) {
-            addrbook->set_search_type(ABOOK_QUERY_CONTAINS);
-        }
-
-        AddressBook_Config *addressbook_config = addressbook_config_load_parameters();
-        addrbook->search(addrbook->search_cb, GTK_ENTRY(addressbookentry), addressbook_config);
-    }
-
-    AddressBook_Config *addressbook_config = addressbook_config_load_parameters();
-    addrbook->search (addrbook->search_cb, GTK_ENTRY (addressbookentry), addressbook_config);
+    return g_strcmp0(label, gtk_menu_item_get_label(GTK_MENU_ITEM(item))) == 0;
 }
 
-static void search_all(GtkWidget *item UNUSED, GtkEntry  *entry)
+static void
+select_search_type(GtkWidget *item, GSettings *settings)
 {
-    HistorySearchType = SEARCH_ALL;
+    if (!addrbook)
+        return;
 
-    gtk_entry_set_icon_from_stock(entry, GTK_ENTRY_ICON_PRIMARY, GTK_STOCK_FIND);
-    gchar *markup = g_markup_printf_escaped("%s\n%s",
-                                            _("Search all"),
-                                            _("Click here to change the search type"));
+    g_debug("Searchbar: %s", gtk_menu_item_get_label(GTK_MENU_ITEM(item)));
+
+    gtk_entry_set_icon_tooltip_text(GTK_ENTRY(addressbookentry), GTK_ENTRY_ICON_PRIMARY,
+                                    gtk_menu_item_get_label(GTK_MENU_ITEM(item)));
+
+
+    if (label_matches("Search is", item))
+        addrbook->set_search_type(ABOOK_QUERY_IS);
+    else if (label_matches("Search begins with", item))
+        addrbook->set_search_type(ABOOK_QUERY_BEGINS_WITH);
+    else if (label_matches("Search contains", item))
+        addrbook->set_search_type(ABOOK_QUERY_CONTAINS);
+
+    addrbook->search(addrbook->search_cb, GTK_ENTRY(addressbookentry),
+                     addressbook_config_load_parameters(settings));
+}
+
+static void
+update_search_entry(GtkEntry *entry, const gchar *search_str,
+                    const gchar *click_str, SearchType type)
+{
+    HistorySearchType = type;
+    gchar *markup = g_markup_printf_escaped("%s\n%s", search_str, click_str);
     gtk_entry_set_icon_tooltip_text(entry, GTK_ENTRY_ICON_PRIMARY, markup);
-
     g_free(markup);
     history_search();
 }
 
-static void search_by_missed(GtkWidget *item UNUSED, GtkEntry  *entry)
+static void
+search_all(G_GNUC_UNUSED GtkWidget *item, GtkEntry *entry)
 {
-    HistorySearchType = SEARCH_MISSED;
+    gtk_entry_set_icon_from_stock(entry, GTK_ENTRY_ICON_PRIMARY, GTK_STOCK_FIND);
+    update_search_entry(entry, _("Search all"),
+                        _("Click here to change the search type"), SEARCH_ALL);
+}
 
+static void
+search_by_missed(G_GNUC_UNUSED GtkWidget *item, GtkEntry *entry)
+{
     gtk_entry_set_icon_from_pixbuf(entry, GTK_ENTRY_ICON_PRIMARY, missed_pixbuf);
-    gtk_entry_set_icon_tooltip_text(entry, GTK_ENTRY_ICON_PRIMARY,
-                                    g_markup_printf_escaped("%s\n%s",
-                                            _("Search by missed call"),
-                                            _("Click here to change the search type")));
-    history_search();
+    update_search_entry(entry, _("Search by missed call"),
+                        _("Click here to change the search type"), SEARCH_MISSED);
 }
 
-static void search_by_incoming(GtkWidget *item UNUSED, GtkEntry *entry)
+static void
+search_by_incoming(G_GNUC_UNUSED GtkWidget *item, GtkEntry *entry)
 {
-    HistorySearchType = SEARCH_INCOMING;
-
     gtk_entry_set_icon_from_pixbuf(entry, GTK_ENTRY_ICON_PRIMARY, incoming_pixbuf);
-    gtk_entry_set_icon_tooltip_text(entry, GTK_ENTRY_ICON_PRIMARY,
-                                    g_markup_printf_escaped("%s\n%s",
-                                            _("Search by incoming call"),
-                                            _("Click here to change the search type")));
-    history_search();
+    update_search_entry(entry, _("Search by incoming call"),
+                        _("Click here to change the search type"), SEARCH_INCOMING);
 }
 
-static void search_by_outgoing(GtkWidget *item UNUSED, GtkEntry  *entry)
+static void
+search_by_outgoing(G_GNUC_UNUSED GtkWidget *item, GtkEntry *entry)
 {
-    HistorySearchType = SEARCH_OUTGOING;
-
     gtk_entry_set_icon_from_pixbuf(entry, GTK_ENTRY_ICON_PRIMARY, outgoing_pixbuf);
-    gtk_entry_set_icon_tooltip_text(entry, GTK_ENTRY_ICON_PRIMARY,
-                                    g_markup_printf_escaped("%s\n%s",
-                                            _("Search by outgoing call"),
-                                            _("Click here to change the search type")));
-    history_search();
+    update_search_entry(entry, _("Search by outgoing call"),
+                        _("Click here to change the search type"), SEARCH_OUTGOING);
 }
 
-static void icon_press_cb(GtkEntry *entry, gint position, GdkEventButton *event, gpointer data UNUSED)
+static void
+icon_press_cb(GtkEntry *entry, gint position, GdkEventButton *event, G_GNUC_UNUSED gpointer data)
 {
-    DEBUG("Searchbar: Icon pressed");
+    g_debug("Searchbar: Icon pressed");
 
-    if (position == GTK_ENTRY_ICON_PRIMARY && calltab_has_name(active_calltree_tab, HISTORY))
-        gtk_menu_popup(GTK_MENU(menu), NULL, NULL, NULL, NULL,
-                       event->button, event->time);
-    else if (position == GTK_ENTRY_ICON_PRIMARY && calltab_has_name(active_calltree_tab, CONTACTS)) {
-        GtkWidget *addrbook_menu = addressbook_menu_new();
-        gtk_menu_popup(GTK_MENU(addrbook_menu), NULL, NULL, NULL, NULL,
-                       event->button, event->time);
-    } else
+    if (position == GTK_ENTRY_ICON_PRIMARY)
+       if (calltab_has_name(active_calltree_tab, HISTORY))
+           gtk_menu_popup(GTK_MENU(menu), NULL, NULL, NULL,
+                          NULL, event->button, event->time);
+       else if (calltab_has_name(active_calltree_tab, CONTACTS))
+           gtk_menu_popup(GTK_MENU(addressbook_menu_new()), NULL, NULL, NULL,
+                          NULL, event->button, event->time);
+       else
+           gtk_entry_set_text(entry, "");
+    else
         gtk_entry_set_text(entry, "");
 }
 
-static void text_changed_cb(GtkEntry *entry, GParamSpec *pspec UNUSED)
+static void
+text_changed_cb(GtkEntry *entry, G_GNUC_UNUSED GParamSpec *pspec)
 {
     const gboolean has_text = gtk_entry_get_text_length(entry) > 0;
     gtk_entry_set_icon_sensitive(entry, GTK_ENTRY_ICON_SECONDARY, has_text);
 }
 
-GtkWidget *addressbook_menu_new(void)
+
+GtkWidget *
+addressbook_menu_new(GSettings *settings)
 {
     // Create the menu
     GtkWidget *menu_widget = gtk_menu_new();
@@ -272,15 +286,15 @@ GtkWidget *addressbook_menu_new(void)
 
     // Populate menu
     GtkWidget *item = gtk_menu_item_new_with_label("Search is");
-    g_signal_connect(item, "activate", G_CALLBACK(select_search_type), searchbox);
+    g_signal_connect(item, "activate", G_CALLBACK(select_search_type), settings);
     gtk_menu_shell_append(GTK_MENU_SHELL(menu_widget), item);
 
     item = gtk_menu_item_new_with_label("Search begins with");
-    g_signal_connect(item, "activate", G_CALLBACK(select_search_type), searchbox);
+    g_signal_connect(item, "activate", G_CALLBACK(select_search_type), settings);
     gtk_menu_shell_append(GTK_MENU_SHELL(menu_widget), item);
 
     item = gtk_menu_item_new_with_label("Search contains");
-    g_signal_connect(item, "activate", G_CALLBACK(select_search_type), searchbox);
+    g_signal_connect(item, "activate", G_CALLBACK(select_search_type), settings);
     gtk_menu_shell_append(GTK_MENU_SHELL(menu_widget), item);
 
     gtk_widget_show_all(menu_widget);
@@ -288,7 +302,9 @@ GtkWidget *addressbook_menu_new(void)
     return menu_widget;
 }
 
-GtkWidget* history_searchbar_new(void)
+
+GtkWidget*
+history_searchbar_new()
 {
     GtkWidget *ret = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 0);
 
@@ -304,7 +320,6 @@ GtkWidget* history_searchbar_new(void)
 
     g_signal_connect(searchbox, "icon-press", G_CALLBACK(icon_press_cb), NULL);
     g_signal_connect(searchbox, "notify::text", G_CALLBACK(text_changed_cb), NULL);
-    //g_signal_connect (searchbox, "activate", G_CALLBACK (activate_cb), NULL);
 
     // Set up the search icon
     search_all(NULL, GTK_ENTRY(searchbox));
@@ -351,53 +366,43 @@ GtkWidget* history_searchbar_new(void)
     return ret;
 }
 
-GtkWidget* contacts_searchbar_new()
+GtkWidget*
+contacts_searchbar_new(GSettings *settings)
 {
-    GtkTreeIter iter, activeIter;
-    GtkCellRenderer *cell;
-
     GtkWidget *ret = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 0);
 
-    liststore = gtk_list_store_new(1,G_TYPE_STRING);
+    liststore = gtk_list_store_new(1, G_TYPE_STRING);
 
     // Create combo box to select current addressbook
     if (!addrbook)
         return NULL;
 
-    gchar **book_list = dbus_get_addressbook_list();
-
-    addrbook->init(book_list);
-
-    GSList *book_list_iterator;
-    book_data_t *book_data;
-    GSList *books_data = addrbook->get_books_data(book_list);
+    addrbook->init();
 
     // Populate menu
     int count = 0;
     gboolean activeIsSet = FALSE;
 
-    for (book_list_iterator = books_data; book_list_iterator != NULL;
-            book_list_iterator = book_list_iterator->next) {
-        book_data = (book_data_t *) book_list_iterator->data;
+    GtkTreeIter iter, activeIter;
+    GSList *books_data = addrbook->get_books_data();
+    for (GSList *book_list_iterator = books_data; book_list_iterator != NULL;
+         book_list_iterator = book_list_iterator->next) {
+        book_data_t *book_data = (book_data_t *) book_list_iterator->data;
 
-        DEBUG("^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^ %s", book_data->name);
+        g_debug("^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^ %s", book_data->name);
 
         if (book_data->active) {
 
             gtk_list_store_append(liststore, &iter);
-
             gtk_list_store_set(liststore, &iter, 0, book_data->name, -1);
 
-            if (book_data->isdefault) {
-                activeIter = iter;
-                activeIsSet = TRUE;
-            }
-
+            activeIter = iter;
+            activeIsSet = TRUE;
             count++;
         }
     }
 
-    cbox = gtk_combo_box_new_with_model((GtkTreeModel *) liststore);
+    cbox = gtk_combo_box_new_with_model(GTK_TREE_MODEL(liststore));
 
     if (activeIsSet)
         gtk_combo_box_set_active_iter(GTK_COMBO_BOX(cbox), &activeIter);
@@ -412,20 +417,17 @@ GtkWidget* contacts_searchbar_new()
     gtk_widget_get_size_request(GTK_WIDGET(cbox), &cbox_width, &cbox_height);
     gtk_widget_set_size_request(GTK_WIDGET(cbox), cbox_width, 26);
 
-    cboxSignalId = g_signal_connect(G_OBJECT(cbox), "changed", G_CALLBACK(cbox_changed_cb), NULL);
+    cboxSignalId = g_signal_connect(G_OBJECT(cbox), "changed",
+            G_CALLBACK(cbox_changed_cb), settings);
 
-    cell = gtk_cell_renderer_text_new();
+    GtkCellRenderer *cell = gtk_cell_renderer_text_new();
     gtk_cell_layout_pack_start(GTK_CELL_LAYOUT(cbox), cell, TRUE);
     gtk_cell_layout_set_attributes(GTK_CELL_LAYOUT(cbox), cell, "text", 0, NULL);
 
-
-    // GdkPixbuf *pixbuf;
-
     gchar *tooltip_text = g_strdup("Search is");
 
     addressbookentry = gtk_entry_new();
     gtk_entry_set_icon_from_stock(GTK_ENTRY(addressbookentry), GTK_ENTRY_ICON_SECONDARY, GTK_STOCK_CLEAR);
-    // pixbuf = gdk_pixbuf_new_from_file (ICONS_DIR "/stock_person.svg", NULL);
     gtk_entry_set_icon_from_stock(GTK_ENTRY(addressbookentry), GTK_ENTRY_ICON_PRIMARY, GTK_STOCK_FIND);
     gtk_entry_set_icon_tooltip_text(GTK_ENTRY(addressbookentry), GTK_ENTRY_ICON_PRIMARY,
                                     tooltip_text);
@@ -437,7 +439,8 @@ GtkWidget* contacts_searchbar_new()
     g_signal_connect(addressbookentry, "icon-press", G_CALLBACK(icon_press_cb), NULL);
 
     gtk_entry_set_activates_default(GTK_ENTRY(addressbookentry), TRUE);
-    g_signal_connect_after(GTK_ENTRY(addressbookentry), "activate", G_CALLBACK(searchbar_addressbook_activated), NULL);
+    g_signal_connect_after(GTK_ENTRY(addressbookentry), "activate",
+            G_CALLBACK(searchbar_addressbook_activated), settings);
 
     g_signal_connect_after(GTK_ENTRY(addressbookentry), "changed", G_CALLBACK(searchbar_entry_changed), NULL);
 
@@ -451,12 +454,13 @@ GtkWidget* contacts_searchbar_new()
     gtk_box_pack_start(GTK_BOX(ret), addressbookentry, TRUE, TRUE, 0);
 
     g_free(tooltip_text);
-    g_strfreev(book_list);
+
+    update_current_addressbook(cbox, settings);
 
     return ret;
 }
 
-SearchType get_current_history_search_type (void)
+SearchType get_current_history_search_type()
 {
     return HistorySearchType;
 }
