@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 2004, 2005, 2006, 2008, 2009, 2010, 2011 Savoir-Faire Linux Inc.
+ *  Copyright (C) 2004-2012 Savoir-Faire Linux Inc.
  *
  *  Author: Antoine Reversat <antoine.reversat@savoirfairelinux.com>
  *  Author: Emmanuel Milou <emmanuel.milou@savoirfairelinux.com>
@@ -17,7 +17,7 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301 USA.
  *
  *  Additional permission under GNU GPL version 3 section 7:
  *
@@ -39,45 +39,43 @@
 #ifndef __SEARCH_FILTER_H__
 #define __SEARCH_FILTER_H__
 
-#include <calllist.h>
 #include <gtk/gtk.h>
-#include <mainwindow.h>
-
-#include <addressbook.h>
-#include <history.h>
-
-GdkPixbuf *waitingPixOff;
-
-SearchType HistorySearchType;
+#include "history.h"
 
 /**
  * Create a new search bar for call hostory
  */
-GtkWidget* history_searchbar_new (void);
+GtkWidget*
+history_searchbar_new();
 
 /**
  * Create a new search bar for addressbook
  */
-GtkWidget* contacts_searchbar_new (void);
+GtkWidget*
+contacts_searchbar_new(GSettings *settings);
 
 /**
  * Get type of call to be search from call history
  */
-SearchType get_current_history_search_type (void);
+SearchType
+get_current_history_search_type();
 
 /**
  * Set focus on addressbook search bar
  */
-void set_focus_on_addressbook_searchbar (void);
+void
+set_focus_on_addressbook_searchbar();
 
 /**
  * Reload combo box to update list of active addressbook
  */
-void update_searchbar_addressbook_list (void);
+void
+update_searchbar_addressbook_list(GSettings *settings);
 
 /**
  * Create a new menu listing all system addressbooks
  */
-GtkWidget *addressbook_menu_new (void);
+GtkWidget *
+addressbook_menu_new();
 
 #endif
