@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 2004, 2005, 2006, 2008, 2009, 2010, 2011 Savoir-Faire Linux Inc.
+ *  Copyright (C) 2004-2012 Savoir-Faire Linux Inc.
  *  Author: Julien Bonjean <julien.bonjean@savoirfairelinux.com>
  *
  *  This program is free software; you can redistribute it and/or modify
@@ -14,7 +14,7 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301 USA.
  *
  *  Additional permission under GNU GPL version 3 section 7:
  *
@@ -32,17 +32,18 @@
 #define SHORTCUTS_H_
 
 #include <gdk/gdkx.h>
+#include "sflphone_client.h"
 
 typedef struct {
     gchar *action;
     guint key;
     GdkModifierType mask;
-    void
-    (*callback) (void);
+    void (*callback) (gpointer data);
+    gpointer data;
 } Accelerator;
 
 void
-shortcuts_initialize_bindings ();
+shortcuts_initialize_bindings(SFLPhoneClient *client);
 
 void
 shortcuts_update_bindings (guint index, guint key, GdkModifierType mask);
